package com.uoc.footballteam.business;

import java.math.BigDecimal;
import java.sql.Date;
import java.sql.Time;
import java.util.ArrayList;
import java.util.GregorianCalendar;

import com.uoc.footballteam.integration.DEntrenaments;
import com.uoc.footballteam.integration.DEquips;
import com.uoc.footballteam.integration.DJugadors;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;

/**
 * Classe que gestiona els equips.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
public class NEquips {
	//Fitxer de configuraci de MyFrameUOC que s'utilitza.
	private String file		= null;
	
	/**
	 * Constructor.
	 * 
	 * @param file - Fixer de configuraci de MyFrameUOC que s'utilitza.
	 */
	public NEquips(String file){
		this.file = file;
	}
	
	/**
	 * Permet donar d'alta un equip.
	 * 
	 * @param equip - Equip que es vol donar d'alta.
	 * 
	 * @throws MyFrameUOCException Si no es pot emmagatzemar l'equip en la base de dades. 
	 */
	public void altaEquip(int idEquip, String nom, String estadi, BigDecimal pressupost) throws MyFrameUOCException{
		DEquips equip		= null;
		
		equip = new DEquips(idEquip, nom, estadi, pressupost);
		equip.altaEquip(this.file);
	}
	
	/**
	 * Permet obtenir un equip que est emmagatzemat en la base de dades.
	 * 
	 * @param idEquip - Identificador de l'equip que es vol recuperar de la base de dades.
	 * 
	 * @return Un <code>DEquips</code> que cont l'equip que es recupera de la base de dades.
	 * 
	 * @throws MyFrameUOCException Si es produeix algn error al recuperar l'equip de la base de dades. 
	 */
	public DEquips consultaEquip(int idEquip) throws MyFrameUOCException{
		DEquips equip		= null;
		
		equip = new DEquips();
		equip = equip.consultaEquip(this.file, idEquip);
		
		return (equip);
	}
	
	/**
	 * Permet obtenir una llista amb els equips que estan emmagatzemats en la base de dades.
	 * 
	 * @return Un <code>ArrayList</code> amb els equips que estan emmagatzemats en la base de dades.
	 * 
	 * @throws MyFrameUOCException Si no es pot obtenir la llista d'equips. 
	 */
	public ArrayList<DEquips> consultaLlistatEquips() throws MyFrameUOCException{
		ArrayList<DEquips> equips		= null;
		DEquips dequips					= null;
		
		dequips = new DEquips();
		equips = dequips.consultaLlistatEquips(this.file);
		return (equips);
	}
	
	/**
	 * Eliminar un equip de la base de dades.
	 * 
	 * @param equip Un <DEquips> que cont l'equip que es vol eliminar de la base de dades.
	 * 
	 * @throws Exception Si no es pot eliminar l'equip de la base de dades. 
	 */
	public void baixaEquip(DEquips equip) throws Exception{
		if (equip != null){
			equip.baixaEquip(this.file);
		}
	}
	
	/**
	 * Actualitza un equip en la base de dades.
	 * 
	 * @param equip - Equip que es vol actualitzar en la base de dades.
	 * 
	 * @throws MyFrameUOCException Si no es pot actualitzar l'equip en la base de dades. 
	 */
	public void actualitzaEquip(DEquips equip) throws MyFrameUOCException{
		if (equip != null){
			equip.actualitzaEquip(this.file);
		}
	}
	
	/**
	 * Permet obtenir els jugadors que no tenen equip.
	 * 
	 * @return Un <code>ArrayList</code> que cont la llista de jugadors que no tenen equip.
	 * 
	 * @throws MyFrameUOCException Si no es pot obtenir la llista de jugadors que no tenen equip. 
	 */
	public ArrayList<DJugadors> consultaJugadorsSenseEquip() throws MyFrameUOCException{
		ArrayList<DJugadors> jugadors		= null;
		DEquips equip						= null;
		
		equip = new DEquips();
		jugadors = equip.consultaJugadorsSenseEquip(this.file);
		
		return (jugadors);
	}
	
	/**
	 * Afegeix un jugador a un equip.
	 * 
	 * @param DNI - DNI del jugador que es vol afegir a l'equip.
	 * @param equip - Equip a on es vol afegir el jugador.
	 * 
	 * @throws Exception Si no es pot afegir el jugador a l'equip. 
	 */
	public void incloureJugador(char[] DNI, DEquips equip) throws Exception{
		if (equip != null){
			equip.incloureJugador(this.file, DNI);
		}
	}
	
	/**
	 * Treu un jugador d'un equip.
	 * 
	 * @param DNI - DNI del jugador que es vol treure de l'equip.
	 * @param equip - Equip del qual es vol treure el jugador.
	 * 
	 * @throws Exception Si no es pot treure el jugador de l'equip. 
	 */
	public void treureJugador(char[] DNI, DEquips equip) throws Exception{
		if (equip != null){
			equip.treureJugador(this.file, DNI);
		}
	}
	
	/**
	 * Carrega unes dades inicials de demostraci.
	 * 
	 * @throws Exception Si no es poden carregar les dades inicials de demostraci. 
	 */
	public void carregarDadesInicials() throws Exception{
		DEquips equip1				= null;
		DEquips equip2				= null;
		DJugadors jugador1			= null;
		DJugadors jugador2			= null;
		DEntrenaments entrenament1	= null;
		DEntrenaments entrenament2	= null;
		DEntrenaments entrenament3	= null;
		GregorianCalendar gc		= null;
		Date date					= null;
		Time durada					= null;
		DEquips equip				= null;
		DJugadors jugador			= null;
		DEntrenaments entrenament	= null;
		
		equip1 = new DEquips(1, "Real Madrid", "Santiago Bernabu", new BigDecimal("250000000"));
		equip2 = new DEquips(2, "Bara", "Camp Nou", new BigDecimal("500000000"));
		
		gc = new GregorianCalendar(1978, 9, 25);
		date = new Date(gc.getTime().getTime());
		jugador1 =  new DJugadors("57575757B".toCharArray(), "Iker", "Casillas", "Snchez", "Espaa", date, 34, "Porter", new BigDecimal("2000000"));
		
		gc = new GregorianCalendar(1980, 1, 25);
		date = new Date(gc.getTime().getTime());
		jugador2 = new DJugadors("44433333T".toCharArray(), "Xavi", "Hernndez", "Lpez", "Espaa", date, 32, "Migcampista", new BigDecimal("150000"));
		
		durada = Time.valueOf("00:15:00");
		entrenament1 = new DEntrenaments("1", "Xuts a porta","Fer xuts a porta buida per amb l'objectiu de ficar la pilota dins de la porteria.", "Fer 10 xuts a l'esquerra de la porteria, 10 xuts al centre i altres 10 xuts a la dreta.", 3, durada);
		
		durada = Time.valueOf("01:30:00");
		entrenament2 = new DEntrenaments("2", "Carrera contnua","Fer carreres contnues.", "Fer carreres contnues de 10 km per a millorar la resistncia aerbica del jugador.", 1, durada);
		
		durada = Time.valueOf("01:30:00");
		entrenament3 = new DEntrenaments("3", "Control pilota ","Fer controls amb la pilota.", "Es tracta de millorar el control del jugador quan rep una pilota.", 5, durada);
		
		jugador1.afegirEntrenament(entrenament1);
		jugador1.afegirEntrenament(entrenament3);
		
		jugador2.afegirEntrenament(entrenament1);
		jugador2.afegirEntrenament(entrenament3);
		
		equip2.afegirJugador(jugador2);
		
		equip = new DEquips();
		equip.drop(this.file);
		
		jugador =  new DJugadors();
		jugador.drop(this.file);
		
		entrenament = new DEntrenaments();
		entrenament.drop(this.file);
		
		equip1.altaEquip(this.file);
		equip2.altaEquip(this.file);
		jugador1.altaJugador(this.file);
		entrenament2.altaEntrenament(this.file);
	}
}
