package com.uoc.footballteam.business;

import java.math.BigDecimal;
import java.util.ArrayList;

import com.uoc.footballteam.integration.DJugadors;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;

/**
 * Classe que gestiona els jugadors d'un equip.
 * 
 * @author Jordi Garcia Casanova
 *
 */
public class NJugadors {

	//Fitxer de configuraci de MyFrameUOC que s'utilitza.
	private String file		= null;
	
	/**
	 * Constructor.
	 * 
	 * @param file - Fitxer de configuraci de MyFrameUOC que s'utilitza.
	 */
	public NJugadors(String file){
		this.file = file;
	}
	
	/**
	 * Permet donar d'alta un nou jugador.
	 * 
	 * @param DNI - Nmdeo de D.N.I. del jugador.
	 * @param nom - Nom del jugador.
	 * @param cognom1 - Prmier cognom del jugador.
	 * @param cognom2 - Segon cognom deljugador.
	 * @param pais - Pas denaixament del jugador.
	 * @param dataNaixement - Data de naixement del jugador.
	 * @param edat - Edat actual del jugador.
	 * @param demarcacio - Posici que ocupa el jugador en el camp.
	 * @param sou - Sou del jugador.
	 * 
	 * @throws Exception Si no es pot donar d'alta el jugador. 
	 */
	public void altaJugador(char[] DNI, String nom, String cognom1, String cognom2, String pais, java.sql.Date dataNaixement, 
			int edat, String demarcacio, BigDecimal sou) throws Exception{
		DJugadors jugador	= null;
		
		jugador = new DJugadors(DNI, nom, cognom1, cognom2, pais, dataNaixement, edat, demarcacio, sou);
		jugador.altaJugador(this.file);
	}
	
	/**
	 * Permet obtenir un jugador que est emmagatzemat en la base de dades.
	 * 
	 * @param DNI - DNI del jugador que es vol obtenir.
	 * 
	 * @return Un <code>DJugadors</code> que cont el jugador o nul si no est emmagatzemat en la base de dades.
	 * 
	 * @throws Exception Si es produeix un error al recuperar el jugador de la base de dades. 
	 */
	public DJugadors consultaJugador(char[] DNI) throws Exception{
		DJugadors jugador		= null;
		
		jugador = new DJugadors();
		jugador = jugador.consultaJugador(this.file, DNI);
		
		return (jugador);
	}
	
	/**
	 * Permet obtenir tots els jugadors que estan emmagatzemats en la base de dades.
	 * 
	 * @return Un <code>ArrayList</code> que cont tots els jugadors que estan emmagatzemats
	 * en la base de dades.
	 * 
	 * @throws MyFrameUOCException Si no es podenobtenir els jugadors emmagatzemats de la base de dades. 
	 */
	public ArrayList<DJugadors> consultaLlistatJugadors() throws MyFrameUOCException{
		ArrayList<DJugadors> jugadors		= null;
		DJugadors jugador					= null;
		
		jugador = new DJugadors();
		jugadors = jugador.consultaLlistatJugadors(this.file);
		
		return (jugadors);
	}
	
	/**
	 * Elimina un jugador de la base de dades.
	 * 
	 * @param jugador - Jugador que es vol esborrar.
	 * 
	 * @throws Exception Si no es pot esborrar el jugador de la base de dades. 
	 */
	public void baixaJugador(DJugadors jugador) throws Exception{
		if (jugador != null){
			jugador.baixaJugador(this.file);
		}
	}
	
	/**
	 * Actualitza un jugador.
	 * 
	 * @param jugador - Jugador que es vol actualitzar.
	 * 
	 * @throws Exception Si no es pot actualitzar el jugador. 
	 */
	public void actualitzaJugador(DJugadors jugador) throws Exception{
		if (jugador != null){
			jugador.actualitzaJugador(this.file);
		}
	}
	
	/**
	 * Iniciar un entrenament per a un jugador.
	 * 
	 * @param jugador - Jugador al qual es vol iniciar l'entrenament.
	 * @param idEntrenament - Identificador de l'entrenament que es vol iniciar per al jugador.
	 * 
	 * @throws Exception Si no es pot iniciar l'entrenament per al jugador. 
	 */
	public void iniciarEntrenament(DJugadors jugador, String idEntrenament) throws Exception{
		if (jugador != null){
			jugador.iniciarEntrenament(this.file, idEntrenament);
		}
	}
	
	/**
	 * Finalitza un entrenament per a un jugador.
	 * 
	 * @param jugador - Jugador al qual es vol finalitzar l'entrenament.
	 * @param idEntrenament - Identificador de l'entrenament que es vol finalitzar per al jugador.
	 * 
	 * @throws Exception Si no es pot iniciar l'entrenament per al jugador. 
	 */
	public void finalitzarEntrenament(DJugadors jugador, String idEntrenament) throws Exception{
		if (jugador != null){
			jugador.finalitzarEntrenament(this.file, idEntrenament);
		}
	}
}
