package com.uoc.footballteam.integration;

import java.sql.Time;
import java.util.ArrayList;

import com.uoc.myframeuoc.annotations.*;
import com.uoc.myframeuoc.environment.Session;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;

/**
 * Classe que representa un entrenament.
 * 
 * @author Jordi Garcia Casanova
 *
 */
@Entity(Table = "Entrenament")
public class DEntrenaments {
	@PrimaryKey(Name = "PK_Entrenament", Field = "campIdEntrenament", Length = "10")
	private String idEntrenament;
	
	@Column(Field = "campNom", Length = "40", Required = true)
	private String nom;
	
	@Column(Field = "campDescripcio", Length = "1000")
	private String descripcio;
	
	@Column(Field = "campInstruccions", Length = "3000")
	private String instruccions;
	
	@Column(Field = "campSessions")
	int sessions;
	
	@Column(Field = "campDurada")
	Time durada;
	
	@ManyToMany(Table = "EntrenamentJugador", NameFK_To = "PK1_EntrenamentJugador", NameFK_From = "PK2_EntrenamentJugador", Fields_To = "jugador-DNI", Fields_From = "entrenament-idEntrenament")
	private ArrayList<DJugadors> jugadors;
	
	//Getters i setters.
	public String getIdEntrenament() {
		return idEntrenament;
	}

	public void setIdEntrenament(String idEntrenament) {
		this.idEntrenament = idEntrenament;
	}

	public String getNom() {
		return nom;
	}

	public void setNom(String nom) {
		this.nom = nom;
	}

	public String getDescripcio() {
		return descripcio;
	}

	public void setDescripcio(String descripcio) {
		this.descripcio = descripcio;
	}

	public String getInstruccions() {
		return instruccions;
	}

	public void setInstruccions(String instruccions) {
		this.instruccions = instruccions;
	}

	public int getSessions() {
		return sessions;
	}

	public void setSessions(int sessions) {
		this.sessions = sessions;
	}

	public Time getDurada() {
		return durada;
	}

	public void setDurada(Time durada) {
		this.durada = durada;
	}

	public ArrayList<DJugadors> getJugadors() {
		return jugadors;
	}

	public void setJugadors(ArrayList<DJugadors> jugadors) {
		this.jugadors = jugadors;
	}

	public void afegirJugador(DJugadors jugador){
		if (this.jugadors == null){
			this.jugadors = new ArrayList<DJugadors>();
		}
		this.jugadors.add(jugador);
	}
	
	public DJugadors treureJugador(char[] DNI){
		boolean trobat		= false;
		int i;
		int numJugadors;
		DJugadors jug		= null;
		
		if (this.jugadors != null){
			numJugadors = this.jugadors.size();
			i = 0;
			trobat = false;
			while (!trobat && i < numJugadors){
				jug = this.jugadors.get(i);
				if (String.valueOf(jug.getDNI()).equals(String.valueOf(DNI))){
					trobat = true;
				}
				else{
					i++;
				}
				if (trobat){
					this.jugadors.remove(i);
				}
			}
		}
		return (jug);
	}
	
	/**
	 * Constructor.
	 */
	public DEntrenaments() {
	}

	/**
	 * Constructor.
	 * 
	 * @param idEntrenament - Identificador de l'entrenament.
	 * @param nom - Nom de l'entrenament.
	 * @param descripcio - Descripci de l'entrenament.
	 * @param instruccions - Instruccions de l'entrenament.
	 * @param duracio - Nmero de sessions de qu consta l'entrenament.
	 * @param durada - Temps que es triga en completar una sessi de l'entrenament.
	 */
	public DEntrenaments(String idEntrenament, String nom, String descripcio, String instruccions, int sessions, Time durada){
		this.idEntrenament = idEntrenament;
		this.nom = nom;
		this.descripcio = descripcio;
		this.instruccions = instruccions;
		this.sessions = sessions;
		this.durada = durada;
	}
	
	/**
	 * Permet obtenir els entrenaments que hi ha emmagatzemats en la base de dades.
	 * 
	 * @param file - Fitxer de configuraci de MyFrameUOC que s'utilitza.
	 * 
	 * @return Un <code>ArrayList</code> que cont els entrenaments que hi ha emmagatzemats en la base de dades.
	 * 
	 * @throws MyFrameUOCException Si no es poden obtenir els entrenaments que hi ha en la base de dades. 
	 */
	public ArrayList<DEntrenaments> consultaLlistatEntrenaments(String file) throws MyFrameUOCException{
		ArrayList<DEntrenaments> entrenaments		= null;
		ArrayList<Object> llista					= null;
		DEntrenaments entrenament					= null;
		Session session								= null;
		String queryUOCQL							= null;
		
		try{
			session = Session.getSession(file);
			queryUOCQL = "FROM " + DEntrenaments.class.getCanonicalName() + " WHERE idEntrenament IS NOT NULL";
			llista = session.executeUOCQL(queryUOCQL);
			if (llista != null && llista.size() > 0){
				entrenaments = new ArrayList<DEntrenaments>();
				for (Object obj: llista){
					entrenament = (DEntrenaments) obj;
					entrenaments.add(entrenament);
				}
			}
		}
		finally{
			if (session != null){
				session.closeNoEx();
			}
		}
		return (entrenaments);
	}
	
	/**
	 * Permet recuperar un entrenament que est emmagatzemat en la base de dades.
	 * 
	 * @param file - Fitxer de configuraci de MyFrameUOC que s'utilitza.
	 * @param idEntrenament - Identificador de l'entrenament que es vol recuperar de la base de dades.
	 * 
	 * @return Un <code>DEntrenaments</code> que cont l'entrenament que es recupera de la base de dades.
	 * 
	 * @throws MyFrameUOCException Si es produeix un error en la recuperaci de l'entrenament de la base de dades. 
	 */
	public DEntrenaments consultaEntrenament(String file, String idEntrenament) throws MyFrameUOCException{
		DEntrenaments entrenament	= null;
		Session session				= null;
		ArrayList<Object> pk		= null;
		
		try{
			session = Session.getSession(file);
			if (idEntrenament != null){
				pk = new ArrayList<Object>();
				pk.add(idEntrenament);
				entrenament = (DEntrenaments) session.read(DEntrenaments.class.getCanonicalName(), pk);
			}
		}
		finally{
			if (session != null){
				session.closeNoEx();
			}
		}
		return (entrenament);
	}
	
	/**
	 * Emmagatzema l'entrenament en la base de dades.
	 * 
	 * @param file - Fitxer de configuraci de MyFrameUOC que s'utilitza.
	 * 
	 * @throws MyFrameUOCException Si no es pot emmagatzemar l'entrenament en la base de dades. 
	 */
	public void altaEntrenament(String file) throws MyFrameUOCException{
		Session session		= null;
		
		try{
			session = Session.getSession(file);
			session.insert(this);
		}
		finally{
			if (session != null){
				session.closeNoEx();
			}
		}
	}
	
	/**
	 * Elimina un entrenament de la base de dades.
	 * 
	 * @param file - Fitxer de configuraci de MyFrameUOC que s'utilitza.
	 * 
	 * @throws Exception Si no es pot eliminar l'entrenament de la base de dades. 
	 */
	@SuppressWarnings("unchecked")
	public void baixaEntrenament(String file) throws Exception{
		Session session					= null;
		DJugadors jugador				= null;
		ArrayList<Object> pk			= null;
		ArrayList<DEquips> equips		= null;
		DEquips dequips					= null;
		DEquips equip					= null;
		ArrayList<DJugadors> jugadors	= null;
		
		try{
			session = Session.getSession(file);
			
			dequips = new DEquips();
			equips = dequips.consultaLlistatEquips(file);
			if (equips != null && equips.size() > 0){
				for (DEquips eq: equips){
					eq.baixaEquip(file);
				}
			}
			
			jugadors = (ArrayList<DJugadors>) this.jugadors.clone();
			if (jugadors != null && jugadors.size() > 0){
				for (DJugadors jug: jugadors){
					this.treureJugador(file, jug.getDNI());
				}
			}
			
			session.delete(this);
			if (this.jugadors != null && this.jugadors.size() > 0){
				pk = new ArrayList<Object>();
				for (DJugadors jug: this.jugadors){
					pk.clear();
					pk.add(jug.getDNI());
					jugador = (DJugadors) session.read(DJugadors.class.getCanonicalName(), pk);
					if (jugador == null){
						jug.treureEntrenament(this.idEntrenament);
						session.insert(jug);
					}
					else{
						jugador.treureEntrenament(this.idEntrenament);
						session.update(jugador);
					}
				}
			}
			
			if (equips != null && equips.size() > 0){
				for (DEquips eq: equips){
					equip = dequips.consultaEquip(file, eq.getIdEquip());
					if (equip == null){
						eq.altaEquip(file);
					}
				}
			}
			
		}
		finally{
			if (session != null){
				session.closeNoEx();
			}
		}
	}
	
	/**
	 * Actualitza un entrenament en la base de dades.
	 * 
	 * @param file - Fitxer de configuraci de MyFrameUOC que s'utilitza.
	 * 
	 * @throws Exception Si no es pot actualitzar l'entrenament en la base de dades. 
	 */
	public void actualitzaEntrenament(String file) throws Exception{
		Session session				= null;
		DEntrenaments entrenament	= null;
		ArrayList<DEquips> equips	= null;
		DEquips dequips				= null;
		DEquips equip				= null;
		
		try{
			session = Session.getSession(file);
			dequips = new DEquips();
			equips = dequips.consultaLlistatEquips(file);
			if (equips != null && equips.size() > 0){
				for (DEquips eq: equips){
					eq.baixaEquip(file);
				}
			}
			entrenament = this.consultaEntrenament(file, this.idEntrenament);
			this.jugadors = entrenament.jugadors;
			session.update(this);
			
			if (equips != null && equips.size() > 0){
				for (DEquips eq: equips){
					equip = dequips.consultaEquip(file, eq.getIdEquip());
					if (equip == null){
						eq.altaEquip(file);
					}
				}
			}
		}
		finally{
			if (session != null){
				session.closeNoEx();
			}
		}
	}
	
	/**
	 * Permet obtenir una llista dels jugadors que no han seguit l'entrenament.
	 * 
	 * @param file - Fitxer de configuraci de MyFrameUOC que s'utilitza.
	 * 
	 * @return Un <code>ArrayList</code> que cont els jugadors que no han seguit l'entrenament.
	 * 
	 * @throws MyFrameUOCException Si no es pot obtenir la llista dels jugadors que no han seguit l'entrenament. 
	 */
	public ArrayList<DJugadors> consultaJugadorsSenseEntrenament(String file) throws MyFrameUOCException{
		ArrayList<DJugadors> jugadorsSenseEntrenament		= null;
		ArrayList<DJugadors> jugadors						= null;
		DJugadors djugadors									= null;
		
		djugadors = new DJugadors();
		jugadors = djugadors.consultaLlistatJugadors(file);
		if (jugadors != null && jugadors.size() > 0){
			jugadorsSenseEntrenament = new ArrayList<DJugadors>();
			for (DJugadors jug: jugadors){
				if (!this.conteJugador(jug)){
					jugadorsSenseEntrenament.add(jug);
				}
			}
		}
		return (jugadorsSenseEntrenament);
	}
	
	/*
	 * Permet conixer si un jugador ha seguit l'entrenament.
	 */
	private boolean conteJugador(DJugadors jugador){
		boolean trobat	= false;
		int elements;
		int i;
		
		if (this.jugadors != null && this.jugadors.size() > 0){
			elements = this.jugadors.size();
			i = 0;
			trobat = false;
			while (!trobat && i < elements){
				if (String.valueOf(this.jugadors.get(i).getDNI()).equals(String.valueOf(jugador.getDNI()))){
					trobat = true;
				}
				else{
					i++;
				}
			}
		}
		return (trobat);
	}
	
	/**
	 * Afegeix un jugador a l'entrenament
	 * 
	 * @param file - Fitxer de configuraci de MyFrameUOC que s'utilitza.
	 * @param DNI - DNI del jugador que es vol afegir a l'entrenament.
	 * 
	 * @throws Exception Si no es pot afegir el jugador a l'entrenament. 
	 */
	public void incloureJugador(String file, char[] DNI) throws Exception{
		DJugadors jugador			= null;
		Session session				= null;
		ArrayList<Object> pk		= null;
		ArrayList<DEquips> equips	= null;
		DEquips dequips				= null;
		DEquips equip				= null;
		
		try{
			session = Session.getSession(file);
			dequips = new DEquips();
			equips = dequips.consultaLlistatEquips(file);
			pk = new ArrayList<Object>();
			pk.add(DNI);
			jugador = (DJugadors) session.read(DJugadors.class.getCanonicalName(), pk);
			if (jugador != null){
				this.afegirJugador(jugador);
				if (equips != null && equips.size() > 0){
					for (DEquips eq: equips){
						eq.baixaEquip(file);
					}
				}
				session.update(this);
				if (equips != null && equips.size() > 0){
					for (DEquips eq: equips){
						equip = dequips.consultaEquip(file, eq.getIdEquip());
						if (equip == null){
							eq.altaEquip(file);
						}
					}
				}
			}
		}
		finally{
			if (session != null){
				session.closeNoEx();
			}
		}
	}
	
	/**
	 * Treu un jugador de l'entrenament.
	 * 
	 * @param file - Fitxer de configuraci de MyFrameUOC que s'utilitza.
	 * @param DNI - DNI del jugador que es vol treure de l'entrenament.
	 * 
	 * @throws Exception Si no es pot treure el jugador de l'entrenament.
	 */
	public void treureJugador(String file, char[] DNI) throws Exception{
		DJugadors jugador			= null;
		Session session				= null;
		ArrayList<DEquips> equips	= null;
		DEquips dequips				= null;
		DEquips equip				= null;
		DEntrenaments entrenament	= null;
		
		try{
			session = Session.getSession(file);
			
			dequips = new DEquips();
			equips = dequips.consultaLlistatEquips(file);
			
			jugador = this.treureJugador(DNI);
			
			if (equips != null && equips.size() > 0){
				for (DEquips eq: equips){
					eq.baixaEquip(file);
				}
			}

			jugador.treureEntrenament(this.idEntrenament);
			
			session.delete(this);
			session.delete(jugador);
			session.insert(jugador);
			entrenament = this.consultaEntrenament(file, this.idEntrenament);
			if (entrenament == null){
				session.insert(this);
			}

			if (equips != null && equips.size() > 0){
				for (DEquips eq: equips){
					equip = dequips.consultaEquip(file, eq.getIdEquip());
					if (equip == null){
						session.insert(eq);
					}
				}
			}
		}
		finally{
			if (session != null){
				session.closeNoEx();
			}
		}
	}
	
	/**
	 * Elimina la taula associada als entrenaments.
	 * 
	 * @param file - Fitxer de configuraci de MyFrameUOC que s'utilitza.
	 * 
	 * @throws MyFrameUOCException Si no es pot eliminar la taula dels entrenaments.
	 */
	public void drop(String file) throws MyFrameUOCException{
		Session session		= null;
		
		try{
			session = Session.getSession(file);
			session.drop(DEntrenaments.class.getCanonicalName());
		}
		finally{
			if (session != null){
				session.closeNoEx();
			}
		}
	}
}
