package com.uoc.footballteam.integration;

import java.math.BigDecimal;
import java.util.ArrayList;

import com.uoc.myframeuoc.annotations.*;
import com.uoc.myframeuoc.environment.Session;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;

/**
 * Classe que representa a un jugador de futbol.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
@Entity(Table = "Jugador")
public class DJugadors {
	@PrimaryKey(Name = "PK_Jugador", Field = "campDNI", Length = "9")
	private char[] DNI;
	
	@Column(Field = "campNom", Length = "40", Required = true)
	private String nom;
	
	@Column(Field = "campCognom1", Length = "40")
	private String cognom1;
	
	@Column(Field = "campCognom2", Length = "40")
	private String cognom2;
	
	@Column(Field = "campPais", Length = "100")
	private String pais;
	
	@Column(Field = "campDataNaix")
	private java.sql.Date dataNaixement;
	
	@Column(Field = "campEdat")
	private int edat;
	
	@Column(Field = "campDemarcacio", Length = "20")
	private String demarcacio;
	
	@Column(Field = "campSou", Precision = "15", Scale = "2")
	private BigDecimal sou;
	
	@ManyToMany(Table = "EntrenamentJugador", NameFK_To = "PK2_EntrenamentJugador", NameFK_From = "PK1_EntrenamentJugador", Fields_To = "entrenament-idEntrenament", Fields_From = "jugador-DNI")
	private ArrayList<DEntrenaments> entrenaments;

	
	//Getters i setters.	
	public char[] getDNI() {
		return DNI;
	}

	public void setDNI(char[] dni) {
		DNI = dni;
	}

	public String getNom() {
		return nom;
	}

	public void setNom(String nom) {
		this.nom = nom;
	}

	public String getCognom1() {
		return cognom1;
	}

	public void setCognom1(String cognom1) {
		this.cognom1 = cognom1;
	}

	public String getCognom2() {
		return cognom2;
	}

	public void setCognom2(String cognom2) {
		this.cognom2 = cognom2;
	}

	public String getPais() {
		return pais;
	}

	public void setPais(String pais) {
		this.pais = pais;
	}

	public java.sql.Date getDataNaixement() {
		return dataNaixement;
	}

	public void setDataNaixement(java.sql.Date dataNaixement) {
		this.dataNaixement = dataNaixement;
	}

	public int getEdat() {
		return edat;
	}

	public void setEdat(int edat) {
		this.edat = edat;
	}

	public String getDemarcacio() {
		return demarcacio;
	}

	public void setDemarcacio(String demarcacio) {
		this.demarcacio = demarcacio;
	}

	public BigDecimal getSou() {
		return sou;
	}

	public void setSou(BigDecimal sou) {
		this.sou = sou;
	}

	public ArrayList<DEntrenaments> getEntrenaments() {
		return entrenaments;
	}

	public void setEntrenaments(ArrayList<DEntrenaments> entrenaments) {
		this.entrenaments = entrenaments;
	}

	public void afegirEntrenament(DEntrenaments entrenament){
		if (this.entrenaments == null){
			this.entrenaments = new ArrayList<DEntrenaments>();
		}
		
		this.entrenaments.add(entrenament);
	}
	
	public void treureEntrenament(String idEntrenament){
		int elements;
		boolean trobat;
		int i;
		
		if (this.entrenaments != null && this.entrenaments.size() > 0){
			elements = this.entrenaments.size();
			trobat = false;
			i = 0;
			while (!trobat && i < elements){
				if (this.entrenaments.get(i).getIdEntrenament().equals(idEntrenament)){
					trobat = true;
				}
				else{
					i++;
				}
			}
			if (trobat){
				this.entrenaments.remove(i);
			}
		}
	}
	
	/**
	 * Constructor.
	 */
	public DJugadors(){
		
	}
	
	/**
	 * Constructor. 
	 * 
	 * @param DNI - Nmdeo de D.N.I. del jugador.
	 * @param nom - Nom del jugador.
	 * @param cognom1 - Prmier cognom del jugador.
	 * @param cognom2 - Segon cognom deljugador.
	 * @param pais - Pas denaixament del jugador.
	 * @param dataNaixement - Data de naixement del jugador.
	 * @param edat - Edat actual del jugador.
	 * @param demarcacio - Posici que ocupa el jugador en el camp.
	 * @param sou - Sou del jugador.
	 */
	public DJugadors(char[] DNI, String nom, String cognom1, String cognom2, String pais, java.sql.Date dataNaixement, 
			int edat, String demarcacio, BigDecimal sou){
		this.DNI = DNI;
		this.nom = nom;
		this.cognom1 = cognom1;
		this.cognom2 = cognom2;
		this.pais = pais;
		this.dataNaixement = dataNaixement;
		this.edat = edat;
		this.demarcacio = demarcacio;
		this.sou = sou;
	}	
	
	/**
	 * Emmagatzema un nou jugador en la base de dades.
	 * 
	 * @param file - Fitxer de configuraci de MyFrameUOC que s'utilitza.
	 * 
	 * @throws Exception Si no es pot emmagatzemar el jugador en la base de dades. 
	 */
	public void altaJugador(String file) throws Exception{
		Session session 	= null;
		
		try{
			session = Session.getSession(file);
			session.insert(this);
		}
		finally{
			if (session != null){
				session.closeNoEx();
			}
		}
	}
	
	/**
	 * Permet obtenir un jugador que estigui emmagatzemat en la base de dades.
	 * 
	 * @param file - Fitxer de configuraci de MyFrameUOC que s'utilitza.
	 * @param DNI - DNI del jugador que es vol recuperar de la base de dades.
	 * 
	 * @return Un <code>DJugadors</code> amb el jugador recuperat de la base de dades. Nul si 
	 * el jugador que es cerca no es troba emmagatzemat en la base de dades.
	 * 
	 * @throws Exception Si es produeix un error en la recuperaci del jugador de la base de dades. 
	 */
	public DJugadors consultaJugador(String file, char[] DNI) throws Exception{
		DJugadors jugador		= null;
		Session session			= null;
		ArrayList<Object> pk	= null;
		
		try{
			session = Session.getSession(file);
			pk = new ArrayList<Object>();
			pk.add(DNI);
			jugador = (DJugadors) session.read(DJugadors.class.getCanonicalName(), pk);
		}
		finally{
			if (session != null){
				session.closeNoEx();
			}
		}
		return (jugador);
	}
	
	/**
	 * Permet obtenir una llista de tots els jugadors que estan emmagatzemats en la base de dades.
	 * 
	 * @param file - Fitxer de configuraci de MyFrameUOC que s'utilitza.
	 * 
	 * @return Un <code>ArrayList</code> que cont tots els jugadors que estan emmagatzemats en
	 * la base de dades.
	 * 
	 * @throws MyFrameUOCException Si es produeix un error al recuperar els jugadors de la base de dades. 
	 */
	public ArrayList<DJugadors> consultaLlistatJugadors(String file) throws MyFrameUOCException{
		ArrayList<DJugadors> jugadors		= null;
		ArrayList<Object> llista			= null;
		Session session						= null;
		String queryUOCQL					= null;
		DJugadors jugador					= null;
		String nameEntity					= DJugadors.class.getCanonicalName();
		
		try{
			queryUOCQL = "FROM " + nameEntity + " WHERE DNI IS NOT NULL";
			session = Session.getSession(file);
			llista = session.executeUOCQL(queryUOCQL);
			if (llista != null && llista.size() > 0){
				jugadors = new ArrayList<DJugadors>();
				for (Object obj: llista){
					jugador = (DJugadors) obj;
					jugadors.add(jugador);
				}
			}
		}
		finally{
			if (session != null){
				session.closeNoEx();
			}
		}
		return (jugadors);
	}
	
	/**
	 * Elimina un jugador de la base de dades.
	 * 
	 * @param file - Fitxer de configuraci de MyFrameUOC que s'utilitza.
	 * 
	 * @throws Exception Si no es pot eliminar el jugador de la base de dades. 
	 */
	public void baixaJugador(String file) throws Exception{
		Session session		= null;
		
		try{
			session = Session.getSession(file);
			
			if (this.entrenaments != null && this.entrenaments.size() > 0){
				for (DEntrenaments entrenament: this.entrenaments){
					entrenament.treureJugador(file, this.DNI);
				}
				this.entrenaments = null;
			}
			
			session.delete(this);
		}
		finally{
			if (session != null){
				session.closeNoEx();
			}
		}
	}
	
	/**
	 * Actualitza un jugador en la base de dades.
	 * 
	 * @param file - Fitxer de configuraci de MyFrameUOC que s'utilitza.
	 * 
	 * @throws MyFrameUOCException Si no es pot actualitzar el jugador. 
	 */
	public void actualitzaJugador(String file) throws MyFrameUOCException{
		Session session 			= null;
		DJugadors jugador			= null;
		ArrayList<Object> pk		= null;
		DEquips dequips				= null;
		ArrayList<DEquips> equips	= null;
		
		try{
			session = Session.getSession(file);
			dequips = new DEquips();
			equips = dequips.consultaLlistatEquips(file);
			pk = new ArrayList<Object>();
			pk.add(this.DNI);
			jugador = (DJugadors) session.read(DJugadors.class.getCanonicalName(), pk);
			this.entrenaments = jugador.entrenaments;
			session.update(this);
			if (equips != null && equips.size() > 0){
				for (DEquips eq: equips){
					session.update(eq);
				}
			}
		}
		finally{
			if (session != null){
				session.closeNoEx();
			}
		}
	}
	
	/**
	 * Permet conixer si el jugador est incls en un entrenament.
	 * 
	 * @param idEntrenament - Identificador de l'entrenament.
	 * 
	 * @return <code>True</code> si el jugador est incls en l'entrenament. 
	 * <code>False</code> en qualsevol altre cas.
	 */
	public boolean conteEntrenament(String idEntrenament){
		boolean trobat		= false;
		int i;
		int numElements;
		
		if (idEntrenament != null){
			if (this.entrenaments != null){
				numElements = this.entrenaments.size();
				trobat = false;
				i = 0;
				while (!trobat && i < numElements){
					if (this.entrenaments.get(i).getIdEntrenament().equals(idEntrenament)){
						trobat = true;
					}
					else{
						i++;
					}
				}
			}
		}
		return (trobat);
	}
	
	/**
	 * Inicia un entrenament per a un jugador.
	 * 
	 * @param file - Fitxer de configuraci de MyFrameUOC que s'utilitza.
	 * @param idEntrenament - Identificador de l'entrenament que es vol iniciar per al jugador.
	 * 
	 * @throws Exception Si no es pot iniciar l'entrenament del jugador. 
	 */
	public void iniciarEntrenament(String file, String idEntrenament) throws Exception{
		DEntrenaments entrenament				= null;
			
		entrenament = new DEntrenaments();
		entrenament = entrenament.consultaEntrenament(file, idEntrenament);
		entrenament.incloureJugador(file, this.DNI);		
	}
	
	/**
	 * Finalitza un entrenament per a un jugador.
	 * 
	 * @param file - Fitxer de configuraci de MyFrameUOC que s'utilitza.
	 * @param idEntrenament - Identificador de l'entrenament que es vol finalitzar per al jugador.
	 * 
	 * @throws Exception Si no es pot finalitzar l'entrenament del jugador. 
	 */
	public void finalitzarEntrenament(String file, String idEntrenament) throws Exception{
		DEntrenaments entrenament				= null;
			
		entrenament = new DEntrenaments();
		entrenament = entrenament.consultaEntrenament(file, idEntrenament);
		entrenament.treureJugador(file, this.DNI);
	}
	
	/**
	 * Elimina la taula associada als jugadors
	 * 
	 * @param file - Fitxer de configuraci de MyFrameUOC que s'utilitza.
	 * 
	 * @throws MyFrameUOCException Si no es pot eliminar la taula dels jugadors. 
	 */
	public void drop(String file) throws MyFrameUOCException{
		Session session		= null;
		
		try{
			session = Session.getSession(file);
			session.drop(DJugadors.class.getCanonicalName());
		}
		finally{
			if (session != null){
				session.closeNoEx();
			}
		}
	}
}
