package com.uoc.footballteam.presentation;

import java.rmi.RemoteException;
import java.sql.Time;
import java.util.ArrayList;

import javax.ejb.CreateException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import com.uoc.footballteam.business.NEntrenaments;
import com.uoc.footballteam.integration.DEntrenaments;
import com.uoc.footballteam.integration.DJugadors;
import com.uoc.footballteam.util.FootballTeam;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;

/**
 * Servlet controlador del component <i>PEntrenaments</i> de la capa
 * de presentaci del sistema <i>FootballTeam</i>.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
public class EntrenamentsServlet implements Command {
	
	//Sessi del la connexi http.
	private HttpSession session;
	
	//Petici http del servlet.
	private HttpServletRequest req;
	
	//Missatge d'error.
	private String msgError		= null;
	
	//Dest de retorn.
	private String desti		= null;
	
	//Fitxer de configuraci de MyFrameUOC.
	private String file			= null;
	
	/**
	 * Constructor.
	 */
	public EntrenamentsServlet() {
	}

	@Override
	public String execute(HttpServlet servlet, HttpServletRequest req, HttpServletResponse resp) throws RemoteException, CreateException {
		String action 		= null;
		String nextPage 	= null;
		
		try{
			action = req.getParameter(FootballTeam.PARAM_ACTION);
			session = req.getSession(true);
			this.req = req;
			this.file = servlet.getServletContext().getRealPath(FootballTeam.MYFRAMEUOC_CONF);
			
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_ENTRENAMENTS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + EntrenamentsActions.LLISTA_ENTRENAMENTS.getAccio();
			
			this.msgError = null;
			
			
			if (EntrenamentsActions.LLISTA_ENTRENAMENTS.getAccio().equals(action)){
				nextPage = EntrenamentsActions.LLISTA_ENTRENAMENTS.getVista();
				this.consultarEntrenaments();
			}
			else if (EntrenamentsActions.ALTA_ENTRENAMENT_IN.getAccio().equals(action)){
				nextPage = EntrenamentsActions.ALTA_ENTRENAMENT_IN.getVista();
			}
			else if (EntrenamentsActions.ALTA_ENTRENAMENT_SAVE.getAccio().equals(action)){
				nextPage = EntrenamentsActions.ALTA_ENTRENAMENT_SAVE.getVista();
				this.session.setAttribute(FootballTeam.PARAM_MSG, FootballTeam.MSG_ENTRENAMENT_EMMAGATZEMAT);
				this.session.setAttribute(FootballTeam.PARAM_TARGET, this.desti);
				this.altaEntrenament();
			}
			else if (EntrenamentsActions.CONSULTA_ENTRENAMENT.getAccio().equals(action)){
				nextPage = EntrenamentsActions.CONSULTA_ENTRENAMENT.getVista();
				this.consultaEntrenament();
			}
			else if (EntrenamentsActions.BAIXA_ENTRENAMENT.getAccio().equals(action)){
				nextPage = EntrenamentsActions.BAIXA_ENTRENAMENT.getVista();
				this.session.setAttribute(FootballTeam.PARAM_MSG, FootballTeam.MSG_ENTRENAMENT_ESBORRAT);
				this.session.setAttribute(FootballTeam.PARAM_TARGET, this.desti);
				this.baixaEntrenament();
			}
			else if (EntrenamentsActions.ACTUALITZA_ENTRENAMENT_IN.getAccio().equals(action)){
				nextPage = EntrenamentsActions.ACTUALITZA_ENTRENAMENT_IN.getVista();
				this.actualitzaEntrenamentIn();
			}
			else if (EntrenamentsActions.ACTUALITZA_ENTRENAMENT_SAVE.getAccio().equals(action)){
				nextPage = EntrenamentsActions.ACTUALITZA_ENTRENAMENT_SAVE.getVista();
				this.session.setAttribute(FootballTeam.PARAM_MSG, FootballTeam.MSG_ENTRENAMENT_MOFIDICAT);
				this.session.setAttribute(FootballTeam.PARAM_TARGET, desti);
				this.actualitzaEntrenament();
				
			}
			else if (EntrenamentsActions.LLISTA_JUGADORSENTRENAMENT.getAccio().equals(action)){
				nextPage = EntrenamentsActions.LLISTA_JUGADORSENTRENAMENT.getVista();
				this.consultaJugadorsEntrenament();
			}
			else if (EntrenamentsActions.INCLOURE_JUGADOR.getAccio().equals(action)){
				nextPage = EntrenamentsActions.INCLOURE_JUGADOR.getVista();
				this.incloureJugador();
			}
			else if (EntrenamentsActions.TREURE_JUGADOR.getAccio().equals(action)){
				nextPage = EntrenamentsActions.TREURE_JUGADOR.getVista();
				this.treureJugador();
			}
			
			if (this.msgError != null){
				nextPage = FootballTeam.VISTA_ERROR;
				session.setAttribute(FootballTeam.PARAM_ERROR, this.msgError);
				session.setAttribute(FootballTeam.PARAM_TARGET, this.desti);
			}
		}
		catch (Exception e){
			e.printStackTrace();
			
			nextPage = FootballTeam.VISTA_ERROR;
			session.setAttribute(FootballTeam.PARAM_ERROR, this.msgError);
			session.setAttribute(FootballTeam.PARAM_TARGET, this.desti);
		}
		return (nextPage);
	}

	/*
	 * Crida a la lgica de negoci per a obtenir la llista d'entrenaments.
	 */
	private void consultarEntrenaments() throws Exception{
		ArrayList<DEntrenaments> entrenaments	= null;
		NEntrenaments nentrenaments				= null;
		
		try{
			nentrenaments = new NEntrenaments(this.file);
			entrenaments = nentrenaments.consultaLlistatEntrenaments();
			this.session.setAttribute(FootballTeam.PARAM_LLISTA_ENTRENAMENTS, entrenaments);
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_CONSULTAR_EQUIPS;
			this.desti = FootballTeam.VISTA_INDEX_ABS;
			throw e;
		}
	}
	
	/*
	 * Crida a la lgica de negoci per a emmagatzemar un entrenament en la base de dades.
	 */
	private void altaEntrenament() throws Exception{
		String idEntrenament			= null;
		String nom						= null;
		String descripcio				= null;
		String instruccions				= null;
		int sessions;
		Time durada						= null;
		String sDurada					= null;
		String value					= null;
		NEntrenaments nentrenaments		= null;
		DEntrenaments entrenament		= null;
		
		try{
			nentrenaments = new NEntrenaments(this.file);
			idEntrenament = this.req.getParameter(EntrenamentProperties.idEntrenament.name());
					
			entrenament = nentrenaments.consultaEntrenament(idEntrenament);

			if (entrenament == null){
				nom = this.req.getParameter(EntrenamentProperties.nom.name());
				descripcio = this.req.getParameter(EntrenamentProperties.descripcio.name());
				instruccions = this.req.getParameter(EntrenamentProperties.instruccions.name());
				value = this.req.getParameter(EntrenamentProperties.sessions.name());
				if (value != null && !"".equals(value)){
					sessions = Integer.parseInt(value);
				}
				else{
					sessions = 0;
				}
				value = this.req.getParameter(EntrenamentProperties.duradaHores.name());
				if (value != null && !"".equals(value)){
					sDurada = value + ":";
				}
				else{
					sDurada = "00:";
				}
				value = this.req.getParameter(EntrenamentProperties.duradaMinuts.name());
				if (value != null && !"".equals(value)){
					sDurada += value + ":";
				}
				else{
					sDurada += "00:";
				}
				sDurada += "00";
				durada = Time.valueOf(sDurada);
				
				nentrenaments.altaEntrenament(idEntrenament, nom, descripcio, instruccions, sessions, durada);
			}
			else{
				this.msgError = FootballTeam.MSG_ENTRENAMENT_EXISTEIX;
				this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_ENTRENAMENTS; 
				this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + EntrenamentsActions.ALTA_ENTRENAMENT_IN.getAccio();
			}
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_CREAR_ENTRENAMENT;
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_ENTRENAMENTS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + EntrenamentsActions.ALTA_ENTRENAMENT_IN.getAccio();
			throw e;
		}
	}
	
	/*
	 * Crida a la lgica de negoci per a obtenir un entrenament.
	 */
	private void consultaEntrenament() throws Exception{
		NEntrenaments nentrenaments		= null;
		DEntrenaments entrenament		= null;
		String idEntrenament			= null;
		
		try{
			nentrenaments = new NEntrenaments(this.file);
			idEntrenament = this.req.getParameter(FootballTeam.PARAM_ELEMENT);
			entrenament = nentrenaments.consultaEntrenament(idEntrenament);
			this.session.setAttribute(FootballTeam.PARAM_ENTRENAMENT, entrenament);
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_DETALL_ENTRENAMENT;
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_ENTRENAMENTS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + EntrenamentsActions.LLISTA_ENTRENAMENTS.getAccio();
			throw e;
		}
	}
	
	/*
	 * Crida a la lgica de negoci per a esborrar un entrenament.
	 */
	private void baixaEntrenament() throws Exception{
		NEntrenaments nentrenaments		= null;
		String idEntrenament			= null;
		
		try{
			idEntrenament = this.req.getParameter(FootballTeam.PARAM_ELEMENT);
			nentrenaments = new NEntrenaments(this.file);
			nentrenaments.baixaEntrenament(idEntrenament);
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_ESBORRAR_ENTRENAMENT;
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_ENTRENAMENTS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + EntrenamentsActions.LLISTA_ENTRENAMENTS.getAccio();
			throw e;
		}
	}
	
	/*
	 * Inclou en la sessi http del servlet l'entrenament que s'ha de modificar.
	 */
	private void actualitzaEntrenamentIn() throws MyFrameUOCException{
		NEntrenaments nentrenaments		= null;
		DEntrenaments entrenament		= null;
		String idEntrenament			= null;
		
		idEntrenament = this.req.getParameter(FootballTeam.PARAM_ELEMENT);
		nentrenaments = new NEntrenaments(this.file);
		entrenament = (DEntrenaments) nentrenaments.consultaEntrenament(idEntrenament);
		
		this.session.setAttribute(FootballTeam.PARAM_ENTRENAMENT, entrenament);
	}
	
	/*
	 * Crida a la lgica de negocia per actualitzar un entrenament.
	 */
	private void actualitzaEntrenament() throws Exception{
		NEntrenaments nentrenaments		= null;
		DEntrenaments entrenament		= null;
		String idEntrenament			= null;
		String nom						= null;
		String descripcio				= null;
		String instruccions				= null;
		int sessions;
		String duradaHores				= null;
		String duradaMinuts				= null;
		Time durada						= null;
		String value					= null;
		
		try{
			idEntrenament = this.req.getParameter(EntrenamentProperties.idEntrenament.name());
			nom = this.req.getParameter(EntrenamentProperties.nom.name());
			descripcio = this.req.getParameter(EntrenamentProperties.descripcio.name());
			instruccions = this.req.getParameter(EntrenamentProperties.instruccions.name());
			value = this.req.getParameter(EntrenamentProperties.sessions.name());
			if (value != null){
				sessions = Integer.valueOf(value);
			}
			else{
				sessions = 0;
			}
			
			duradaHores = this.req.getParameter(EntrenamentProperties.duradaHores.name());
			duradaMinuts = this.req.getParameter(EntrenamentProperties.duradaMinuts.name());
			if (duradaHores == null || "".equals(duradaHores)){
				duradaHores = "00";
			}
			if (duradaMinuts == null || "".equals(duradaMinuts)){
				duradaMinuts = "00";
			}
			value = duradaHores + ":" + duradaMinuts + ":" + "00";
			durada = Time.valueOf(value);
			
			entrenament = new DEntrenaments(idEntrenament, nom, descripcio, instruccions, sessions, durada);
			nentrenaments = new NEntrenaments(this.file);
			nentrenaments.actualitzaEntrenament(entrenament);
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_ACTUALITZAR_ENTRENAMENT;
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_ENTRENAMENTS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + EntrenamentsActions.ACTUALITZA_ENTRENAMENT_IN.getAccio();
			this.desti += "&" + FootballTeam.PARAM_ELEMENT + "=" + idEntrenament;
			throw e;
		}
	}
	
	/*
	 * Crida a la lgica de negoci per a obtenir els jugadors que han seguit un entrenament determinat.
	 */
	private void consultaJugadorsEntrenament() throws Exception{
		NEntrenaments nentrenaments						= null;
		DEntrenaments entrenament						= null;
		String idEntrenament							= null;
		ArrayList<DJugadors> jugadorsSenseEntrenament	= null;
		
		try{
			nentrenaments = new NEntrenaments(this.file);
			idEntrenament = this.req.getParameter(FootballTeam.PARAM_ELEMENT);
			entrenament = nentrenaments.consultaEntrenament(idEntrenament);
			jugadorsSenseEntrenament = nentrenaments.consultaJugadorsSenseEntrenament(entrenament);
			this.session.setAttribute(FootballTeam.PARAM_ENTRENAMENT, entrenament);
			this.session.setAttribute(FootballTeam.PARAM_LLISTA_JUGADORS, jugadorsSenseEntrenament);
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_ACTUALITZAR_ENTRENAMENT;
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_ENTRENAMENTS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + EntrenamentsActions.LLISTA_ENTRENAMENTS.getAccio();
			throw e;
		}
	}
	
	/*
	 * Crida a la lgica de negoci perqu s'inclogui el jugador en l'equip.
	 */
	private void incloureJugador() throws Exception{
		DEntrenaments entrenament						= null;
		char[] DNI										= null;
		NEntrenaments nentrenaments						= null;
		ArrayList<DJugadors> jugadorsSenseEntrenament	= null;
		
		try{
			entrenament = (DEntrenaments) this.session.getAttribute(FootballTeam.PARAM_ENTRENAMENT);
			if (entrenament != null){
				DNI = this.req.getParameter(FootballTeam.PARAM_JUGADOR).toCharArray();
				nentrenaments = new NEntrenaments(this.file);
				nentrenaments.incloureJugador(DNI, entrenament);
				entrenament = nentrenaments.consultaEntrenament(entrenament.getIdEntrenament());
				jugadorsSenseEntrenament = nentrenaments.consultaJugadorsSenseEntrenament(entrenament); 
				this.session.setAttribute(FootballTeam.PARAM_ENTRENAMENT, entrenament);
				this.session.setAttribute(FootballTeam.PARAM_LLISTA_JUGADORS, jugadorsSenseEntrenament);
			}
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_INCLOURE_JUGADORENT;
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_ENTRENAMENTS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + EntrenamentsActions.LLISTA_ENTRENAMENTS.getAccio();
			throw e;
		}
	}
	
	/*
	 * Crida a la lgica de negoci per treure un jugador de l'entrenament.
	 */
	private void treureJugador() throws Exception{
		DEntrenaments entrenament						= null;
		char[] DNI										= null;
		NEntrenaments nentrenaments						= null;
		ArrayList<DJugadors> jugadorsSenseEntrenament	= null;
		
		try{
			entrenament = (DEntrenaments) this.session.getAttribute(FootballTeam.PARAM_ENTRENAMENT);
			if (entrenament != null){
				DNI = this.req.getParameter(FootballTeam.PARAM_JUGADOR).toCharArray();
				nentrenaments = new NEntrenaments(this.file);
				nentrenaments.treureJugador(DNI, entrenament);
				entrenament = nentrenaments.consultaEntrenament(entrenament.getIdEntrenament());
				jugadorsSenseEntrenament = nentrenaments.consultaJugadorsSenseEntrenament(entrenament);
				this.session.setAttribute(FootballTeam.PARAM_ENTRENAMENT, entrenament);
				this.session.setAttribute(FootballTeam.PARAM_LLISTA_JUGADORS, jugadorsSenseEntrenament);
			}
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_TREURE_JUGADOREQ;
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_EQUIPS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + EquipsActions.LLISTA_EQUIPS.getAccio();
			throw e;
		}
	}
}
