package com.uoc.footballteam.presentation;

import java.math.BigDecimal;
import java.rmi.RemoteException;
import java.util.ArrayList;

import javax.ejb.CreateException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import com.uoc.footballteam.business.NEquips;
import com.uoc.footballteam.integration.DEquips;
import com.uoc.footballteam.integration.DJugadors;
import com.uoc.footballteam.util.FootballTeam;

/**
 * Servlet controlador del component <i>PEquips</i> de la capa
 * de presentaci del sistema <i>FootballTeam</i>.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
public class EquipsServlet implements Command {
	
	//Sessi del la connexi http.
	private HttpSession session;
	
	//Petici http del servlet.
	private HttpServletRequest req;
	
	//Missatge d'error.
	private String msgError		= null;
	
	//Dest de retorn.
	private String desti		= null;
	
	//Fitxer de configuraci de MyFrameUOC.
	private String file			= null;
	
	/**
	 * Constructor.
	 */
	public EquipsServlet() {
	}

	@Override
	public String execute(HttpServlet servlet, HttpServletRequest req, HttpServletResponse resp) throws RemoteException, CreateException {
		String action 		= null;
		String nextPage 	= null;
		
		try{
			action = req.getParameter(FootballTeam.PARAM_ACTION);
			session = req.getSession(true);
			this.req = req;
			this.file = servlet.getServletContext().getRealPath(FootballTeam.MYFRAMEUOC_CONF);
			
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_EQUIPS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + EquipsActions.LLISTA_EQUIPS.getAccio();
			
			this.msgError = null;
			
			
			if (EquipsActions.LLISTA_EQUIPS.getAccio().equals(action)){
				nextPage = EquipsActions.LLISTA_EQUIPS.getVista();
				this.consultarEquips();
			}
			else if (EquipsActions.ALTA_EQUIP_IN.getAccio().equals(action)){
				nextPage = EquipsActions.ALTA_EQUIP_IN.getVista();
			}
			else if (EquipsActions.ALTA_EQUIP_SAVE.getAccio().equals(action)){
				nextPage = EquipsActions.ALTA_EQUIP_SAVE.getVista();
				this.session.setAttribute(FootballTeam.PARAM_MSG, FootballTeam.MSG_EQUIP_EMMAGATZEMAT);
				this.session.setAttribute(FootballTeam.PARAM_TARGET, this.desti);
				
				this.altaEquip();
			}
			else if (EquipsActions.BAIXA_EQUIP.getAccio().equals(action)){
				nextPage = EquipsActions.BAIXA_EQUIP.getVista();
				this.session.setAttribute(FootballTeam.PARAM_MSG, FootballTeam.MSG_EQUIP_ESBORRAT);
				this.session.setAttribute(FootballTeam.PARAM_TARGET, this.desti);
				this.baixaEquip();
			}
			else if (EquipsActions.ACTUALITZA_EQUIP_IN.getAccio().equals(action)){
				nextPage = EquipsActions.ACTUALITZA_EQUIP_IN.getVista();
				this.actualitzaEquipIn();
			}
			else if (EquipsActions.ACTUALITZA_EQUIP_SAVE.getAccio().equals(action)){
				nextPage = EquipsActions.ACTUALITZA_EQUIP_SAVE.getVista();
				this.session.setAttribute(FootballTeam.PARAM_MSG, FootballTeam.MSG_EQUIP_MODIFICAT);
				this.session.setAttribute(FootballTeam.PARAM_TARGET, this.desti);
				this.actualitzaEquip();
			}
			else if (EquipsActions.LLISTA_JUGADORSEQUIP.getAccio().equals(action)){
				nextPage = EquipsActions.LLISTA_JUGADORSEQUIP.getVista();
				this.consultaJugadorsEquip();
			}
			else if (EquipsActions.INCLOURE_JUGADOR.getAccio().equals(action)){
				nextPage = EquipsActions.INCLOURE_JUGADOR.getVista();
				this.incloureJugador();
			}
			else if (EquipsActions.TREURE_JUGADOR.getAccio().equals(action)){
				nextPage = EquipsActions.TREURE_JUGADOR.getVista();
				this.treureJugador();
			}
			else if (EquipsActions.DADES_INICIALS.getAccio().equals(action)){
				nextPage = EquipsActions.DADES_INICIALS.getVista();
				this.session.setAttribute(FootballTeam.PARAM_MSG, FootballTeam.MSG_DADES_INICIALS_CARREGADES);
				this.session.setAttribute(FootballTeam.PARAM_TARGET, FootballTeam.VISTA_INDEX_ABS);
				this.dadesInicials();
			}
			
			if (this.msgError != null){
				nextPage = FootballTeam.VISTA_ERROR;
				session.setAttribute(FootballTeam.PARAM_ERROR, this.msgError);
				session.setAttribute(FootballTeam.PARAM_TARGET, this.desti);
			}
		}
		catch (Exception e){
			e.printStackTrace();
			
			nextPage = FootballTeam.VISTA_ERROR;
			session.setAttribute(FootballTeam.PARAM_ERROR, this.msgError);
			session.setAttribute(FootballTeam.PARAM_TARGET, this.desti);
		}
		return (nextPage);
	}

	/*
	 * Crida a la lgica de negoci per a emmagatzemar un equip en la base de dades.
	 */
	private void altaEquip() throws Exception{
		int idEquip;
		String nom					= null;
		String estadi				= null;
		String pressupostSencer		= null;
		String pressupostDecimal	= null;
		String value				= null;
		BigDecimal pressupost		= null;
		NEquips nequips				= null;
		DEquips equip				= null;
		
		try{
			nequips = new NEquips(this.file);
			idEquip = Integer.valueOf(this.req.getParameter(EquipProperties.idEquip.name()));

			equip = nequips.consultaEquip(idEquip);

			if (equip == null){
				nom = this.req.getParameter(EquipProperties.nom.name());
				estadi = this.req.getParameter(EquipProperties.estadi.name());
				pressupostSencer = this.req.getParameter(EquipProperties.pressupostSencer.name());
				if (pressupostSencer == null || "".equals(pressupostSencer)){
					pressupostSencer = "0";
				}
				pressupostDecimal = this.req.getParameter(EquipProperties.pressupostDecimal.name());
				if (pressupostDecimal == null || "".equals(pressupostDecimal)){
					pressupostDecimal = "0";
				}
				value = pressupostSencer + "." + pressupostDecimal;
				pressupost = new BigDecimal(value);

				nequips.altaEquip(idEquip, nom, estadi, pressupost);
			}
			else{
				this.msgError = FootballTeam.MSG_ERROR_EQUIP_EXISTEIX;
				this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_EQUIPS; 
				this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + EquipsActions.ALTA_EQUIP_IN.getAccio();
			}
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_CREAR_EQUIP;
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_EQUIPS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + EquipsActions.ALTA_EQUIP_IN.getAccio();
			throw e;
		}
	}
	
	/*
	 * Crida a la lgica de negoci per a obtenir el llistat d'equips.
	 */
	private void consultarEquips() throws Exception{
		ArrayList<DEquips> equips		= null;
		NEquips nequips					= null;
		
		try{
			nequips = new NEquips(this.file);
			equips = nequips.consultaLlistatEquips();
			this.session.setAttribute(FootballTeam.PARAM_LLISTA_EQUIPS, equips);
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_CONSULTAR_EQUIPS;
			this.desti = FootballTeam.VISTA_INDEX_ABS;
			throw e;
		}
	}
	
	/*
	 * Crida a la lgica de negoci per a esborrar un equip de la base de dades.
	 */
	@SuppressWarnings("unchecked")
	private void baixaEquip() throws Exception{
		NEquips nequips					= null;
		ArrayList<DEquips> equips		= null;
		String element;
		DEquips equip					= null;
		
		try{
			nequips = new NEquips(this.file);
			equips = (ArrayList<DEquips>) this.session.getAttribute(FootballTeam.PARAM_LLISTA_EQUIPS);
			element = this.req.getParameter(FootballTeam.PARAM_ELEMENT);
			
			if (equips != null && equips.size() > 0){
				equip = equips.get(Integer.valueOf(element));
				nequips.baixaEquip(equip);
			}
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_ESBORRAR_EQUIP;
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_EQUIPS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + EquipsActions.LLISTA_EQUIPS.getAccio();
			throw e;
		}
	}
	
	/*
	 * Inclou en la sessi http del servlet l'equip que s'ha de modificar.
	 */
	@SuppressWarnings("unchecked")
	private void actualitzaEquipIn(){
		DEquips equip				= null;
		ArrayList<DEquips> equips	= null;
		String element;
		
		equips = (ArrayList<DEquips>) this.session.getAttribute(FootballTeam.PARAM_LLISTA_EQUIPS);
		element = this.req.getParameter(FootballTeam.PARAM_ELEMENT);
		if (equips != null && equips.size() > 0){
			equip = equips.get(Integer.valueOf(element));
		}
		this.session.setAttribute(FootballTeam.PARAM_EQUIP, equip);
		this.session.setAttribute(FootballTeam.PARAM_ELEMENT, element);
	}
	
	/*
	 * Crida a la lgica de negoci per actualitzar un equip.
	 */
	private void actualitzaEquip() throws Exception{
		int idEquip					= -1;
		String nom					= null;
		String estadi				= null;
		BigDecimal pressupost		= null;
		String pressupostSencer		= null;
		String pressupostDecimal	= null;
		NEquips nequips				= null;
		String value				= null;
		DEquips equip				= null;
		DEquips equipOrig			= null;
		
		try{
			nequips = new NEquips(this.file);
			
			value = this.req.getParameter(EquipProperties.idEquip.name()); 
			if ( value != null){
				idEquip = Integer.valueOf(value);
			}
			
			equipOrig = (DEquips) nequips.consultaEquip(idEquip);
			
			nom = this.req.getParameter(EquipProperties.nom.name());
			estadi = this.req.getParameter(EquipProperties.estadi.name());
			
			pressupostSencer = this.req.getParameter(EquipProperties.pressupostSencer.name());
			if (pressupostSencer == null || "".equals(pressupostSencer)){
				pressupostSencer = "0";
			}
			pressupostDecimal = this.req.getParameter(EquipProperties.pressupostDecimal.name());
			if (pressupostDecimal == null || "".equals(pressupostDecimal)){
				pressupostDecimal = "0";
			}
			value = pressupostSencer + "." + pressupostDecimal;
			pressupost = new BigDecimal(value);

			equip = new DEquips(idEquip, nom, estadi, pressupost);
			equip.setJugadors(equipOrig.getJugadors());
			
			nequips.actualitzaEquip(equip);

		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_ACTUALITZAR_EQUIP;
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_EQUIPS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + EquipsActions.ACTUALITZA_EQUIP_IN.getAccio();
			this.desti += "&" + FootballTeam.PARAM_ELEMENT + "=" + this.session.getAttribute(FootballTeam.PARAM_ELEMENT);
			throw e;
		}
	}
	
	/*
	 * Crida a la lgica de negoci per a obtenir els jugadors d'un equip.
	 */
	private void consultaJugadorsEquip() throws Exception{
		DEquips equip							= null;
		NEquips nequips							= null;
		int idEquip;
		ArrayList<DJugadors> jugadorsSenseEquip	= null;
		
		try{
			nequips = new NEquips(this.file);
			idEquip = Integer.valueOf(this.req.getParameter(FootballTeam.PARAM_ELEMENT));
			equip = nequips.consultaEquip(idEquip);
			jugadorsSenseEquip = nequips.consultaJugadorsSenseEquip();
			
			this.session.setAttribute(FootballTeam.PARAM_EQUIP, equip);
			this.session.setAttribute(FootballTeam.PARAM_LLISTA_JUGADORS, jugadorsSenseEquip);
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_CONSULTA_JUGADORSEQ;
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_EQUIPS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + EquipsActions.LLISTA_EQUIPS.getAccio();
			throw e;
		}	
	}
	
	/*
	 * Crida a la lgica de negoci perqu s'inclogui el jugador en l'equip.
	 */
	private void incloureJugador() throws Exception{
		DEquips equip								= null;
		char[] DNI									= null;
		NEquips nequips								= null;
		ArrayList<DJugadors> jugadorsSenseEquip		= null;
		
		try{
			equip = (DEquips) this.session.getAttribute(FootballTeam.PARAM_EQUIP);
			if (equip != null){
				DNI = this.req.getParameter(FootballTeam.PARAM_JUGADOR).toCharArray();
				nequips = new NEquips(this.file);
				nequips.incloureJugador(DNI, equip);
				jugadorsSenseEquip = nequips.consultaJugadorsSenseEquip();
				this.session.setAttribute(FootballTeam.PARAM_EQUIP, equip);
				this.session.setAttribute(FootballTeam.PARAM_LLISTA_JUGADORS, jugadorsSenseEquip);
			}
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_INCLOURE_JUGADOREQ;
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_EQUIPS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + EquipsActions.LLISTA_EQUIPS.getAccio();
			throw e;
		}
	}
	
	/*
	 * Crida a la lgica de negoci per treure un jugador d'un equip.
	 */
	private void treureJugador() throws Exception{
		DEquips equip								= null;
		char[] DNI									= null;
		NEquips nequips								= null;
		ArrayList<DJugadors> jugadorsSenseEquip		= null;
		
		try{
			equip = (DEquips) this.session.getAttribute(FootballTeam.PARAM_EQUIP);
			if (equip != null){
				DNI = this.req.getParameter(FootballTeam.PARAM_JUGADOR).toCharArray();
				nequips = new NEquips(this.file);
				nequips.treureJugador(DNI, equip);
				jugadorsSenseEquip = equip.consultaJugadorsSenseEquip(this.file);
				this.session.setAttribute(FootballTeam.PARAM_EQUIP, equip);
				this.session.setAttribute(FootballTeam.PARAM_LLISTA_JUGADORS, jugadorsSenseEquip);
			}
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_TREURE_JUGADOREQ;
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_ENTRENAMENTS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + EntrenamentsActions.LLISTA_ENTRENAMENTS.getAccio();
			throw e;
		}
	}
	
	/*
	 * Emmagatzema en la base de dades unes dades inicials de demostraci.
	 */
	private void dadesInicials() throws Exception{
		NEquips nequips		= null;
		
		try{
			nequips = new NEquips(this.file);
			nequips.carregarDadesInicials();
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_DADES_INICIALS;
			this.desti = FootballTeam.VISTA_INDEX_ABS;
			throw e;
		}
	}
}
