package com.uoc.footballteam.presentation;

import java.util.*;
import com.uoc.footballteam.util.FootballTeam;

/**
 * Calsse que implementa el patr Factory de Commands.
 *
 */
public class Factory {
	//Objecte factoria.
	private static Factory factory;
	
	//Llista de 'commands'.
	Hashtable <String, Command> commands;
	
	/**
	 * Constructor,
	 */
	public Factory(){
		commands = new Hashtable <String, Command>();
	}
	
	/**
	 * Permet obtenir una instncia de la classe <i>Factory</i>.
	 * 
	 * @return Una instncia de la classe <i>Factory</i>.
	 */
	public static Factory getReference()
	{
		if (factory == null)
		{
			factory = new Factory();
		}
		return factory;
	}
	
	/**
	 * Permet obtenir una instncia d'una de les
	 * implementacions de la interfcie {@link com.uoc.footballteam.presentation.Command Command}
	 * 
	 * @param param - Nom de la implementaci concreta de la
	 * interfcie {@link com.uoc.footballteam.presentation.Command Command}.
	 * 
	 * @return Una instncia de la implementaci de la
	 * interfcie {@link com.uoc.footballteam.presentation.Command Command}
	 */
	public Command getCommand(String param)
	{
		Command cmd = commands.get(param);
		if (cmd == null)
		{
			cmd = getInstance(param);
			commands.put(param,cmd);
		}
		else
		{
			System.out.println("To go in hashtable with " + param);
		}
		return cmd;
	}
	
	/**
	 * Aquest mtode es qui realment crea una instcia 
	 * d'una implementaci de la interfcie {@link com.uoc.footballteam.presentation.Command Command}
	 * 
	 * @param param - Nom de la implementaci de la interfcie 
	 * {@link com.uoc.footballteam.presentation.Command Command}
	 * 
	 * @return Una instncia d'una implementaci de la
	 * interfcie {@link com.uoc.footballteam.presentation.Command Command}.
	 */
	private Command getInstance(String param){
		String nameClass 	= FootballTeam.DIR_COMMANDFACTORY + param;
		Command cmd 		= null;
		Class<?> c;
		
		try{
			c = Class.forName(nameClass);
			cmd = (Command) c.newInstance();
		}
		catch (Exception e){
			e.printStackTrace();
		}
		return cmd;
	}
}
