package com.uoc.footballteam.presentation;

import java.math.BigDecimal;
import java.rmi.RemoteException;
import java.util.ArrayList;
import java.util.GregorianCalendar;

import javax.ejb.CreateException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import com.uoc.footballteam.business.NEntrenaments;
import com.uoc.footballteam.business.NJugadors;
import com.uoc.footballteam.integration.DEntrenaments;
import com.uoc.footballteam.integration.DJugadors;
import com.uoc.footballteam.util.FootballTeam;

/**
 * Servlet controlador del component <i>PJugadors</i> de la 
 * capa de presentaci del sistema <i>FootballTeam</i>.
 * 
 * @author Jordi Garcia Casanova
 *
 */
public class JugadorsServlet implements Command{
	//Sessi del la connexi http.
	private HttpSession session;
	
	//Petici http del servlet.
	private HttpServletRequest req;
	
	//Missatge d'error.
	private String msgError		= null;
	
	//Dest de retorn.
	private String desti		= null;
	
	//Fitxer de configuraci de MyFrameUOC.
	private String file			= null;
	
	@Override
	public String execute(HttpServlet servlet, HttpServletRequest req,
			HttpServletResponse resp) throws RemoteException, CreateException {

		String action 		= null;
		String nextPage 	= null;
		
		try{
			action = req.getParameter(FootballTeam.PARAM_ACTION);
			session = req.getSession(true);
			this.req = req;
			this.file = servlet.getServletContext().getRealPath(FootballTeam.MYFRAMEUOC_CONF);
			
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_JUGADORS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + JugadorsActions.LLISTA_JUGADORS.getAccio();
			
			this.msgError = null;
			
			if (JugadorsActions.LLISTA_JUGADORS.getAccio().equals(action)){
				nextPage = JugadorsActions.LLISTA_JUGADORS.getVista();
				this.consultarJugadors();
			}
			else if (JugadorsActions.ALTA_JUGADOR_IN.getAccio().equals(action)){
				nextPage = JugadorsActions.ALTA_JUGADOR_IN.getVista();
			}
			else if (JugadorsActions.ALTA_JUGADOR_SAVE.getAccio().equals(action)){
				nextPage = JugadorsActions.ALTA_JUGADOR_SAVE.getVista();
				this.session.setAttribute(FootballTeam.PARAM_MSG, FootballTeam.MSG_JUGADOR_EMMAGATZEMAT);
				this.session.setAttribute(FootballTeam.PARAM_TARGET, this.desti);
				this.altaJugador();
			}
			else if (JugadorsActions.BAIXA_JUGADOR.getAccio().equals(action)){
				nextPage = JugadorsActions.BAIXA_JUGADOR.getVista();
				this.session.setAttribute(FootballTeam.PARAM_MSG, FootballTeam.MSG_JUGADOR_ESBORRAT);
				this.session.setAttribute(FootballTeam.PARAM_TARGET, this.desti);
				this.baixaJugador();
			}
			else if (JugadorsActions.ACTUALITZA_JUGADOR_IN.getAccio().equals(action)){
				nextPage = JugadorsActions.ACTUALITZA_JUGADOR_IN.getVista();
				this.actualitzaJugadorIn();
			}
			else if (JugadorsActions.ACTUALITZA_JUGADOR_SAVE.getAccio().equals(action)){
				nextPage = JugadorsActions.ACTUALITZA_JUGADOR_SAVE.getVista();
				this.session.setAttribute(FootballTeam.PARAM_MSG, FootballTeam.MSG_JUGADOR_MODIFICAT);
				this.session.setAttribute(FootballTeam.PARAM_TARGET, this.desti);
				this.actualitzaJugador();
			}
			else if (JugadorsActions.LLISTA_ENTRENAMENTSJUGADOR.getAccio().equals(action)){
				nextPage = JugadorsActions.LLISTA_ENTRENAMENTSJUGADOR.getVista();
				this.consultaEntrenamentsJugador();
			}
			else if (JugadorsActions.INICIA_ENTRENAMENT.getAccio().equals(action)){
				nextPage = JugadorsActions.INICIA_ENTRENAMENT.getVista();
				this.iniciaEntrenament();
			}
			else if (JugadorsActions.FINALITZA_ENTRENAMENT.getAccio().equals(action)){
				nextPage = JugadorsActions.FINALITZA_ENTRENAMENT.getVista();
				this.finalitzaEntrenament();
			}

			if (this.msgError != null){
				nextPage = FootballTeam.VISTA_ERROR;
				session.setAttribute(FootballTeam.PARAM_ERROR, this.msgError);
				session.setAttribute(FootballTeam.PARAM_TARGET, this.desti);
			}
		}
		catch (Exception e){
			e.printStackTrace();
			
			nextPage = FootballTeam.VISTA_ERROR;
			session.setAttribute(FootballTeam.PARAM_ERROR, this.msgError);
			session.setAttribute(FootballTeam.PARAM_TARGET, this.desti);
		}
		return (nextPage);	
	}

	/*
	 * Crida a la lgica de negoci perqu s'emmagatzemi un nou jugador en la base de dades. 
	 */
	private void altaJugador() throws Exception{
		char[] DNI				= null;
		String sDNI				= null;
		String DNINumero		= null;
		String DNILletra		= null;
		String nom				= null;
		String cognom1			= null;
		String cognom2			= null;
		String pais				= null;
		java.sql.Date dataNaix	= null;
		Integer diaNaix			= null;
		Integer mesNaix			= null;
		Integer anyNaix			= null;
		int edat;
		String demarcacio		= null;
		BigDecimal sou			= null;
		String souSencer		= null;
		String souDecimal		= null;
		NJugadors njugadors		= null;
		String value			= null;
		GregorianCalendar gc	= null;
		DJugadors jugador		= null;
	
		
		try{
			njugadors = new NJugadors(this.file);

			DNINumero = this.req.getParameter(JugadorProperties.DNINumero.name());
			DNILletra = this.req.getParameter(JugadorProperties.DNILletra.name());
			sDNI = DNINumero + DNILletra;
			DNI = sDNI.toCharArray();
			jugador = njugadors.consultaJugador(DNI);

			if (jugador == null){
				nom = this.req.getParameter(JugadorProperties.nom.name());
				cognom1 = this.req.getParameter(JugadorProperties.cognom1.name());
				cognom2 = this.req.getParameter(JugadorProperties.cognom2.name());
				pais = this.req.getParameter(JugadorProperties.pais.name());

				value = this.req.getParameter(JugadorProperties.diaNaix.name());
				if (value != null && !"".equals(value)){
					diaNaix = Integer.valueOf(value);
				}

				value = this.req.getParameter(JugadorProperties.mesNaix.name());
				if (value != null && !"".equals(value)){
					mesNaix = Integer.valueOf(value);
				}

				value = this.req.getParameter(JugadorProperties.anyNaix.name());
				if (value != null && !"".equals(value)){
					anyNaix = Integer.valueOf(value);
				}

				if (diaNaix != null && mesNaix != null && anyNaix != null){
					gc = new GregorianCalendar(anyNaix, mesNaix - 1, diaNaix);
					dataNaix = new java.sql.Date(gc.getTime().getTime());
				}
				else{
					dataNaix = null;
				}

				value = this.req.getParameter(JugadorProperties.edat.name());
				if (value != null && !"".equals(value)){
					edat = Integer.valueOf(value);
				}
				else{
					edat = 0;
				}
				demarcacio = this.req.getParameter(JugadorProperties.demarcacio.name());
				souSencer = this.req.getParameter(JugadorProperties.souSencer.name());
				if (souSencer == null || "".equals(souSencer)){
					souSencer = "0";
				}
				souDecimal = this.req.getParameter(JugadorProperties.souDecimal.name());
				if (souDecimal == null || "".equals(souDecimal)){
					souDecimal = "0";
				}
				value = souSencer + "." + souDecimal;
				sou = new BigDecimal(value);

				njugadors.altaJugador(DNI, nom, cognom1, cognom2, pais, dataNaix, edat, demarcacio, sou);
			}
			else{
				this.msgError = FootballTeam.MSG_ERROR_JUGADOR_EXISTEIX;
				this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_JUGADORS; 
				this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + JugadorsActions.ALTA_JUGADOR_IN.getAccio();
			}
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_CREAR_JUGADOR;
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_JUGADORS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + JugadorsActions.ALTA_JUGADOR_IN.getAccio();
			throw e;
		}
	}
	
	/*
	 * Crida a la lgica de negoci per a obtenir la llista de tots els 
	 * jugadors emmagatzemats en la base de dades.
	 */
	private void consultarJugadors() throws Exception{
		ArrayList<DJugadors> jugadors		= null;
		NJugadors njugadors					= null;
		
		try{
			njugadors = new NJugadors(this.file);
			jugadors = njugadors.consultaLlistatJugadors();
			this.session.setAttribute(FootballTeam.PARAM_LLISTA_JUGADORS, jugadors);
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_CONSULTAR_JUGADORS;
			this.desti = FootballTeam.VISTA_INDEX_ABS;
			throw e;
		}
	}
	
	/*
	 * Crida a la lgica de negoci per a esborrar un jugador de la base de dades.
	 */
	@SuppressWarnings("unchecked")
	private void baixaJugador() throws Exception{
		NJugadors njugadors					= null;
		ArrayList<DJugadors> jugadors		= null;
		String element;
		DJugadors jugador					= null;
		
		try{
			
			njugadors = new NJugadors(this.file);
			jugadors = (ArrayList<DJugadors>) this.session.getAttribute(FootballTeam.PARAM_LLISTA_JUGADORS);
			element = this.req.getParameter(FootballTeam.PARAM_ELEMENT);
			
			if (jugadors != null && jugadors.size() > 0){
				jugador = jugadors.get(Integer.valueOf(element));
				njugadors.baixaJugador(jugador);
			}
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_BAIXA_JUGADOR;
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_JUGADORS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + JugadorsActions.LLISTA_JUGADORS.getAccio();
			throw e;
		}
	}
	
	/*
	 * Inclou en la sessi http del servlet el jugador que s'ha de modificar.
	 */
	@SuppressWarnings("unchecked")
	private void actualitzaJugadorIn(){
		DJugadors jugador				= null;
		ArrayList<DJugadors> jugadors	= null;
		String element;
		
		jugadors = (ArrayList<DJugadors>) this.session.getAttribute(FootballTeam.PARAM_LLISTA_JUGADORS);
		element = this.req.getParameter(FootballTeam.PARAM_ELEMENT);
		if (jugadors != null && jugadors.size() > 0){
			jugador = jugadors.get(Integer.valueOf(element));
		}
		this.session.setAttribute(FootballTeam.PARAM_JUGADOR, jugador);
		this.session.setAttribute(FootballTeam.PARAM_ELEMENT, element);
	}
	
	/*
	 * Crida a la lgica de negoci per actualitzar un jugador.
	 */
	private void actualitzaJugador() throws Exception{
		char[] DNI				= null;
		String sDNI				= null;
		String DNINumero		= null;
		String DNILletra		= null;
		String nom				= null;
		String cognom1			= null;
		String cognom2			= null;
		String pais				= null;
		java.sql.Date dataNaix	= null;
		Integer diaNaix			= null;
		Integer mesNaix			= null;
		Integer anyNaix			= null;
		int edat;
		String demarcacio		= null;
		BigDecimal sou			= null;
		String souSencer		= null;
		String souDecimal		= null;
		NJugadors njugadors		= null;
		String value			= null;
		GregorianCalendar gc	= null;
		DJugadors jugador		= null;
		
		try{
			njugadors = new NJugadors(this.file);

			DNINumero = this.req.getParameter(JugadorProperties.DNINumero.name());
			DNILletra = this.req.getParameter(JugadorProperties.DNILletra.name());
			sDNI = DNINumero + DNILletra;
			DNI = sDNI.toCharArray();

			nom = this.req.getParameter(JugadorProperties.nom.name());
			cognom1 = this.req.getParameter(JugadorProperties.cognom1.name());
			cognom2 = this.req.getParameter(JugadorProperties.cognom2.name());
			
			pais = this.req.getParameter(JugadorProperties.pais.name());

			value = this.req.getParameter(JugadorProperties.diaNaix.name());
			if (value != null && !"".equals(value)){
				diaNaix = Integer.valueOf(value);
			}

			value = this.req.getParameter(JugadorProperties.mesNaix.name());
			if (value != null && !"".equals(value)){
				mesNaix = Integer.valueOf(value);
			}

			value = this.req.getParameter(JugadorProperties.anyNaix.name());
			if (value != null && !"".equals(value)){
				anyNaix = Integer.valueOf(value);
			}

			if (diaNaix != null && mesNaix != null && anyNaix != null){
				gc = new GregorianCalendar(anyNaix, mesNaix - 1, diaNaix);
				dataNaix = new java.sql.Date(gc.getTime().getTime());
			}
			else{
				dataNaix = null;
			}

			value = this.req.getParameter(JugadorProperties.edat.name());
			if (value != null && !"".equals(value)){
				edat = Integer.valueOf(value);
			}
			else{
				edat = 0;
			}
			demarcacio = this.req.getParameter(JugadorProperties.demarcacio.name());
			souSencer = this.req.getParameter(JugadorProperties.souSencer.name());
			if (souSencer == null || "".equals(souSencer)){
				souSencer = "0";
			}
			souDecimal = this.req.getParameter(JugadorProperties.souDecimal.name());
			if (souDecimal == null || "".equals(souDecimal)){
				souDecimal = "0";
			}
			value = souSencer + "." + souDecimal;
			sou = new BigDecimal(value);

			jugador = new DJugadors(DNI, nom, cognom1, cognom2, pais, dataNaix, edat, demarcacio, sou);
			njugadors.actualitzaJugador(jugador);

		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_ACTUALITZAR_JUGADOR;
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_JUGADORS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + JugadorsActions.ACTUALITZA_JUGADOR_IN.getAccio();
			this.desti += "&" + FootballTeam.PARAM_ELEMENT + "=" + this.session.getAttribute(FootballTeam.PARAM_ELEMENT);
			throw e;
		}
	}
	
	/*
	 * Inclou en la sessi http del servlet el jugador i una llista d'entrenaments en els quals no est inlcs el jugador.
	 */
	private void consultaEntrenamentsJugador() throws Exception{
		DJugadors jugador								= null;
		NJugadors njugadors								= null;
		ArrayList<DEntrenaments> entrenaments			= null;
		NEntrenaments nentrenaments						= null;
		String DNI										= null;
		
		try{
			DNI = this.req.getParameter(FootballTeam.PARAM_ELEMENT);
			njugadors = new NJugadors(this.file);
			jugador = njugadors.consultaJugador(DNI.toCharArray());
			this.session.setAttribute(FootballTeam.PARAM_JUGADOR, jugador);
			
			nentrenaments = new NEntrenaments(this.file);
			entrenaments = nentrenaments.consultaLlistatEntrenamentsNoJugador(jugador);
			
			this.session.setAttribute(FootballTeam.PARAM_LLISTA_ENTRENAMENTS, entrenaments);
			
			
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_ENTRENAMENTS_JUGADOR;
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_JUGADORS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + JugadorsActions.LLISTA_JUGADORS.getAccio();
			throw e;
		}
	}
	
	/*
	 * Crida a la lgica de negoci per a iniciar un entrenament del jugador.
	 */
	private void iniciaEntrenament() throws Exception{
		String idEntrenament					= null;
		NJugadors njugadors						= null;
		DJugadors jugador						= null;
		ArrayList<DEntrenaments> entrenaments	= null;
		NEntrenaments nentrenaments				= null;
		
		try{
			idEntrenament = this.req.getParameter(FootballTeam.PARAM_ELEMENT);
			jugador = (DJugadors) this.session.getAttribute(FootballTeam.PARAM_JUGADOR);
			njugadors = new NJugadors(this.file);
			njugadors.iniciarEntrenament(jugador, idEntrenament);
			jugador = njugadors.consultaJugador(jugador.getDNI());
			nentrenaments = new NEntrenaments(this.file);
			entrenaments = nentrenaments.consultaLlistatEntrenamentsNoJugador(jugador);
			this.session.setAttribute(FootballTeam.PARAM_JUGADOR, jugador);
			this.session.setAttribute(FootballTeam.PARAM_LLISTA_ENTRENAMENTS, entrenaments);
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_INICIAR_ENT;
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_JUGADORS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + JugadorsActions.LLISTA_JUGADORS.getAccio();
			throw e;
		}
	}
	
	/*
	 * Crida a la lgica de negoci per a finalitzar un entrenament del jugador.
	 */
	private void finalitzaEntrenament() throws Exception{
		String idEntrenament					= null;
		NJugadors njugadors						= null;
		DJugadors jugador						= null;
		ArrayList<DEntrenaments> entrenaments	= null;
		NEntrenaments nentrenaments				= null;
		
		try{
			idEntrenament = this.req.getParameter(FootballTeam.PARAM_ELEMENT);
			jugador = (DJugadors) this.session.getAttribute(FootballTeam.PARAM_JUGADOR);
			njugadors = new NJugadors(this.file);
			njugadors.finalitzarEntrenament(jugador, idEntrenament);
			jugador = njugadors.consultaJugador(jugador.getDNI());
			nentrenaments = new NEntrenaments(this.file);
			entrenaments = nentrenaments.consultaLlistatEntrenamentsNoJugador(jugador);
			this.session.setAttribute(FootballTeam.PARAM_JUGADOR, jugador);
			this.session.setAttribute(FootballTeam.PARAM_LLISTA_ENTRENAMENTS, entrenaments);
		}
		catch (Exception e){
			this.msgError = FootballTeam.MSG_ERROR_FINALITZAR_ENT;
			this.desti = FootballTeam.SERVLET_FRONT_CONTROLLER +"?" + FootballTeam.PARAM_COMMAND + "=" + FootballTeam.SERVLET_JUGADORS; 
			this.desti += "&" + FootballTeam.PARAM_ACTION + "=" + JugadorsActions.LLISTA_JUGADORS.getAccio();
			throw e;
		}
	}
}
