package com.uoc.myframeuoc.annotations;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Interfcie que s'utilitza per a definir l'anotaci @Column.
 * Aquesta anotaci serveix per a configurar i associar un atribut
 * de l'entitat amb un camp de la taula.
 * 
 * @author Jordi Garcia Casanova
 *
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.FIELD)
public @interface Column {

	/**
	 * Nom del camp de la taula amb el qual s'associa l'atribut.
	 * 
	 * @return Un <code>String</code> amb el nom del camp de la taula amb el qual s'associa l'atribut.
	 */
	String Field() default "";
	/**
	 * Indica que el seu valor s obligatori i, per tant, no pot ser nul. Per defecte, no s obligatori.
	 * 
	 * @return <code>True</code> si el seu valor no pot ser nul i <code>False</code> si pot estar buit.
	 */
	boolean Required() default false;
	/**
	 * Indica si el seu valor es pot repetir, s a dir, si el seu valor s nic. Per defecte, es pot repetir.
	 * 
	 * @return <code>True</code> si s nic i <code>False</code> si es pot repetir.
	 */
	boolean Unique() default false;
	/**
	 * Precisi o nmero de digits que pot tenir un nmero.
	 * 
	 * @return Un <code>int</code> amb la precisi.
	 */
	String Precision() default "";
	/**
	 * Escala o nmero de dgits de la part decimal d'un nmero.
	 * 
	 * @return Un <code>int</code> amb l'escala.
	 */
	String Scale() default "";
	/**
	 * Mida en carcters o bytes d'un camp.
	 * 
	 * @return Un <code>int</code> amb la mida en carcters o bytes d'un camp.
	 */
	String Length() default "";
}
