package com.uoc.myframeuoc.annotations;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Interfcie que s'utilitza per a definir l'anotaci @ManyToMany.
 * Aquesta anotaci serveix per a configurar una relaci de molts a molts.
 * 
 * @author Jordi Garcia Casanova
 *
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.FIELD)
public @interface ManyToMany {
	/**
	 * Nom de la taula que s'utilitza per a implementar la relaci
	 * molts a molts. s obligatori perqu aquest tipus de 
	 * relacions sempre s'implementaran per mitj d'una taula.
	 * 
	 * @return Un <code>String</code> amb el nom de la taula que
	 * s'utilitzar per a implementar la relaci molts a molts.
	 */
	String Table() default "";
	/**
	 * Nom de la clau forana cap a la taula de l'entitat dest de la relaci
	 * molts a molts
	 * 
	 * @return Un <code>String</code> amb el nom de la clau forana cap la taula
	 * de l'entitat dest de la relaci molts a molts.
	 */
	String NameFK_To() default "";
	/**
	 * Nom de la clau forana cap a la taula de l'entitat origen de la relaci
	 * molts a molts
	 * 
	 * @return Un <code>String</code> amb el nom de la clau forana cap a la taula
	 * de l'entitat origen de la relaci molts a molts.
	 */
	String NameFK_From() default "";
	/**
	 * Correspondncies entre els camps origen i les claus primries de l'entitat dest.
	 * 
	 * @return Un <code>String</code> amb les correspondncies entre els camps origen
	 * i les claus primries de l'entitat dest.
	 */
	String Fields_To() default "";
	/**
	 * Correspondncies entre els camps dest i les claus primries de l'entitat origen.
	 * 
	 * @return Un <code>String</code> amb les correspondncies entre els camps dest i
	 * les claus primries de l'entitat origen.
	 */
	String Fields_From() default "";
}
