package com.uoc.myframeuoc.annotations;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Interfcie que s'utilitza per a definir l'anotaci @OneToOne.
 * Aquesta anotaci serveix per a definir una relaci un a un.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.FIELD)
public @interface OneToOne {
	/**
	 * Nom de la taula que s'utilitza per a implementar la relaci 
	 * un a un. Si no s'indica cap, llavors no s'utilitzar una
	 * taula per a implementar-la.
	 * 
	 * @return Un <code>String</code> amb el nom de la taula que s'utilitza
	 * per a implementar la relaci un a un.
	 */
	String Table() default "";
	/**
	 * Nom de la clau forana cap a la taula de l'entitat dest de la relaci
	 * un a un.
	 * 
	 * @return Un <code>String</code> amb el nom de la clau forana cap a la taula
	 * de l'entitat dest de la relaci un a un.
	 */
	String NameFK_To() default "";
	/**
	 * Nom de la clau forana cap a la taula de l'entitat origen de la relaci
	 * un a un.
	 * 
	 * @return Un <code>String</code> amb el nom de la clau forana cap a la taula
	 * de l'entitat origen de la relaci un a un.
	 */
	String NameFK_From() default "";
	
	/**
	 * Correspondncies entre els camps origen i les claus primries de l'entitat dest.
	 * 
	 * @return Un <code>String</code> amb les correspondncies entre els camps origen
	 * i les claus primries de l'entitat dest.
	 */
	String Fields_To() default "";
	
	/**
	 * Correspondncies entre els camps dest i les claus primries de l'entitat origen.
	 * 
	 * @return Un <code>String</code> amb les correspondncies entre els camps dest i
	 * les claus primries de l'entitat origen.
	 */
	String Fields_From() default "";
}
