package com.uoc.myframeuoc.annotations;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Interfcie que s'utilitza per a definir l'anotaci @PrimaryKey.
 * Aquesta anotaci serveix per a configurar una clau primria en una entitat.
 * 
 * @author Jordi Garcia Casanova
 *
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.FIELD)
public @interface PrimaryKey {

	/**
	 * Nom de la clau primria de la taula.
	 * 
	 * @return - Un <code>String</code> amb el nom de la clau primria.
	 */
	String Name() default "";
	/**
	 * Nom del camp que li correspon a l'atribut en la taula. 
	 * 
	 * @return - Un <code>String</code>amb el nom del camp que li correspon a l'atribut en la taula.
	 */
	String Field() default "";
	/**
	 * Precisi o nmero de digits d'un nmero.
	 * 
	 * @return - Un <code>int</code> amb la precisi.
	 */
	String Precision() default "";
	/**
	 * Escala o nmero de dgits de la part decimal d'un nmero.
	 * 
	 * @return - Un <code>int</code> amb l'escala.
	 */
	String Scale() default "";
	/**
	 * Mida en carcters o bytes d'un camp.
	 * 
	 * @return - Un <code>int</code> amb la mida en carcters o bytes d'un camp.
	 */
	String Length() default "";
}
