package com.uoc.myframeuoc.database;

/**
 * Enum que serveix per a emmagatzemar els tipus de 
 * dades de Java que es poden utilitzar en MyFrameUOC:
 * <br><br>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#String String}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#char_ char_}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#Character Character}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#int_ int_}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#Integer Integer}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#float_ float_}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#Float Float}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#double_ double_}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#Double Double}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#BigDecimal BigDecimal}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#Date Date}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#byte_ byte_}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#Byte Byte}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#short_ short_}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#Short Short}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#long_ long_}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#Long Long}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#boolean_ boolean_}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#Boolean Boolean}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#Time Time}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.database.JavaType#BigInteger BigInteger}
 * </li>
 * <br><br>
 * @author Jordi Garcia Casanova.
 *
 */
public enum JavaType {
	/**
	 * Representa el tipus <code>java.lang.String</code> de Java.
	 */
	String(java.lang.String.class.getCanonicalName()),
	
	/**
	 * Repreenta el tipus primitiu <code>char</code> de Java.
	 */
	char_(char.class.getCanonicalName()),
	
	/**
	 * Representa el tipus <code>java.lang.Character</code> de Java
	 */
	Character(java.lang.Character.class.getCanonicalName()),
	
	/**
	 * Representa el tipus primitiu <code>char[]</code> de Java.
	 */
	char_array(char[].class.getCanonicalName()),
	
	/**
	 * Representa el tipus primitu <code>int</code> de Java.
	 */
	int_(int.class.getCanonicalName()),
	
	/**
	 * Representa el tipus <code>java.lang.Integer</code> de Java.
	 */
	Integer(java.lang.Integer.class.getCanonicalName()),
	
	/**
	 * Represnta el tipus primitiu <code>float</code> de Java.
	 */
	float_(float.class.getCanonicalName()),
	
	/**
	 * Represnta el tipus <code>java.lang.Float</code> de Java.
	 */
	Float(java.lang.Float.class.getCanonicalName()),
	
	/**
	 * Representa el tipus primitiu <code>double</code> de Java.
	 */
	double_(double.class.getCanonicalName()),
	
	/**
	 * Representa el tipus <code>java.lang.Double</code> de Java.
	 */
	Double(java.lang.Double.class.getCanonicalName()),
	
	/**
	 * Represnta el tipus <code>java.math.BigDecimal</code> de Java.
	 */
	BigDecimal(java.math.BigDecimal.class.getCanonicalName()),
	
	/**
	 * Represnta el tipus <code>java.sql.Date</code> de Java.
	 */
	Date(java.sql.Date.class.getCanonicalName()),
	
	/**
	 * Represnta el tipus primitiu <code>byte</code> de Java.
	 */
	byte_(byte.class.getCanonicalName()),
	/**
	 * Represnta el tipus <code>java.lang.Byte</code> de Java.
	 */
	Byte(java.lang.Byte.class.getCanonicalName()),
	/**
	 * Represnta el tipus primitiu <code>short</code> de Java.
	 */
	short_(short.class.getCanonicalName()),
	/**
	 * Represnta el tipus <code>java.lang.Short</code> de Java.
	 */
	Short(java.lang.Short.class.getCanonicalName()),
	/**
	 * Represnta el tipus primitiu <code>long</code> de Java.
	 */
	long_(long.class.getCanonicalName()),
	/**
	 * Represnta el tipus <code>java.lang.Long</code> de Java.
	 */
	Long(java.lang.Long.class.getCanonicalName()),
	/**
	 * Represnta el tipus primitiu <code>boolean</code> de Java.
	 */
	boolean_(boolean.class.getCanonicalName()),
	/**
	 * Represnta el tipus <code>java.lang.Boolean</code> de Java.
	 */
	Boolean(java.lang.Boolean.class.getCanonicalName()),
	/**
	 * Representa el tipus <code>java.sql.Time</code> de Java.
	 */
	Time(java.sql.Time.class.getCanonicalName()),
	/**
	 * Representa el tipus <code>java.math.BigInteger</code> de Java.
	 */
	BigInteger(java.math.BigInteger.class.getCanonicalName());
	
	//Nom cannic del tipus de Java que es representa.
	private final String type;
	
	JavaType(String type){
		this.type = type;
	}
	
	/**
	 * Permet obtenir el nom del tipus de Java que es representa.
	 * 
	 * @return Un <code>String</code> amb el nom del tipus de Java que es representa
	 */
	public String getType(){
		return (this.type);
	}
	
}
