package com.uoc.myframeuoc.exceptions;

/**
 * Aquest <code>Enum</code> serveix per a emmagatzemar els missatges d'error
 * que es produexien en el paquet <i>DataBase</i>.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
public enum DataBaseMsg {
	/**
	 * No hi ha una connexi oberta amb la base de dades.
	 */
	NO_CONNEXIO_OBERTA("No hi ha una connexi oberta amb la base de dades.", 2),
	/**
	 * No s'ha pogut registrar la classe 'oracle.jdbc.driver.OracleDriver'.
	 */
	NO_REGSITRE_ORACLE("No s'ha pogut registrar la classe 'oracle.jdbc.driver.OracleDriver'.", 3),
	/**
	 * No s'ha pogut obrir una connexi amb el sistema de gesti de bases de dades perqu la configuraci no s vlida.
	 */
	NO_OBRIR_CONNEXIO_CONFIG("No s'ha pogut obrir una connexi amb el sistema de gesti de bases de dades perqu la configuraci no s vlida.", 4),
	/**
	 * No s'ha pogut obrir una connexi amb el sistema de gesti de bases de dades.
	 */
	NO_OBRIR_CONNEXIO("No s'ha pogut obrir una connexi amb el sistema de gesti de bases de dades.", 5),
	/**
	 * No s'ha pogut registrar la classe 'com.mysql.jdbc.Driver'.
	 */
	NO_REGISTRE_MYSQL("No s'ha pogut registrar la classe 'com.mysql.jdbc.Driver'.", 6),
	/**
	 * S'ha produt un error en verificar l'existncia d'una taula en la base de dades.
	 */
	ERR_EXISTEIX_TAULA("S'ha produt un error en verificar l'existncia d'una taula en la base de dades.", 7),
	/**
	 * No s'ha pogut iniciar la transacci.
	 */
	NO_INICIAR_TRANSACCIO("No s'ha pogut iniciar la transacci.", 8),
	/**
	 * No s'ha pogut confirmar la transacci.
	 */
	NO_CONFIRMAR_TRANSACCIO("No s'ha pogut confirmar la transacci.", 9),
	/**
	 * No s'ha pogut cancellar la transacci.
	 */
	NO_CANCELAR_TRANSACCIO("No s'ha pogut cancellar la transacci.", 10),
	/**
	 * No s'ha pogut executar la consulta SQL sobre la base de dades.
	 */
	NO_EXECUTAR_CONSULTA("No s'ha pogut executar la consulta SQL sobre la base de dades.", 11),
	/**
	 * No es pot crear una connexi sense una configuraci.
	 */
	CONNEXIO_SENSE_CONFIGURACIO("No es pot crear una connexi sense una configuraci.", 12),
	/**
	 * No s'han afegit al sistema tipus de dades mapejats.
	 */
	NO_TIPUS_MAPEJATS("No s'han afegit al sistema tipus de dades mapejats.", 13),
	/**
	 * El tipus de dades de Java no est suportotat per MyFrameUOC.
	 */
	NO_EXISTEIX_TIPUS_JAVA("El tipus de dades de Java no est suportat per MyFrameUOC.", 14),
	/**
	 * No s'ha informat la mida d'algun dels atributs de l'entitat.
	 */
	MIDA_NO_INDICADA("No s'ha informat la mida d'algun dels atributs de l'entitat.", 15),
	/**
	 * No s'ha informat la precisi d'algun dels atributs de l'entitat.
	 */
	PRECISIO_NO_INDICADA("No s'ha informat la precisi d'algun dels atributs de l'entitat.", 16),
	/**
	 * No s'ha informat l'escala d'algun dels atributs de l'entitat.
	 */
	ESCALA_NO_INDICADA("No s'ha informat l'escala d'algun dels atributs de l'entitat.", 17),
	/**
	 * No es pot inserir un valor en una sentncia preparada si la sentncia est buida.
	 */
	INSERTAR_VALOR_SENSE_SENTENCIA("No es pot inserir un valor en una sentncia preparada si la sentncia est buida.", 18),
	/**
	 * S'ha produt un error en inserir els valors en una sentncia preparada.
	 */
	INSERTAR_VALOR_ERROR("S'ha produt un error en inserir els valors en una sentncia preparada.", 19),
	/**
	 * S'ha produt un error en obtenir els valors d'un objecte.
	 */
	OBTENIR_OBJECTE_ERROR("S'ha produt un error en obtenir els valors d'un objecte.", 20),
	/**
	 * S'ha produt un error en l'obtenci d'una sentncia preparada i els seus valors.
	 */
	PREPARAR_SENTENCIA_VALORS_ERROR("S'ha produt un error en l'obtenci d'una sentncia preparada i els seus valors.", 21),
	/**
	 * No es pot executar una sentncia SQL DDL sense la sentncia preparada.
	 */
	EXECUTESQLDDL_SENSE_SENTENCIA_PREPARADA("No es pot executar una sentncia SQL DDL sense la sentncia preparada.", 22),
	/**
	 * No es pot executar una sentncia SQL DDL sense l'objecte que cont els valors.
	 */
	EXECUTSQLDDL_SENSE_OBJECTE("No es pot executar una sentncia SQL DDL sense l'objecte que cont els valors.", 23),
	/**
	 * S'ha produt un error en executar una sentncia SQL DDL preparada.
	 */
	EXECUTESQLDDL_ERROR("S'ha produt un error en executar una sentncia SQL DDL preparada.", 24),
	/**
	 * No es pot executar una sentncia SQL sense la sentncia preparada.
	 */
	EXECUTESQL_SENSE_SENTENCIA("No es pot executar una sentncia SQL sense la sentncia preparada.", 25),
	/**
	 * No es pot executar una sentncia SQL sense la llista de valors per a la restricci.
	 */
	EXECUTESQL_SENSE_VALORS("No es pot executar una sentncia SQL sense la llista de valors per a la restricci.", 26),
	/**
	 * S'ha produt un error en l'obtenci del mapeig del tipus de dades.
	 */
	GETTYPEMAP_ERROR("S'ha produt un error en l'obtenci del mapeig del tipus de dades.", 27),
	/**
	 * El tipus de dada no pot tenir ni precisi ni escala
	 */
	DADA_AMB_PRECISIO_ESCALA("El tipus de dada no pot tenir ni precisi ni escala.", 28),
	/**
	 * El tipus de dada no pot tenir una mida.
	 */
	DADA_AMB_MIDA("El tipus de dada no pot tenir una mida.", 29),
	/**
	 * El tipus de dada ha de tenir precisi i escala o cap de les dues.
	 */
	DADA_SENSE_PRECISIO_O_ESCALA("El tipus de dada ha de tenir precisi i escala o cap de les dues.", 30),
	/**
	 * S'ha produt un error al tancar la connexi amb la base de dades.
	 */
	CLOSE_ERROR("S'ha produt un error al tancar la connexi amb la base de dades.", 31),
	/**
	 * Un BigInteger ha de tenir indicat una precisi.
	 */
	BIGINTEGER_SENSE_PRECISIO("Un BigInteger ha de tenir indicat una precisi.", 32);
	
	//Text del missatge.
	private String msg		= null;
	
	//Codi identificatiu del missatge.
	private int code		= -1;
	
	/**
	 * Constructor.
	 * 
	 * @param msg - Text del missatge.
	 * @param code - Codi del missatge.
	 */
	DataBaseMsg(String msg, int code){
		this.msg = msg;
		this.code = code;
	}
	
	/**
	 * Permet obtenir el text del missatge.
	 * 
	 * @return Un <code>String</code> amb el text del missatge.
	 */
	public String getMsg(){
		return (this.msg);
	}
	
	/**
	 * Permet obtenir el codi del missatge.
	 * 
	 * @return Un <code>int</code> amb el codi del missatge.
	 */
	public int getCode(){
		return (this.code);
	}
}
