package com.uoc.myframeuoc.exceptions;

/**
 * Aquest <code>Enum</code> serveix per a emmagatzemar els missatges d'errors que
 * es produeixen en el paquet <i>Environment</i>
 * 
 * @author Jordi Garcia Casanova.
 *
 */
public enum EnvironmentMsg {
	/**
	 * No s'ha trobat el node <i>MyFrameUOC</i> en el fitxer de configuraci.
	 */
	NO_NODE_MYFRAMEUOC("No s'ha trobat el node <MyFrameUOC> en el fitxer de configuraci.", 1),
	/**
	 * No s'ha trobat el node <i>propietats</i> en el fitxer de configuraci.
	 */
	NO_NODE_PROPIETATS("No s'ha trobat el node <propietats> en el fitxer de configuraci.", 2),
	/**
	 * No s'ha trobat node <i>SGBD</i> en el fitxer de configuraci.
	 */
	NO_NODE_SGBD("No s'ha trobat node <SGBD> en el fitxer de configuraci.", 3),
	/**
	 * El valor del node <i>SGBD</i> no est informat.
	 */
	NO_INFORMAT_SGBD("El valor del node <SGBD> no est informat.", 4),
	/**
	 * El sistema de gesti de bases de dades que s'ha informat en el fitxer de configuraci s incorrecte.
	 */
	SGBD_INCORRECTE("El sistema de gesti de bases de dades que s'ha informat en el fitxer de configuraci s incorrecte. La versi 1.0 de MyFrameUOC noms suporta Oracle i MySQL.", 5),
	/**
	 * L'estructura del fitxer de configuraci s incorrecta.
	 */
	FITXERCONFIG_INCORRECTE("L'estructura del fitxer de configuraci s incorrecta.", 6),
	/**
	 * No s'ha trobat el node <i>url</i> en el fitxer de configuraci.
	 */
	NO_NODE_URL("No s'ha trobat el node <url> en el fitxer de configuraci.", 7),
	/**
	 * El valor del node <i>url</i> no est informat.
	 */
	NO_INFORMAT_URL("El valor del node <url> no est informat.", 8),
	/**
	 * No s'ha trobat el node <i>user</i> en el fitxer de configuraci.
	 */
	NO_NODE_USER("No s'ha tobat el node <user> en el fitxer de configuraci.", 9),
	/**
	 * El valor del node <i>user</i> no est informat.
	 */
	NO_INFORMAT_USER("El valor del node <user> no est informat.", 10),
	/**
	 * No s'ha trobat el node <i>password</i> en el fitxer de configuraci.
	 */
	NO_NODE_PASSWORD("No s'ha trobat el node <password> en el fitxer de configuraci.", 11),
	/**
	 * No s'ha pogut obrir el fitxer XML de configuraci.
	 */
	NO_OBRIR_FITXERCONFIG("No s'ha pogut obrir el fitxer XML de configuraci.", 12),
	/**
	 * No s'ha indicat un nom d'entitat per a carregar-la a memria.
	 */
	NO_NOM_ENTITAT("No s'ha indicat un nom d'entitat per a carregar-la a memria.", 13),
	/**
	 * No s'ha pogut crear una connexi amb la base de dades perqu la sessi no 
	 * est inicialitzada.
	 */
	NO_SESSION_INICIALITZADA("No s'ha pogut crear una connexi amb la base de dades perqu la sessi no est inicialitzada.", 14),
	/**
	 * Ja hi ha una transacci activa. No es pot tornar a iniciar una transacci dins de la mateixa sessi.
	 */
	TRANSACCIO_ACTIVA("Ja hi ha una transacci activa. No es pot tornar a iniciar una transacci dins de la mateixa sessi.", 15),
	/**
	 * No hi ha una transacci activa.
	 */
	TRANSACCI_NO_ACTIVA("No hi ha una transacci activa.", 16),
	/**
	 * No s'ha pogut iniciar la transacci.
	 */
	NO_INICIAR_TRANSACCIO("No s'ha pogut iniciar la transacci.", 17),
	/**
	 * L'objecte ja existeix en la base de dades.
	 */
	EXISTEIX_OBJECTE("L'objecte ja existeix en la base de dades.", 18),
	/**
	 * No s'ha trobat l'entitat.
	 */
	ENTITAT_NO_TROBADA("No s'ha trobat l'entitat.", 19),
	/**
	 * No es pot registrar una entitat buida.
	 */
	REGISTRE_ENITAT_BUIDA("No es pot registrar una entitat buida.", 20),
	/**
	 * No hi ha una sessi de MyFrameUOC oberta.
	 */
	NO_SESSIO_OBERTA("No hi ha una sessi de MyFrameUOC oberta.", 21),
	/**
	 * La sessi no t una configuraci.
	 */
	SESSIO_SENSE_CONFIGURACIO("La sessi no t una configuraci.", 22),
	/**
	 * La sessi no t una connexi oberta amb la base de dades.
	 */
	SESSIO_SENSE_CONNEXIO("La sessi no t una connexi oberta amb la base de dades.", 23),
	/**
	 * La sessi no t un gestor d'entitats inicialitzat.
	 */
	SESSIO_SENSE_GESTOR_ENTITATS("La sessi no t un gestor d'entitats inicialitzat.", 24),
	/**
	 * No es pot iniciar una sessi sense indicar un fitxer de configuraci.
	 */
	FITXER_CONFIGURACIO_SENSE_INFORMAR("No es pot iniciar una sessi sense indicar un fitxer de configuraci.", 25),
	/**
	 * S'ha produt un error en l'eliminaci d'un objecte de la base de dades.
	 */
	DELETE_OBJECT_ERROR("S'ha produt un error en l'eliminaci d'un objecte de la base de dades.", 26),
	/**
	 * S'ha produt un error en la confirmaci d'una transacci.
	 */
	COMMIT_ERROR("S'ha produt un error en la confirmaci d'una transacci.", 27),
	/**
	 * S'ha produt un error en la cancellaci d'una transacci.
	 */
	ROLLBACK_ERROR("S'ha produt un error en la cancellaci d'una transacci.", 28),
	/**
	 * S'ha produt un error en la inserci d'un objecte en la base de dades.
	 */
	INSERT_OBJECT_ERROR("S'ha produt un error en la inserci d'un objecte en la base de dades.", 29),
	/**
	 * S'ha produt un error en la lectura d'un objecte de la base de dades.
	 */
	READ_OBJECT_ERROR("S'ha produt un error en la lectura d'un objecte de la base de dades.", 30),
	/**
	 * S'ha produt un error en l'actualitzaci d'un objecte en la base de dades.
	 */
	UPDATE_OBJECT_ERROR("S'ha produt un error en l'actualitzaci d'un objecte en la base de dades.", 31),
	/**
	 * S'ha produt un error en l'eliminaci de la taula d'una entitat de la base de dades.
	 */
	DROP_ENTITY_ERROR("S'ha produt un error en l'eliminaci de la taula d'una entitat de la base de dades.", 32),
	/**
	 * S'ha produt un error al tacnar la connexi amb la base de dades.
	 */
	CLOSE_ERROR("S'ha produt un error al tacnar la connexi amb la base de dades.", 33),
	/**
	 * No es pot inserir un objecte nul en la base de dades.
	 */
	INSERT_SENSE_OBJECTE("No es pot inserir un objecte nul en la base de dades.", 34),
	/**
	 * S'ha produt un error en la conversi d'una sentncia UOCQL en una sentncia SQL.
	 */
	CONVERTUOCQL_ERROR("S'ha produt un error en la conversi d'una sentncia UOCQL en una sentncia SQL.", 35),
	/**
	 * No es pot executar una consulta UOCQL que est buida.
	 */
	CONVERTUOCQL_UOCQL_BUIDA("No es pot executar una consulta UOCQL que est buida.", 36),
	/**
	 * La consulta UOCQL no est ben construda.
	 */
	CONVERTUOCQL_UOCQL_INCORRECTA("La consulta UOCQL no est ben construda.", 37),
	/**
	 * Algun atribut indicat en la sentncia UOCQL no existeix en la  definici de l'entitat.
	 */
	CONVERTUOCQL_ATRIBUT_NO_EXISTEIX("Algun atribut indicat en la sentncia UOCQL no existeix en la  definici de l'entitat.", 38),
	/**
	 * L'operador relacional utilitzat en la sentncia UOCQL no est perms.
	 */
	CONVERTUOCQL_OPERADOR_RELACIONAL_ERRONI("L'operador relacional utilitzat en la sentncia UOCQL no est perms.", 39),
	/**
	 * S'ha produt un error en l'execuci de la consulta UOCQL.
	 */
	EXECUTEUOCQL_ERROR("S'ha produt un error en l'execuci de la consulta UOCQL.", 40),
	/**
	 * L'entitat no t claus primries.
	 */
	EXECUTEUOCQL_ENTITAT_SENSE_PK("L'entitat no t claus primries.", 41);

	//Text del missatge.
	private String msg		= null;
	
	//Codi del missatge.
	private int code		= -1;
	
	/**
	 * Permet obtenir el text del missatge.
	 * 
	 * @return Un <code>String</code> amb el text del missatge.
	 */
	public String getMsg(){
		return (msg);
	}
	
	/**
	 * Permet obtenir el codi del missatge.
	 * 
	 * @return Un <code>int</code> amb el codi del missatge.
	 */
	public int getCode(){
		return (code);
	}
	
	/**
	 * Constructor.
	 * 
	 * @param msg - Text del missatge.
	 * @param code - Codi del missatge.
	 */
	EnvironmentMsg(String msg, int code){
		this.msg = msg;
		this.code = code;
	}
}
