package com.uoc.myframeuoc.exceptions;

/**
 * Aquest <code>Enum</code> serveix per a emmagatzemar els missatges d'error associats
 * a la base de dades:
 * <br><br>
 * {@link com.uoc.myframeuoc.exceptions.GeneralMsg#NO_SGBD NO_SGBD}
 * 
 * @author Jordi Garcia Casanova.
 *
 */
public enum GeneralMsg{

	/**
	 * No s'ha definit un sistema de gesti de base de dades. No hi ha cap especialitzaci de la
	 * classe <code>{@link com.uoc.myframeuoc.database.Connection}</code>. Aquest cas, tericament,
	 * no es pot donar perqu MyFrameUOC es proporciona amb dues especialitzacions, s a dir, 
	 * que es pot treballar amb Oracle y MySQL. 
	 */
	NO_SGBD("No hi ha definit internament cap sistema de gesti de base de dades. Consultar amb el provedor de MyFrameUOC", 1),
	/**
	 * L'entitat no t definides les claus primries.
	 */
	ENTITAT_SENSE_PK("L'entitat no t definides les claus primries.", 2);
	
	//Text del missatge.
	private final String msg;
	
	//Codi del missatge.
	private final int code;
	
	/**
	 * Permet obtenr el text del missatge.
	 * 
	 * @return Un <code>String</code> amb el text del missatge.
	 */
	public String getMsg(){
		return (this.msg);
	}
	
	/**
	 * Permet obtenir el codi del missatge.
	 * 
	 * @return Un <code>int</code> amb el codi del missatge.
	 */
	public int getCode(){
		return (this.code);
	}
	
	/**
	 * Constructor. 
	 * 
	 * @param msg - Text del missatge.
	 * @param code - Codi del missatge.
	 */
	GeneralMsg(String msg, int code){
		this.msg = msg;
		this.code = code;
	}
}
