package com.uoc.myframeuoc.exceptions;

/**
 * Aquest <code>Enum</code> serveix per a emmagatzemar els missatges d'error que
 * es produceixen en el paquet <i>Mapping</i>.
 * 
 * @author Jordi Garcia Casanova
 *
 */
public enum MappingMsg {
	/**
	 * No es pot crear un objecte mapejat sense indicar un atribut.
	 */
	OBJECTEMAPEJAT_SENSE_PROPIETAT("No es pot crear un objecte mapejat sense indicar un atribut.", 1),
	/**
	 * No es pot crear un objecte mapejat sense indicar el camp de la taula.
	 */
	OBJECTEMAPEJAT_SENSE_CAMP("No es pot crear un objecte mapejat sense indicar el camp de la taula.", 2),
	/**
	 * No es pot crear un objecte mapejat sense el tipus de dades mapejat.
	 */
	OBJECTEMAPEJAT_SENSE_TIPUS("No es pot crear un objecte mapejat sense el tipus de dades mapejat.", 3),
	/**
	 * No es pot crear una clau primria mapejada sense indicar el nom que t en la taula de la base de dades.
	 */
	CLAUPRIMARIA_SENSE_NOM("No es pot crear una clau primria mapejada sense indicar el nom que t en la taula de la base de dades.", 4),
	/**
	 * No es pot crear una entitat sense el seu nom.
	 */
	CREAR_ENTITAT_SENSE_NOM("No es pot crear una entitat sense el seu nom.", 5),
	/**
	 * No es poden obtenir les anotacions d'una classe que s nulla.
	 */
	ANOTACIONS_SENSE_CLASSE("No es poden obtenir les anotacions d'una classe que s nulla.", 6),
	/**
	 * S'ha produt un error en l'obtenci de la classe de l'entitat.
	 */
	ERROR_OBTENCIO_CLASSE("S'ha produt un error en l'obtenci de la classe de l'entitat.", 7),
	/**
	 * L'entitat no t definida l'anotaci <i>@Entity</i>.
	 */
	ANOTACIO_ENTITAT_NO_EXISTEIX("L'entitat no t definida l'anotaci @Entity.", 8),
	/**
	 * L'entitat no t definida la propietat <i>Taula</i> en l'anotaci <i>@Entity</i>.
	 */
	ANOTACIO_ENTITAT_SENSE_TAULA("L'entitat no t definida la propietat Taula en l'anotaci @Entity", 9),
	/**
	 * No s'han trobat anotacions en l'entitat.
	 */
	ENTITAT_SENSE_ANOTACIONS("No s'han trobat anotacions en l'entitat.", 10),
	/**
	 * L'entitat que es vol registrar no t atributs.
	 */
	ENTITAT_SENSE_ATRIBUTS("L'entitat que es vol registrar no t atributs.", 11),
	/**
	 * No es pot crear una relaci sense l'atribut de l'entitat.
	 */
	RELACIO_SENSE_ATRIBUT("No es pot crear una relaci sense l'atribut de l'entitat.", 12),
	/**
	 * No es pot crear una relaci sense el nom de la seva entitat.
	 */
	RELACIO_SENSE_ENTITAT("No es pot crear una relaci sense el nom de la seva entitat.", 13),
	/**
	 * No es pot crear una relaci sense una sessi inicialitzada.
	 */
	RELACIO_SENSE_SESSIO("No es pot crear una relaci sense una sessi inicialitzada.", 14),
	/**
	 * No es pot crear una clau forana sense el seu nom.
	 */
	CLAU_FORANA_SENSE_NOM("No es pot crear una clau forana sense el seu nom.", 15),
	/**
	 * No es pot crear una clau forana cap a una entitat que no t clau primria.
	 */
	CLAU_FORANA_SENSE_CLAU_PRIMARIA("No es pot crear una clau forana cap a una entitat que no t clau primria.", 16),
	/**
	 * No es pot crear una clau forana sense indicar una correpondncia entre els camps origen i dest.
	 */
	CLAU_FORANA_SENSE_CORRESPONDENCIA("No es pot crear una clau forana sense indicar una correpondncia entre els camps origen i dest.", 17),
	/**
	 * No s'han pogut afegir les claus foranes a la sentncia CREATE TABLE.
	 */
	CREATE_TABLE_NO_CLAU_FORANA("No s'han pogut afegir les claus foranes a la sentncia CREATE TABLE.", 18),
	/**
	 * L'entitat dest de la clau forana no t claus primries.
	 */
	CREATE_TABLE_NO_CLAUS_PRIMARIES("L'entitat dest de la clau forana no t claus primries.", 19),
	/**
	 * L'entita dest no t la clau primria que s'ha indicat en l'anotaci de la clau forana.
	 */
	CREATE_TABLE_CLAU_PRIMARIA_NO_TROBADA("L'entitat dest no t la clau primria que s'ha indicat en l'anotaci de la clau forana.", 20),
	/**
	 * El nom de la clau primria d'una entitat ha de ser nica perqu noms pot haver-hi una clau primria en una taula.
	 */
	CLAU_PRIMARIA_NO_UNICA("El nom de la clau primria d'una entitat ha de ser nica perqu noms pot haver-hi una clau primria en una taula.", 21),
	/**
	 * La clau forana de l'entitat no est ben definida. Falten o sobren camps de correspondncia.
	 */
	CLAU_FORANA_FALTEN_CAMPS("La clau forana de l'entitat no est ben definida. Falten o sobren camps de correspondncia.", 22),
	/**
	 * La sentncia preparedSqlCreateTable de l'entitat no est creada.
	 */
	CREACIO_TAULES_SENSE_CREATE_TABLE("La sentncia preparedSqlCreateTable de l'entitat no est creada.", 23),
	/**
	 * No es poden crear taules sense una sessi inicialitzada.
	 */
	CREACIO_TAULES_SENSE_SESSIO("No es poden crear taules sense una sessio inicialitzada.", 24),
	/**
	 * S'ha produt un error en la creaci de les taules de l'entitat.
	 */
	CREACIO_TAULES_ERROR("S'ha produt un error en la creaci de les taules de l'entitat.", 25),
	/**
	 * No es pot registrar una entitat sense una sessi.
	 */
	CREAR_ENTITAT_SENSE_SESSIO("No es pot registrar una entitat sense una sessi.", 26),
	/**
	 * No es pot obtenir la informaci de les anotacios de clau primria sense una sessi inicialitzada.
	 */
	OBTENIR_ANOTACIONS_PK_SENSE_SESSIO("No es pot obtenir la informaci de les anotacios de clau primria sense una sessi inicialitzada.", 27),
	/**
	 * S'ha produt un error en l'obtenci de la informaci de les anotacions de clau primria.
	 */
	OBTENIR_ANOTACIONS_PK_ERROR("S'ha produt un error en l'obtenci de la informaci de les anotacions de clau primria.", 28),
	/**
	 * No es pot obtenir la informaci de les anotacions de les columnes sense una sessi inicialitzada.
	 */
	OBTENIR_ANOTACIONS_COLUMNA_SENSE_SESSIO("No es pot obtenir la informaci de les anotacions de les columnes sense una sessi inicialitzada.", 29),
	/**
	 * S'ha produt un error en l'obtenci de la informaci de les anotacions de columna.
	 */
	OBTENIR_ANOTACIONS_COLUMNA_ERROR("S'ha produt un error en l'obtenci de la informaci de les anotacions de columna.", 30),
	/**
	 * No es pot obtenir la informaci de les anotacions de clau forana sense una sessi inicialitzada.
	 */
	OBTENIR_ANOTACIONS_FK_SENSE_SESSIO("No es pot obtenir la informaci de les anotacions de clau forana sense una sessi inicialitzada.", 31),
	/**
	 * S'ha produt un error en l'obtenci de la informaci de les anotacions de clau forana.
	 */
	OBTENIR_ANOTACIONS_FK_ERROR("S'ha produt un error en l'obtenci de la informaci de les anotacions de clau forana.", 32),
	/**
	 * S'ha produt un error en la preparaci de les sentncies SQL d'una entitat.
	 */
	PREPARAR_QUERIES_ERROR("S'ha produt un error en la preparaci de les sentncies SQL d'una entitat.", 33),
	/**
	 * S'ha produt un error en la prerparaci de la sentncia CREATE TABLE.
	 */
	PREPARAR_CREATE_TABLE_ERROR("S'ha produt un error en la preparaci de la sentncia CREATE TABLE.", 34),
	/**
	 * S'ha produt un error en la preparaci de la sentncia CREATE TABLE sense restriccions de clau forana.
	 */
	PREPARAR_CREATE_TABLE_NOFK_ERROR("S'ha produt un error en la preparaci de la sentncia CREATE TABLE sense restriccions de clau forana.", 35),
	/**
	 * S'ha produt un error en la preparaci de la sentncia ALTER TABLE.
	 */
	PREPARAR_ALTER_TABLE_ERROR("S'ha produt un error en la preparaci de la sentncia ALTER TABLE.", 36),
	/**
	 * Una entitat ha de tenir una clau primria com a mnim.
	 */
	ENTITAT_SENSE_CLAU_PRIMARIA("Una entitat ha de tenir una clau primria com a mnim.", 37),
	/**
	 * No es pot emmagatzemar un nou objecte sense una sessi inicialitzada.
	 */
	INSERIR_ENTITAT_SENSE_SESSIO("No es pot emmagatzemar un nou objecte sense una sessi inicialitzada.", 38),
	/**
	 * No es pot llegir una entitat de la base de dades sense una sessi inicialitzada.
	 */
	LLEGIR_ENTITAT_SENSE_SESSIO("No es pot llegir una entitat de la base de dades sense una sessi inicialitzada.", 39),
	/**
	 * No es pot llegir una entitat de la base de dades sense indicar la llista dels valors de les claus primries.
	 */
	LLEGIR_ENTITAT_SENSE_VALORS("No es pot llegir una entitat de la base de dades sense indicar la llista dels valors de les claus primries.", 40),
	/**
	 * El nmero de valors passats en la llista de valors no coincideix amb el nmero de claus primries.
	 */
	LLEGIR_ENTITAT_VALORS_DIFERENTS("El nmero de valors passats en la llista de valors no coincideix amb el nmero de claus primries.", 41),
	/**
	 * S'ha produt un error en la lectura d'una entitat de la base de dades.
	 */
	LLEGIR_ENTITAT_ERROR("S'ha produt un error en la lectura d'un objecte d'una entitat de la base de dades.", 42),
	/**
	 * S'ha produt un eror en l'assignaci de valors a un objecte.
	 */
	SETVALUESOBJECT_ERROR("S'ha produt un eror en l'assignaci de valors a un objecte.", 43),
	/**
	 * No es pot actualitzar una entitat sense una sessi inicialitzada.
	 */
	UPDATE_SENSE_SESSIO("No es pot actualitzar una entitat sense una sessi inicialitzada.", 44),
	/**
	 * No es pot crear una sentncia DELETE preparada si l'entitat no t claus primries.
	 */
	DELETE_SENSE_CLAUS_PRIMARIES("No es pot crear una sentncia DELETE preparada si l'entitat no t claus primries.", 45),
	/**
	 * No es pot esborrar un objecte d'una entitat sense una sessi inicialitzada.
	 */
	DELETE_SENSE_SESSIO("No es pot esborrar un objecte d'una entitat sense una sessi inicialitzada.", 46),
	/**
	 * No es pot esborrar una entitat sense una sessi inicialitzada.
	 */
	DROP_SENSE_SESSIO("No es pot esborrar una entitat sense una sessi inicialitzada.", 47),
	/**
	 * S'ha produt un error en l'eliminaci d'un objecte de la base de dades.
	 */
	DELETE_ERROR("S'ha produt un error en l'eliminaci d'un objecte de la base de dades.", 48),
	/**
	 * S'ha produt un error en la creaci d'una entitat.
	 */
	CREAR_ENTITAT_ERROR("S'ha produt un error en la creaci d'una entitat.", 49),
	/**
	 * S'ha produt un error en inserir un objecte en la base de dades.
	 */
	INSERT_ERROR("S'ha produt un error en inserir un objecte en la base de dades.", 50),
	/**
	 * No es pot inserir un objecte nul en la base de dades.
	 */
	INSERT_SENSE_OBJECTE("No es pot inserir un objecte nul en la base de dades.", 51),
	/**
	 * No es pot crear la sentncia preparedSqlCreateTableNoFK sense la sentncia preparedSqlCreateTable.
	 */
	PREPAREDCREATETABLENOFK_SENSE_PREPAREDSQLCREATETABLE("No es pot crear la sentncia preparedSqlCreateTableNoFK sense la sentncia preparedSqlCreateTable.", 52),
	/**
	 * No es pot crear la sentncia preparedSqlAlterTable sense la sentncia preparedSqlCreateTable.
	 */
	PREAPREDALTERTABLE_SENSE_PREPAREDSQLCREATETABLE("No es pot crear la sentncia preparedSqlAlterTable sense la sentncia preparedSqlCreateTable.", 53),
	/**
	 * No es pot crear la sentncia preparedSqlUpdateOnlyFK si l'entitat no t claus primries.
	 */
	PREPAREDSQLUPDATEONLYFK_SENSE_CLAUS_PRIMARIES("No es pot crear la sentncia preparedSqlUpdateOnlyFK si l'entitat no t claus primries.", 54),
	/**
	 * S'ha produt un error en la creaci de la sentncia SQL preparada preparedSqlUpdateOnlyFK.
	 */
	PREPAREDSQLUPDATEONLYFK_ERROR("S'ha produt un error en la creaci de la sentncia SQL preparada preparedSqlUpdateOnlyFK.", 55),
	/**
	 * No es pot verificar l'existncia d'un objecte en la base de dades sense una sessi.
	 */
	EXISTSOBJECT_SENSE_SESSIO("No es pot verificar l'existncia d'un objecte en la base de dades sense una sessi.", 56),
	/**
	 * S'ha produt un error en la verificaci de l'existncia d'un objecte en la base de dades.
	 */
	EXISTSOBJECT_ERROR("S'ha produt un error en la verificaci de l'existncia d'un objecte en la base de dades.", 57),
	/**
	 * S'ha produt un error en l'obtenci del valor d'un atribut d'un objecte.
	 */
	GETOBJECTVALUE_ERROR("S'ha produt un error en l'obtenci del valor d'un atribut d'un objecte.", 58),
	/**
	 * No es pot obtenir el valor d'un atribut d'un objecte si no s'indica el nom de l'atribut.
	 */
	GETOBJECTVALUE_SENSE_ATRIBUT("No es pot obtenir el valor d'un atribut d'un objecte si no s'indica el nom de l'atribut.", 59),
	/**
	 * No es pot obtenir el valor d'un atribut d'un objecte si l'objecte s nul.
	 */
	GETOBJECTVALUE_SENSE_OBJECTE("No es pot obtenir el valor d'un atribut d'un objecte si l'objecte s nul.", 60),
	/**
	 * S'ha produt un error en la insercci o actualitzaci de les claus foranes.
	 */
	INSERTFK_ERROR("S'ha produt un error en la insercci o actualitzaci de les claus foranes.", 61),
	/**
	 * No es poden inserir o actualitzar les claus foranes sense una sessi inicialitzada.
	 */
	INSERTFK_SENSE_SESSIO("No es poden inserir o actualitzar les claus foranes sense una sessi inicialitzada.", 62),
	/**
	 * S'ha produt un error en la preparaci de la sentncia preparedSqlAlterTableDropFK.
	 */
	PREPAREALTERTABLEDROPFK_ERROR("S'ha produt un error en la preparaci de la sentncia preparedSqlAlterTableDropFK.", 63),
	/**
	 * No es pot preparar la sentncia preparedAlterTAbleDropFK sense una sessi inicialitzada.
	 */
	PREPAREALTERTABLEDROPFK_SENSE_SESSIO("No es pot preparar la sentncia preparedAlterTAbleDropFK sense una sessi inicialitzada.", 64),
	/**
	 * No es pot inserir un objecte que ja existeix en la base de dades.
	 */
	INSERT_OBJECTE_REPETIT("No es pot inserir un objecte que ja existeix en la base de dades.", 65),
	/**
	 * S'ha produt un error en la lecutra dels objectes dels atributs de clau forana d'un objecte.
	 */
	READFK_ERROR("S'ha produt un error en la lecutra dels objectes dels atributs de clau forana d'un objecte.", 66),
	/**
	 * Falta informaci per a poder llegir els objectes dels atributs de les claus foranes d'un objecte.
	 */
	READFK_FALTA_INFORMACIO("Falta informaci per a poder llegir els objectes dels atributs de les claus foranes d'un objecte.", 67),
	/**
	 * No es pot assignar valor a un atribut d'un objecte si no s'indica el nom de l'atribut que es vol modificar.
	 */
	SETOBJECTPROPERTY_SENSE_ATRIBUT("No es pot assignar valor a un atribut d'un objecte si no s'indica el nom de l'atribut que es vol modificar.", 69),
	/**
	 * No es pot assignar un objecte a un atribut d'un objecte si l'objecte s nul.
	 */
	SETOBJECTPROPERTY_SENSE_OBJ("No es pot assignar un objecte a un atribut d'un objecte si l'objecte s nul.", 70),
	/**
	 * No es pot assignar un objecte a un atribut d'un objecte si l'objecte a assignar s nul.
	 */
	SETOBJECTPROPERTY_SENSE_OBJSOURCE("No es pot assignar un objecte a un atribut d'un objecte si l'objecte a assignar s nul.", 71),
	/**
	 * S'ha produt un error en la preparaci de la sentncia preparedSqlUpdate.
	 */
	PREPARESQLUPDATE_ERROR("S'ha produt un error en la preparaci de la sentncia preparedSqlUpdate.", 72),
	/**
	 * No es pot crear la sentncia preparedSqlUpdate si l'entitat no t claus primries.
	 */
	PREPARESQLUPDATE_SENSE_PK("No es pot crear la sentncia preparedSqlUpdate si l'entitat no t claus primries.", 73),
	/**
	 * S'ha produt un error en l'eliminaci de les claus foranes de l'entitat.
	 */
	DELETEFK_ERROR("S'ha produt un error en l'eliminaci de les claus foranes de l'entitat.", 76),
	/**
	 * No es pot esborrar les claus foranes de l'entitat sense una sessi inicialitzada.
	 */
	DELETEFK_SENSE_SESSIO("No es pot esborrar les claus foranes de l'entitat sense una sessi inicialitzada.", 77),
	/**
	 * No s'ha pogut llegir de la base de dades l'objecte que es vol modificar.
	 */
	UPDATE_NO_EXISTEIX_OBJ("No s'ha pogut llegir de la base de dades l'objecte que es vol modificar.", 78),
	/**
	 * L'entitat de l'objecte que es vol actualitzar no t definides les claus primries.
	 */
	UPDATE_OBJ_NO_PK("L'entitat de l'objecte que es vol actualitzar no t definides les claus primries.", 79),
	/**
	 * No es pot obtenir la informaci de les anotacions de les relacions un a un sense una sessi inicialitzada.
	 */
	GETONETOONEANNOTATIONSDATA_SENSE_SESSIO("No es pot obtenir la informaci de les anotacions de les relacions un a un sense una sessi inicialitzada.", 80),
	/**
	 * S'ha produt un error en l'obtenci de la informaci de les anotacions de les relacions un a un.
	 */
	GETONETOONEANNOTACIONSDATA_ERROR("S'ha produt un error en l'obtenci de la informaci de les anotacions de les relacions un a un.", 81),
	/**
	 * No s'ha indicat el nom de la clau forana cap a la taula de l'entitat dest de la relaci.
	 */
	BINARYASSOCIATIONMAP_SENSE_NAMEFK("No s'ha indicat el nom de la clau forana cap a la taula de l'entitat dest de la relaci.", 82),
	/**
	 * No s'ha indicat el nom de la clau forana cap a la taula de l'entitat origen de la relaci.
	 */
	BINARYASSOCIATIONMAP_SENSE_NAMEFROM("No s'ha indicat el nom de la clau forana cap a la taula de l'entitat origen de la relaci.", 83),
	/**
	 * No s'ha indicat la correspondncia entre els camps de la clau forana i els atributs de l'entitat dest de la relaci.
	 */
	BINARYASSOCIATIONMAP_SENSE_FIELDSTO("No s'ha indicat la correspondncia entre els camps de la clau forana i els atributs de l'entitat dest de la relaci.", 84),
	/**
	 * No s'ha indicat la correspondncia entre els camps de la clau forana i els atributs de l'entitat origen de la relaci.
	 */
	BINARYASSOCIATIONMAP_SENSE_FIELDSFROM("No s'ha indicat la correspondncia entre els camps de la clau forana i els atributs de l'entitat origen de la relaci.", 85),
	/**
	 * S'ha produt un error en la construcci de les sentncies de les relacions d'un a un.
	 */
	PREPAREONETOONEQUERIES_ERROR("S'ha produt un error en la construcci de les sentncies de les relacions d'un a un.", 86),
	/**
	 * S'ha produt un error en la creaci de les sentncies CREATE TABLE de les relacions d'un a un.
	 */
	ONETOONECREATETABLE_ERROR("S'ha produt un error en la creaci de les sentncies CREATE TABLE de les relacions d'un a un.", 87),
	/**
	 * La definici de la correspondncia entre els camps de la clau forana i els atributs de l'entitat dest s incorrecta.
	 */
	ASSOCIATIONBINARYMAP_BUILDFIELDS_TO_ERROR("La definici de la correspondncia entre els camps de la clau forana i els atributs de l'entitat dest s incorrecta.", 88),
	/**
	 * La definici de la correspondncia entre els camps de la clau forana i els atributs de l'entitat origen s incorrecta.
	 */
	ASSOCIATIONBINARYMAP_BUILDFIELDS_FROM_ERROR("La definici de la correspondncia entre els camps de la clau forana i els atributs de l'entitat origen s incorrecta.", 89),
	/**
	 * S'ha produt un error en la creaci de les taules de les relacions d'un a un de l'entitat.
	 */
	CREATEONETOONETABLES_ERROR("S'ha produt un error en la creaci de les taules de les relacions d'un a un de l'entitat.", 90),
	/**
	 * No es poden crear les taules de les relacions d'un a un de l'entitat sense una sesssi inicialitzada.
	 */
	CREATEONETOONETABLES_SENSE_SESSIO("No es poden crear les taules de les relacions d'un a un de l'entitat sense una sesssi inicialitzada.", 91),
	/**
	 * S'ha produt un error en la preparaci de les sentncies DROP TABLE de les relacions d'un a un de l'entitat.
	 */
	PREPAREONETOONEDROP_ERROR("S'ha produt un error en la preparaci de les sentncies DROP TABLE de les relacions d'un a un de l'entitat.", 92),
	/**
	 * No es poden crear les sentncies DROP TABLE de les relacions d'un a un de l'entitat sense una sessi inicialitzada.
	 */
	PREPAREONETOONEDROP_SENSE_SESSIO("No es poden crear les sentncies DROP TABLE de les relacions d'un a un de l'entitat sense una sessi inicialitzada.", 93),
	/**
	 * S'ha produt un error en la preparaci de les sentncies INSERT de les relacions d'un a un de l'entitat.
	 */
	PREPAREONETOONEINSERT_ERROR("S'ha produt un error en la preparaci de les sentncies INSERT de les relacions d'un a un de l'entitat.", 94),
	/**
	 * No es poden crear les sentncies INSERT de les relacions d'un a un de l'entitat sense una sessi inicialitzada.
	 */
	PREPAREONETOONEINSERT_SENSE_SESSIO("No es poden crear les sentncies INSERT de les relacions d'un a un de l'entitat sense una sessi inicialitzada.", 95),
	/**
	 * S'ha produt un error en la inserci de les relacions d'un a un de l'entitat.
	 */
	INSERTONETOONE_ERROR("S'ha produt un error en la inserci de les relacions d'un a un de l'entitat.", 96),
	/**
	 * No es poden inserir les relacions d'un a un de l'entitat sense una sessi inicialitzada.
	 */
	INSERTONETOONE_SENSE_SESSIO("No es poden inserir les relacions d'un a un de l'entitat sense una sessi inicialitzada.", 97),
	/**
	 * S'ha produt un error en la preparpaci de les sentncies SELECT de les relacions un a un de l'entitat.
	 */
	PREPAREONETOONEREAD_ERROR("S'ha produt un error en la preparpaci de les sentncies SELECT de les relacions un a un de l'entitat.", 98),
	/**
	 * No es poden crear les sentncies SELECT de les relacions un a un de l'entitat sense una sessi inicialitzada.
	 */
	PREPAREONETOONEREAD_SENSE_SESSIO("No es poden crear les sentncies SELECT de les relacions un a un de l'entitat sense una sessi inicialitzada.", 99),
	/**
	 * S'ha produt un error en la lectura de les relacions d'un a un d'un objecte.
	 */
	READONETOONE_ERROR("S'ha produt un error en la lectura de les relacions d'un a un d'un objecte.", 100),
	/**
	 * No es poden llegir les relacions d'un a un sense una sessi inicialitzadao.
	 */
	READONETOONE_SENSE_SESSIO("No es poden llegir les relacions d'un a un sense una sessi inicialitzadao.", 101),
	/**
	 * No es pot llegir un objecte de la base de dades si l'entitat no t configurades les seves claus primries.
	 */
	READ_SENSE_PK("No es pot llegir un objecte de la base de dades si l'entitat no t configurades les seves claus primries.", 103),
	/**
	 * S'ha produt un error en l'actualitzaci d'un objecte.
	 */
	UPDATE_ERROR("S'ha produt un error en l'actualitzaci d'un objecte.", 104),
	/**
	 * S'ha produt un error en l'eliminaci de les taules de les relacions un a un de l'entitat.
	 */
	DELETEONETOONE_ERROR("S'ha produt un error en l'eliminaci de les taules de les relacions un a un de l'entitat.", 105),
	/**
	 * No es poden esborrar les relacions d'un a un de l'entitat sense una sessi inicialitzada.
	 */
	DELETEONETOONE_SENSE_SESSIO("No es poden esborrar les relacions d'un a un de l'entitat sense una sessi inicialitzada.", 106),
	/**
	 * No es poden esborrar les relacions d'un a un d'un objecte que s nul.
	 */
	DELETEONETOONE_SENSE_OBJ("No es poden esborrar les relacions d'un a un d'un objecte que s nul.", 107),
	/**
	 * S'ha produt un error en l'eliminaci de les taules d'una entitat.
	 */
	DROP_ERROR("S'ha produt un error en l'eliminaci de les taules d'una entitat.", 111),
	/**
	 * No es pot obtenir la informaci de les anotacions de les relacions d'un a molts sense una sessi inicialitzada.
	 */
	GETONETOMANYANNOTATIONDATA_SENSE_SESSIO("No es pot obtenir la informaci de les anotacions de les relacions d'un a molts sense una sessi inicialitzada.", 113),
	/**
	 * S'ha produt un error en l'obtenci de la informaci de les anotacions de les relacions d'un a molts de l'entitat.
	 */
	GETONETOMANYANNOTATIONDATA_ERROR("S'ha produt un error en l'obtenci de la informaci de les anotacions de les relacions d'un a molts de l'entitat.", 114),
	/**
	 * S'ha produt un error en l'obtenci del tipus de dades dels objectes d'una collecci.
	 */
	GETENTITYCOLLECTIONTYPE_ERROR("S'ha produt un error en l'obtenci del tipus de dades dels objectes d'una collecci.", 116),
	/**
	 * No es pot obtenir el tipus de dades dels objectes d'una collecci d'una entitat si no s'indica el nom de l'entitat.
	 */
	GETENTITYCOLLECTIONTYPE_SENSE_ENTITAT("No es pot obtenir el tipus de dades dels objectes d'una collecci d'una entitat si no s'indica el nom de l'entitat.", 117),
	/**
	 * No es pot obtenir el tipus de dades dels objectes d'una collecci d'una entitat si no s'indica el nom de la propietat que cont la collecci.
	 */
	GETENTITYCOLLECTIONTYPE_SENSE_PROPIETAT("No es pot obtenir el tipus de dades dels objectes d'una collecci d'una entitat si no s'indica el nom de la propietat que cont la collecci.", 118),
	/**
	 * S'ha produt un error en la preparaci de les sentncies de les relacions d'un a molts de l'entitat.
	 */
	PREPAREONETOMANYQUERIES_ERROR("S'ha produt un error en la preparaci de les sentncies de les relacions d'un a molts de l'entitat.", 119),
	/**
	 * S'ha produt un error en la preparaci de les sentncies CREATE TABLE de les relacions d'un a molts de l'entitat.
	 */
	ONETOMANYCREATETABLE_ERROR("S'ha produt un error en la preparaci de les sentncies CREATE TABLE de les relacions d'un a molts de l'entitat.", 120),
	/**
	 * S'ha produt un error en la creaci de les taules de les relacions d'un a molts de l'entitat.
	 */
	CREATEONETOMANYTABLES_ERROR("S'ha produt un error en la creaci de les taules de les relacions d'un a molts de l'entitat.", 121),
	/**
	 * No es poden crear les taules de les relacions d'un a molts de l'entitat sense una sessi inicialitzada.
	 */
	CREATEONETOMANYTABLES_SENSE_SESSIO("No es poden crear les taules de les relacions d'un a molts de l'entitat sense una sessi inicialitzada.", 122),
	/**
	 * S'ha produt un error en la preparaci de les sentncies DROP TABLE de les relacions d'un a molts de l'entitat.
	 */
	PREPAREONETOMANYDROP_ERROR("S'ha produt un error en la preparaci de les sentncies DROP TABLE de les relacions d'un a molts de l'entitat.", 123),
	/**
	 * No es poden preparar les sentncies INSERT de les relacions d'un a molts de l'entitat sense una sessi inicialitzada.
	 */
	PREPAREONETOMANYINSERT_SENSE_SESSIO("No es poden preparar les sentncies INSERT de les relacions d'un a molts de l'entitat sense una sessi inicialitzada.", 124),
	/**
	 * S'ha produt un error en la preparaci de les sentncies INSERT de les relacions d'un a molts de l'entitat.
	 */
	PREPAREONETOMANYINSERT_ERROR("S'ha produt un error en la preparaci de les sentncies INSERT de les relacions d'un a molts de l'entitat.", 125),
	/**
	 * S'ha produt un error en la inserci dels registres de les relacions d'un a molts de l'entitat.
	 */
	INSERTONETOMANY_ERROR("S'ha produt un error en la inserci dels registres de les relacions d'un a molts de l'entitat.", 126),
	/**
	 * No es pot inserir els registres de les relacions d'un a molts sense una sessi inicialitzada.
	 */
	INSERTONETOMANY_SENSE_SESSIO("No es pot inserir els registres de les relacions d'un a molts sense una sessi inicialitzada.", 127),
	/**
	 * No es poden preparar les sentncies SELECT de les relacions d'un a molts sense una sessi inicialitzada.
	 */
	PREPAREONETOMANYREAD_SENSE_SESSIO("No es poden preparar les sentncies SELECT de les relacions d'un a molts sense una sessi inicialitzada.", 128),
	/**
	 * S'ha produt un error en la preparaci de les sentncies SELECT de les relacions d'un a molts de l'entitat.
	 */
	PREPAREONETOMANYREAD_ERROR("S'ha produt un error en la preparaci de les sentncies SELECT de les relacions d'un a molts de l'entitat. ", 129),
	/**
	 * No es poden llegir els objectes de les relacions d'un a molts d'una entitat sense una sessi inicialitzada.
	 */
	READONETOMANY_SENSE_SESSIO("No es poden llegir els objectes de les relacions d'un a molts d'una entitat sense una sessi inicialitzada.", 130),
	/**
	 * S'ha produt un error en la lectura dels objectes de les relacions d'un a molts d'una entitat.
	 */
	READONETOMANY_ERROR("S'ha produt un error en la lectura dels objectes de les relacions d'un a molts d'una entitat.", 131),
	/**
	 * No es poden esborrar els registres de les taules de les relacions d'un a molts sense una sessi inicialitzada.
	 */
	DELETEONETOMANY_SENSE_SESSIO("No es poden esborrar els registres de les taules de les relacions d'un a molts sense una sessi inicialitzada.", 132),
	/**
	 * No es poden esborrar els registres de les taules de les relacions d'un a molts d'un objecte que s nul.
	 */
	DELETEONETOMANY_SENSE_OBJ("No es poden esborrar els registres de les taules de les relacions d'un a molts d'un objecte que s nul.", 133),
	/**
	 * S'ha produt un error en l'eliminaci dels registres de les taules de les relacions d'un a molts de l'entitat.
	 */
	DELETEONETOMANY_ERROR("S'ha produt un error en l'eliminaci dels registres de les taules de les relacions d'un a molts de l'entitat.", 137),
	/**
	 * S'ha produt un error en l'obtenci d'un objecte ja llegit.
	 */
	GETOBJECTREAD_ERROR("S'ha produt un error en l'obtenci d'un objecte ja llegit.", 138),
	/**
	 * No es pot obtenir la informaci de les anotacions de les relacions molts a molts d'una entitat sense una sessi inicialitzada.
	 */
	GETMANYTOMANYANNOTATIONDATA_SENSE_SESSIO("No es pot obtenir la informaci de les anotacions de les relacions molts a molts d'una entitat sense una sessi inicialitzada.", 139),
	/**
	 * S'ha produt un error en l'obtenci de la informaci de les anotacions de les relacions motls a molts d'una entitat.
	 */
	GETMANYTOMANYANNOTATIONDATA_ERROR("S'ha produt un error en l'obtenci de la informaci de les anotacions de les relacions motls a molts d'una entitat.", 140),
	/**
	 * S'ha produt un error en la preparaci de les sentncies de les relacions de molts a molts de l'entitat.
	 */
	PREPAREMANYTOMANYQUERIES_ERROR("S'ha produt un error en la preparaci de les sentncies de les relacions de molts a molts de l'entitat.", 141),
	/**
	 * S'ha produt un error en la preparaci de les sentncies CREATE TABLE de les relacions de molts a molts de l'entitat.
	 */
	MANYTOMANYCREATETABLE_ERROR("S'ha produt un error en la preparaci de les sentncies CREATE TABLE de les relacions de molts a molts de l'entitat.", 142),
	/**
	 * S'ha produt un error en la creaci de les taules de les relacions molts a molts de l'entitat.
	 */
	CREATEMANYTOMANYTABLES_ERROR("S'ha produt un error en la creaci de les taules de les relacions molts a molts de l'entitat.", 143),
	/**
	 * No es poden crear les taules de les relacions de molts a molts de l'entitat sense una sessi inicialitzada.
	 */
	CREATEMANYTOMANYTABLES_SENSE_SESSIO("No es poden crear les taules de les relacions de molts a molts de l'entitat sense una sessi inicialitzada.", 144),
	/**
	 * S'ha produt un error en la preparaci de les sentncies DROP TABLE de les relacions de molts a molts de l'entitat.
	 */
	PREPAREMANYTOMANYDROP_ERROR("S'ha produt un error en la preparaci de les sentncies DROP TABLE de les relacions de molts a molts de l'entitat.", 145),
	/**
	 * S'ha produt un error en la preparaci de les sentncies INSERT de les relacions de molts a molts de l'entitat.
	 */
	PREPAREMANYTOMANYINSERT_ERROR("S'ha produt un error en la preparaci de les sentncies INSERT de les relacions de molts a molts de l'entitat.", 146),
	/**
	 * No es poden preparar les sentncies INSERT de les relacions de molts a molts de l'entitat sense una sessi inicialitzada.
	 */
	PREPAREMANYTOMANYINSERT_SENSE_SESSIO("No es poden preparar les sentncies INSERT de les relacions de molts a molts de l'entitat sense una sessi inicialitzada.", 147),
	/**
	 * S'ha produt un error en la inserci dels registres de les relacions molts a molts de l'entitat.
	 */
	INSERTMANYTOMANY_ERROR("S'ha produt un error en la inserci dels registres de les relacions molts a molts de l'entitat.", 148),
	/**
	 * No es poden inserir els registres de les relacions molts a molts de l'entitat sense una sessi inicialitzada.
	 */
	INSERTMANYTOMANY_SENSE_SESSIO("No es poden inserir els registres de les relacions molts a molts de l'entitat sense una sessi inicialitzada.", 149),
	/**
	 * S'ha produt un error en la preparaci de les sentntices SELECT de les relacions de molts a molts de l'entitat.
	 */
	PREPAREMANYTOMANYREAD_ERROR("S'ha produt un error en la preparaci de les sentntices SELECT de les relacions de molts a molts de l'entitat.", 150),
	/**
	 * No es poden preparar les sentncies SELECT de les relacions molts a molts de l'entitat sense una sessi inicialitzada.
	 */
	PREPAREMANYTOMANYREAD_SENSE_SESSIO("No es poden preparar les sentncies SELECT de les relacions molts a molts de l'entitat sense una sessi inicialitzada.", 151),
	/**
	 * S'ha produt un error en la lectura dels registres de les relacions de molts a molts de l'entitat.
	 */
	READMANYTOMANY_ERROR("S'ha produt un error en la lectura dels registres de les relacions de molts a molts de l'entitat.", 152),
	/**
	 * No es poden llegir els registres de les relacions de molts a molts de l'entitat sense una sessi inicialitzada.
	 */
	READMANYTOMANY_SENSE_SESSIO("No es poden llegir els registres de les relacions de molts a molts de l'entitat sense una sessi inicialitzada.", 153),
	/**
	 * S'ha produt un error en la preparaci de la sentncia SELECT per a obtenir els registres de la collecci de les relacions molts a molts.
	 */
	PREPAREMANYTOMANYREADCOLLECTION_ERROR("S'ha produt un error en la preparaci de la sentncia SELECT per a obtenir els registres de la collecci de les relacions molts a molts.", 154),
	/**
	 * No es poden preparar les sentncies SELECT per a obtenir les registres de la collecci de les relacions de molts a molts sense una sessi inicialitzada.
	 */
	PREPAREMANYTOMANYREADCOLLECTION_SENSE_SESSIO("No es poden preparar les sentncies SELECT per a obtenir les registres de la collecci de les relacions de molts a molts sense una sessi inicialitzada.", 155),
	/**
	 * S'ha produt un error en l'eliminaci dels regitres de les relacions de molts a molts de l'entitat.
	 */
	DELETEMANYTOMANY_ERROR("S'ha produt un error en l'eliminaci dels regitres de les relacions de molts a molts de l'entitat.", 156),
	/**
	 * No es poden esborrar els registres de les taules de les relacions molts a molts de l'entitat sense una sessi inicialitzada.
	 */
	DELETEMANYTOMANY_SENSE_SESSIO("No es poden esborrar els registres de les taules de les relacions molts a molts de l'entitat sense una sessi inicialitzada.", 157),
	/**
	 * No es poden esborrar els registres de les taules de les relacions de molts a molts d'un objecte que s nul.
	 */
	DELETEMANYTOMANY_SENSE_OBJ("No es poden esborrar els registres de les taules de les relacions de molts a molts d'un objecte que s nul.", 158);
	
	
	//Text del missatge.
	private String msg		= null;
	
	//Codi del missatge.
	private int code		= -1;
	
	/**
	 * Constructor.
	 * 
	 * @param msg - Text del missatge.
	 * @param code - Codi del missatge.
	 */
	MappingMsg(String msg, int code){
		this.msg = msg;
		this.code = code;
	}
	
	/**
	 * Permet obtenir el text del missatge.
	 * 
	 * @return Un <code>String</code> amb el text del missatge.
	 */
	public String getMsg(){
		return (this.msg);
	}
	
	/**
	 * Permet obtenir el codi del missatge.
	 * 
	 * @return Un <code>int</code> amb el codi del missatge.
	 */
	public int getCode(){
		return (this.code);
	}
}
