package com.uoc.myframeuoc.exceptions;

/**
 * Classe que serveix per a crear excepcions de tipus MyFrameUOC.
 * 
 * @author Jordi Garcia Casanova
 *
 */
public class MyFrameUOCException extends Exception {

	private static final long serialVersionUID = 1L;	
	
	//Indica el tipus o origen de l'excepci.
	private TypeException type		= null;
	
	//Codi de l'excepci.
	private int code				= -1;
	
	/**
	 * Constructor.
	 */
	public MyFrameUOCException() {
	}

	/**
	 * Constructor.
	 * 
	 * @param generalMsg - Un <code>{@link com.uoc.myframeuoc.exceptions.GeneralMsg GeneralMsg}</code> amb 
	 * l'excepci general de MyFrameUOC.
	 */
	public MyFrameUOCException (GeneralMsg generalMsg){
		super(generalMsg.getMsg());
		
		this.type = TypeException.GENERAL;
		this.code = generalMsg.getCode();
	}
	
	/**
	 * Constructor.
	 * 
	 * @param generalMsg - Un <code>{@link com.uoc.myframeuoc.exceptions.GeneralMsg GeneralMsg}</code> amb 
	 * l'excepci general de MyFrameUOC.
	 * @param cause - Possible causa de l'error.
	 */
	public MyFrameUOCException(GeneralMsg generalMsg, String cause){
		super(generalMsg.getMsg() + "\n" + cause);
		
		this.type = TypeException.GENERAL;
		this.code = generalMsg.getCode();
	}
	
	/**
	 * Constructor.
	 * 
	 * @param environmentMsg - Un <code>{@link com.uoc.myframeuoc.exceptions.EnvironmentMsg EnvironmentMsg}</code>
	 * amb l'excepci que s'ha produt en el paquet <i>Environment</i>.
	 */
	public MyFrameUOCException(EnvironmentMsg environmentMsg){
		super(environmentMsg.getMsg());
		
		this.type = TypeException.ENVIRONMENT;
		this.code = environmentMsg.getCode();
	}
	
	/**
	 * Constructor.
	 * 
	 * @param environmentMsg - Un <code>{@link com.uoc.myframeuoc.exceptions.EnvironmentMsg EnvironmentMsg}</code>
	 * amb l'excepci que s'ha produt en el paquet <i>Environment</i>.
	 * @param cause - Possible causa de l'error.
	 */
	public MyFrameUOCException(EnvironmentMsg environmentMsg, String cause){
		super(environmentMsg.getMsg() + "\n" + cause);
		
		this.type = TypeException.ENVIRONMENT;
		this.code = environmentMsg.getCode();
	}
	
	/**
	 * Constructor.
	 * 
	 * @param dataBaseMsg - Un <code>{@link com.uoc.myframeuoc.exceptions.DataBaseMsg DataBaseMsg}</code> amb
	 * l'excepci que s'ha produt en el paquet <i>DataBase</i>.
	 */
	public MyFrameUOCException(DataBaseMsg dataBaseMsg){
		super(dataBaseMsg.getMsg());
		
		this.type = TypeException.DATABASE;
		this.code = dataBaseMsg.getCode();
	}
	
	/**
	 * Constructor.
	 * 
	 * @param dataBaseMsg - Un <code>{@link com.uoc.myframeuoc.exceptions.DataBaseMsg DataBaseMsg}</code> amb
	 * l'excepci que s'ha produt en el paquet <i>DataBase</i>.
	 * @param cause - Possible causa de l'error.
	 */
	public MyFrameUOCException(DataBaseMsg dataBaseMsg, String cause){
		super(dataBaseMsg.getMsg() + "\n" + cause);
		
		this.type = TypeException.DATABASE;
		this.code = dataBaseMsg.getCode();
	}
	
	/**
	 * Constructor.
	 * 
	 * @param queryManagementMsg - Un <code>{@link com.uoc.myframeuoc.exceptions.QueryManagementMsg QueryManagementMsg}</code> amb
	 * l'excepci que s'ha produt en el paquet <i>QueryManagement</i>.
	 */
	public MyFrameUOCException(QueryManagementMsg queryManagementMsg){
		super(queryManagementMsg.getMsg());
		
		this.type = TypeException.QUERYMANAGEMENT;
		this.code = queryManagementMsg.getCode();
	}
	
	/**
	 * Constructor.
	 * 
	 * @param queryManagementMsg - Un <code>{@link com.uoc.myframeuoc.exceptions.QueryManagementMsg QueryManagementMsg}</code> amb
	 * l'excepci que s'ha produt en el paquet <i>QueryManagement</i>.
	 * @param cause
	 */
	public MyFrameUOCException(QueryManagementMsg queryManagementMsg, String cause){
		super(queryManagementMsg.getMsg() + "\n" + cause);
		
		this.type = TypeException.QUERYMANAGEMENT;
		this.code = queryManagementMsg.getCode();
	}

	/**
	 * Constructor.
	 * 
	 * @param mappingMsg - Un <code>{@link com.uoc.myframeuoc.exceptions.MappingMsg MappingMsg}</code> amb 
	 * l'excepci que s'ha produt en el paquet <i>Mapping</i>.
	 */
	public MyFrameUOCException(MappingMsg mappingMsg){
		super(mappingMsg.getMsg());
		
		this.type = TypeException.MAPPING;
		this.code = mappingMsg.getCode();
	}
	
	/**
	 * Constructor.
	 * 
	 * @param mappingMsg - Un <code>{@link com.uoc.myframeuoc.exceptions.MappingMsg MappingMsg}</code> amb 
	 * l'excepci que s'ha produt en el paquet <i>Mapping</i>.
	 * @param cause - Possible causa de l'error.
	 */
	public MyFrameUOCException(MappingMsg mappingMsg, String cause){
		super(mappingMsg.getMsg() + "\n" + cause);
		
		this.type = TypeException.MAPPING;
		this.code = mappingMsg.getCode();
	}
	/**
	 * Permet obtenir el tipus o l'origen de l'excepci.
	 * 
	 * @return Un <code>{@link com.uoc.myframeuoc.exceptions.TypeException TypeException}</code>
	 */
	public TypeException getType(){
		return (this.type);
	}
	
	public int getCode(){
		return (this.code);
	}
}
