package com.uoc.myframeuoc.exceptions;

/**
 * Aquest <code>Enum</code> serveix per a emmagatzemar els missatges d'error
 * que es produeixen en el paquet <i>QueryManagement</i>.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
public enum QueryManagementMsg {
	/**
	 * No hi ha una taula associada a la consulta.
	 */
	NO_TAULA("No hi ha una taula associada a la consulta.", 1),
	/**
	 * No s'han afegit parells camp-valor en la sentncia.
	 */
	NO_PARELLS_CAMP_VALOR("No s'han afegit parells camp-valor en la sentncia.", 2),
	/**
	 * S'ha produt un error en la construcci de la sentncia INSERT.
	 */
	ERROR_CONSTRUCCIO_INSERT("S'ha produt un error en la construcci de la sentncia INSERT.", 3),
	/**
	 * La sentncia SELECT no t camps per a projectar.
	 */
	SELECT_SENSE_CAMPS("La sentncia SELECT no t camps per a projectar.", 4),
	/**
	 * La sentncia UPDATE no t cap parell camp-valor del SET.
	 */
	UPDATE_SENSE_PARELLS("La sentncia UPDATE no t cap parell camp-valor del SET.", 5),
	/**
	 * No es pot crear una condici sense un operador relacional o de comparaci.
	 */
	CONDICIO_SENSE_OPERADOR_RELACIONAL("No es pot crear una condici sense un operador relacional o de comparaci.",6),
	/**
	 * No es pot crear una condici sense un parell de camp-valor.
	 */
	CONDICIO_SENSE_PARELL("No es pot crear una condici sense un parell de camp-valor.", 7),
	/**
	 * No es pot crear una sentncia SQL sense indicar una taula.
	 */
	SENTENCIA_SENSE_TAULA("No es pot crear una sentncia SQL sense indicar una taula.", 8),
	/**
	 * No es pot crear un parell camp-valor sense el camp.
	 */
	PARELL_SENSE_CAMP("No es pot crear un parell camp-valor sense el camp.", 9),
	/**
	 * No es pot crear un parell camp-valor sense el valor.
	 */
	PARELL_SENSE_VALOR("No es pot crear un parell camp-valor sense el valor.", 10),
	/**
	 * No es pot crear un camp sense nom.
	 */
	CAMP_SENSE_NOM("No es pot crear un camp sense nom.", 11),
	/**
	 * No es pot crear una restricci d'una sentncia SQL sense una condici.
	 */
	RESTRICCIO_SENSE_CONDICIO("No es pot crear una restricci d'una sentncia SQL sense una condici.", 12),
	/**
	 * No es pot afegir una condici en una restricci sense un operador lgic.
	 */
	CONDICIO_AFEGIDA_SENSE_OPERADOR_LOGIC("No es pot afegir una condici en una restricci sense un operador lgic.", 13),
	/**
	 * No es pot afegir una condici nulla en una restricci.
	 */
	CONDICIO_AFEGIDA_NULA("No es pot afegir una condici nulla en una restricci.", 14),
	/**
	 * No es pot crear una restricci o constraint sense nom.
	 */
	CONSTRAINT_SENSE_NOM("No es pot crear una restricci o constraint sense nom.", 15),
	/**
	 * La restricci no t camps.
	 */
	CONSTRAINT_SENSE_CAMPS("La restricci no t camps.", 16),
	/**
	 * No es pot crear una restricci o constraint sense indicar el seu tipus.
	 */
	CONSTRAINT_SENSE_TIPUS("No es pot crear una restricci o constraint sense indicar el seu tipus.", 17),
	/**
	 * La sentncia CREATE TABLE no t columnes definides.
	 */
	CREATE_TABLE_SENSE_COLUMNES("La sentncia CREATE TABLE no t columnes definides.", 18),
	/**
	 * No es pot crear una clau forana sense nom.
	 */
	CLAUFORANA_SENSE_NOM("No es pot crear una clau forana sense nom.", 19),
	/**
	 * No es pot crear una clau forana sense taula de referncia.
	 */
	CLAUFORANA_SENSE_TAULA("No es pot crear una clau forana sense taula de referncia.", 20),
	/**
	 * La restricci o constraint de clau forana no t camps.
	 */
	CLAUFORANA_SENSE_CAMPS("La restricci o constraint de clau forana no t camps.", 21),
	/**
	 * No es pot crear una sentncia CREATE TABLE sense una sessi inicialitzada.
	 */
	CREATE_TABLE_SENSE_SESSIO("No es pot crear una sentncia CREATE TABLE sense una sessi inicialitzada.", 22),
	/**
	 * No es pot crear una sentncia ALTER TABLE sense una sessi inicialitzada.
	 */
	ALTER_TABLE_SENSE_SESSIO("No es pot crear una sentncia ALTER TABLE sense una sessi inicialitzada.", 23),
	/**
	 * La sentncia ALTER TABLE no t claus foranes.
	 */
	ALTER_TABLE_SENSE_CLAUS_FORANES("La sentncia ALTER TABLE no t claus foranes.", 24),
	/**
	 * No es pot crear una sentncia INSERT sense una sessi inicialitzada.
	 */
	INSERT_SENSE_SESSIO("No es pot crear una sentncia INSERT sense una sessi inicialitzada.", 25),
	/**
	 * No es pot crear una sentncia SELECT sense una sessi inicialitzada.
	 */
	SELECT_SENSE_SESSIO("No es pot crear una sentncia SELECT sense una sessi inicialitzada.", 26),
	/**
	 * No es pot crear una sentncia UPDATE sense una sessi inicialitzada.
	 */
	UPDATE_SENSE_SESSIO("No es pot crear una sentncia UPDATE sense una sessi inicialitzada.", 27),
	/**
	 * No es pot crear una sentncia DELETE sense una sessi inicicalitzada.
	 */
	DELETE_SENSE_SESSIO("No es pot crear una sentncia DELETE sense una sessi inicicalitzada.", 28),
	/**
	 * No es pot crear una sentncia ALTER TABLE sense indicar el seu tipus.
	 */
	ALTERTABLE_SENSE_TIPUS("No es pot crear una sentncia ALTER TABLE sense indicar el seu tipus.", 29);
	
	//Text del missatge.
	private String msg		= null;
	
	//Codi del missatge.
	private	int code		= -1;
	
	/**
	 * Constructor.
	 * 
	 * @param msg - Text del missatge.
	 * @param code - Codi del missatge.
	 */
	QueryManagementMsg(String msg, int code){
		this.msg = msg;
		this.code = code;
	}
	
	/**
	 * Permet obtenir el text del missatge.
	 * 
	 * @return Un <code>String</code> amb el text del missatge.
	 */
	public String getMsg(){
		return (this.msg);
	}
	
	/**
	 * Permet obtenir el codi del missatge.
	 * 
	 * @return Un <code>int</code> amb el codi del missatge.
	 */
	public int getCode(){
		return (this.code);
	}
}
