package com.uoc.myframeuoc.mapping;

import com.uoc.myframeuoc.environment.Session;
import com.uoc.myframeuoc.exceptions.MappingMsg;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;

/**
 * Classe que representa i gestiona les associacions entre entitats.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
public class AssociationMap {

	//Taula amb la qual s'implementa la relaci.
	private String table		= null;
	
	//Nom de l'atribut de la relaci de l'entitat.
	private String property		= null;
	
	//Entitat amb la qual es relaciona l'entitat.
	private RegisteredEntity entity		= null;
	
	/**
	 * Constructor.
	 * 
	 * @param table - Taula amb la qual s'implementa la relaci.
	 * @param property - Nom de l'atribut de la relaci de l'entitat.
	 * @param nameEntity - Nom de l'entitat de la relaci.
	 * @param session - Session de MyFrameUOC que s'utilitza.
	 * 
	 * @throws MyFrameUOCException 
	 */
	public AssociationMap(String table, String property, String nameEntity, Session session) throws MyFrameUOCException {
		if (property == null || "".equals(property)){
			//Error => No es pot crear una relaci sense l'atribut de l'entitat.
			throw new MyFrameUOCException(MappingMsg.RELACIO_SENSE_ATRIBUT);
		}
		if (nameEntity == null || "".equals(nameEntity)){
			//Error => No es pot crear una relaci sense el nom de l'entitat amb el que es relaciona una entitat.
			throw new MyFrameUOCException(MappingMsg.RELACIO_SENSE_ENTITAT);
		}

		if (session == null){
			//Error => No es pot crear una relaci sense una sessi inicialitzada.
			throw new MyFrameUOCException(MappingMsg.RELACIO_SENSE_SESSIO);
		}
		
		this.table = table;
		this.property = property;
		this.entity = session.getEntityManager().registerEntity(nameEntity, session, false);
	}

	/**
	 * Permet obtenir el nom de la taula amb la qual s'implementa la relaci.
	 * 
	 * @return Un <code>String</code> amb el nom de la taula amb la qual s'implementa
	 * la relaci. Si la relalci no s'implementa amb una taula, llavors es retorna
	 * nul.
	 */
	public String getTable(){
		return (this.table);
	}
	
	/**
	 * Permet obtenir el nom de l'atribut de la relaci de l'entitat.
	 * 
	 * @return Un <code>String</code> amb el nom de l'atribut de la relaci de l'entitat.
	 */
	public String getProperty(){
		return (this.property);
	}
	
	/**
	 * Permet obtenir l'entitat de la relaci.
	 * 
	 * @return Un <code>{@link com.uoc.myframeuoc.mapping.RegisteredEntity Entity}</code> que cont
	 * l'entitat de la relaci.
	 */
	public RegisteredEntity getEntity(){
		return (this.entity);
	}
}
