package com.uoc.myframeuoc.mapping;

import com.uoc.myframeuoc.environment.Session;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;
import com.uoc.myframeuoc.querymanagement.Select;

/**
 * Classe que representa i gestiona les relacions de molts a molts mapejades.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
public class ManyToManyMap extends BinaryAssociationMap {

	//Sentncia SQL preparada que serveix per a llegir els registre de la collecci de la relaci de molts a molts.
	private Select preparedSqlReadCollection		= null;
	
	/**
	 * Constructor.
	 * 
	 * @param table - Nom de la taula que s'utilitza per a implementar la relaci de molts a molts.
	 * @param property - Nom de l'atribut de l'entitat que fa de relaci de molts a molts (s la <code>Collection</code>
	 * cap a l'entitat dest de la relaci).
	 * @param nameEntity - Nom de l'entitat dest de la relaci.
	 * @param session - Sessi de MyFrameUOC que s'utilitza.
	 * @param nameFKTo - Nom de la clau forana de la taula de la relaci cap a l'entitat dest.
	 * @param nameFKFrom - Nom de la clau forana de la taula de la relaci cap a l'entitat origen.
	 * @param fieldsTo - Correspondncia entre els camps de la clau forana i els atributs de l'entitat dest.
	 * @param fieldsFrom - Correspondncia entre els camps de la clau forana i els atributs de l'entitat origen.
	 * 
	 * @throws MyFrameUOCException Si no es pot crear la relaci de molts a molts mapejada.
	 */
	public ManyToManyMap(String table, String property, String nameEntity,
			Session session, String nameFKTo, String nameFKFrom,
			String fieldsTo, String fieldsFrom) throws MyFrameUOCException {
		super(table, property, nameEntity, session, nameFKTo, nameFKFrom,
				fieldsTo, fieldsFrom);
	}

	/**
	 * Permet obtenir la sentncia SELECT per a llegir els registres de la collecci de la
	 * relaci de molts a molts.
	 * 
	 * @return Un <code>{@link com.uoc.myframeuoc.querymanagement.Select Select} que cont la sentncia
	 * SELECT que permet obtenir els registres de la collecci de la relaci de molts a molts.
	 */
	public Select getPreparedSqlReadCollection() {
		return preparedSqlReadCollection;
	}

	/**
	 * Defineix la sentncia SELECT que permet obtenir els registres de la collecci de la relaci
	 * de molts a molts.
	 * 
	 * @param preparedSqlReadCollection - Un <code>{@link com.uoc.myframeuoc.querymanagement.Select Select} que cont la sentncia
	 * SELECT que permet obtenir els registres de la collecci de la relaci de molts a molts.
	 */
	public void setPreparedSqlReadCollection(Select preparedSqlReadCollection) {
		this.preparedSqlReadCollection = preparedSqlReadCollection;
	}

	
}
