package com.uoc.myframeuoc.mapping;

import com.uoc.myframeuoc.database.TypeMap;
import com.uoc.myframeuoc.exceptions.MappingMsg;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;

/**
 * Classe que representa i gestiona el mapeig d'una clau primria.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
public class PrimaryKeyMap extends FieldMap {

	//Nom que t la clau primria dins de la taula de la base de dades.
	private String name		= null;
	
	/**
	 * Constructor.
	 * 
	 * @param property - Nom de l'atribut que es mapeja.
	 * @param field - Nom de la columna de la taula amb la qual es vincula l'atribut.
	 * @param typeMap - Tipus de dades mapejat que li correspon a l'atribut mapejat.
	 * @param precision - Precisi del camp numric de la taula.
	 * @param scale - Escala del camp numric de la taula.
	 * @param length - Mida en carcters o bytes del camp de la taula.
	 * @param name - Nom que t la clau primria en la taula de la base de dades.
	 * 
	 * @throws MyFrameUOCException Si no es pot crear la clau primria mapejada.
	 */
	public PrimaryKeyMap(String property, String field, TypeMap typeMap, Integer precision, Integer scale, Integer length, 
			String name) throws MyFrameUOCException {
		super(property, field, typeMap, precision, scale, length, false, true);
		
		if (name == null || "".equals(name)){
			//Error => No es pot crear el mapeig d'una clau primria sense indicar el nom que t en la taula de la BD.
			throw new MyFrameUOCException(MappingMsg.CLAUPRIMARIA_SENSE_NOM);
		}
		this.name = name;
	}

	/**
	 * Permet obtenir el nom que t la clau primria en la taula de la base de dades.
	 * 
	 * @return Un <code>String</code> amb el nom que t la clau primria en la taula de la base de dades.
	 */
	public String getName(){
		return (this.name);
	}
}
