package com.uoc.myframeuoc.querymanagement;

import java.util.ArrayList;

import com.uoc.myframeuoc.exceptions.MyFrameUOCException;

/**
 * Classe que representa i gestiona les sentncies ALTER TABLE en MySQL.
 * 
 * @author Jordi Garcia Casnaova
 *
 */
public class AlterTableMySQL extends AlterTable {

	/**
	 * Constructor.
	 * 
	 * @param table - Nom de la taula que participa en la sentncia ALTER TABLE.
	 * @param type - Tipus de sentncia ALTER TABLE.
	 * 
	 * @throws MyFrameUOCException Si no es pot crear la sentncia ALTER TABLE en MySQL.
	 */
	public AlterTableMySQL(String table, AlterTableType type) throws MyFrameUOCException {
		super(table, type);
	}

	/**
	 * Permet obtenir la sentncia ALTER TABLE construda en MySQL.
	 * 
	 * @return Un <code>String</code< amb la sentncia ALTER TABLE 
	 * construda en MySQL.
	 */
	@Override
	public String getQuery() throws MyFrameUOCException {
		String query											= null;
		ArrayList<ForeignKeyConstraint> foreignKeyConstraints	= null;
		int elements;
		
		//Validar les propietats de la sentncia ALTER TABLE.
		this.validateQuery();
		foreignKeyConstraints = this.getForeignKeyConstraints();
		elements = foreignKeyConstraints.size();

		if (AlterTableType.ADD == this.getType()){
			//query = "ALTER TABLE " + this.getTable() + " ADD " + foreignKeyConstraints.get(0).getForeignKeyConstraint();
			query = "ALTER TABLE " + this.getTable() + " ADD " + foreignKeyConstraints.get(0).getForeignKeyConstraint() + " ON DELETE CASCADE";
		}
		else if (AlterTableType.DROP == this.getType()){
			query = "ALTER TABLE " + this.getTable() + " DROP FOREIGN KEY " + foreignKeyConstraints.get(0).getName();
		}
		for (int i = 1; i < elements; i++){
			if (AlterTableType.ADD == this.getType()){
				//query += ", ADD " + foreignKeyConstraints.get(i).getForeignKeyConstraint();
				query += ", ADD " + foreignKeyConstraints.get(i).getForeignKeyConstraint() + " ON DELETE CASCADE";
			}
			else if (AlterTableType.DROP == this.getType()){
				query += ", DROP FOREIGN KEY " + foreignKeyConstraints.get(i).getName();
			}
		}
		return (query);
	}

}
