package com.uoc.myframeuoc.querymanagement;

import java.util.ArrayList;

import com.uoc.myframeuoc.exceptions.MyFrameUOCException;

/**
 * Classe que representa una sentncia CREATE TABLE en Oracle.
 * 
 * @author Jordi Garcia Casanova
 *
 */
public class CreateTableOracle extends CreateTable {

	/**
	 * Constructor.
	 * 
	 * @param table - Nom de la taula que participa en la sentncia CREATE TABLE.
	 * 
	 * @throws MyFrameUOCException
	 */
	public CreateTableOracle(String table) throws MyFrameUOCException {
		super(table);
	}

	/**
	 * Permet obtenir la sentncia CREATE TABLE construda en Oracle.
	 * 
	 * @exception MyFrameUOCException Si no es pot obtenir la sentncia CREATE TABLE construda en Oracle.
	 */
	@Override
	public String getQuery() throws MyFrameUOCException {
		String query											= null;
		int elements											= 0;
		FieldValuePair pair										= null;
		ArrayList<FieldValuePair> columns						= null;
		ArrayList<Constraint> constraints						= null;
		ArrayList<ForeignKeyConstraint> foreignKeyConstraints	= null;
		
		//Validar les propietats de la sentncia CREATE TABLE.
		this.validateQuery();
		
		columns = this.getColumns();
		constraints = this.getConstraints();
		foreignKeyConstraints = this.getFKConstraints();
		
		query = "CREATE TABLE " + this.getTable() + "(";
		elements = columns.size();
		pair = columns.get(0);
		query += pair.getField().getName() + " " + pair.getValue();
		for (int i = 1; i < elements; i++){
			pair = columns.get(i);
			query += ", " + pair.getField().getName() + " " + pair.getValue(); 
		}
		if (constraints != null && constraints.size() > 0){
			elements = constraints.size();
			query += ", " + constraints.get(0).getConstraint();
			for (int i = 1; i < elements; i++){
				query += ", " + constraints.get(i).getConstraint();
			}
		}
		if (foreignKeyConstraints != null && foreignKeyConstraints.size() > 0){
			for (ForeignKeyConstraint fk: foreignKeyConstraints){
				//query += ", " + fk.getForeignKeyConstraint();
				query += ", " + fk.getForeignKeyConstraint() + " ON DELETE CASCADE";
			}
		}
		query += ")";
		return (query);
	}
}
