package com.uoc.myframeuoc.querymanagement;

import com.uoc.myframeuoc.environment.Configuration;
import com.uoc.myframeuoc.environment.SGBDType;
import com.uoc.myframeuoc.environment.Session;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;
import com.uoc.myframeuoc.exceptions.QueryManagementMsg;

/**
 * Classe que representa una sentncia DELETE.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
public abstract class Delete extends RestrictionQuery {

	/**
	 * Constructor.
	 * 
	 * @param table - Nom de la taula associada la sentncia DELETE.
	 * 
	 * @throws MyFrameUOCException 
	 */
	protected Delete(String table) throws MyFrameUOCException {
		super(table);
	}

	/**
	 * Permet obtenir la sentncia DELETE construda.
	 * 
	 * @return Un <code>String</code> amb la sentncia DELETE construda.
	 */
	@Override
	public abstract String getQuery() throws MyFrameUOCException;

	/**
	 * Valida les propietas de la sentncia DELETE.
	 */
	@Override
	public void validateQuery() throws MyFrameUOCException {
		super.validateQuery();
	}
	
	/**
	 * Permet obtenir una sentncia DELETE inicialitzada.
	 * 
	 * @param session - Sessi de MyFrameUOC que s'utilitza.
	 * @param table - Nom de la taula que participa en la sentncia DELETE.
	 * 
	 * @return Un <code>{@link com.uoc.myframeuoc.querymanagement.Delete Delete}</code> que
	 * cont la sentncia DELETE inicialitzada.
	 * 
	 * @throws MyFrameUOCException Si no es pot obtenir la sentncia DELETE inicialitzada. 
	 */
	public static Delete getDelete(Session session, String table) throws MyFrameUOCException{
		Delete delete					= null;
		Configuration configuration		= null;
		SGBDType sgbd					= null;
		
		if (session == null){
			//Error => La sessi no est inicialitzada.
			throw new MyFrameUOCException(QueryManagementMsg.DELETE_SENSE_SESSIO);
		}
		configuration = session.getConfiguration();
		sgbd = configuration.getSGBD();
		if (SGBDType.Oracle.name().equals(sgbd.name())){
			delete = new DeleteOracle(table);
		}
		else if (SGBDType.MySQL.name().equals(sgbd.name())){
			delete = new DeleteMySQL(table);
		}
		return (delete);
	}
}
