package com.uoc.myframeuoc.querymanagement;

import com.uoc.myframeuoc.exceptions.MyFrameUOCException;

/**
 * Classe que representa i gestiona les sentncies DELETE en MySQL.
 * 
 * @author Jordi Garcia Casanova
 *
 */
public class DeleteMySQL extends Delete {

	/**
	 * Constructor.
	 * 
	 * @param table - Nom de la taula que participa en la sentncia DELETE.
	 * 
	 * @throws MyFrameUOCException Si no es pot crear la sentncia DELETE.
	 */
	public DeleteMySQL(String table) throws MyFrameUOCException {
		super(table);
	}

	/**
	 * Permet obtenir la sentncia DELETE construda en MySQL.
	 * 
	 * @return Un <code>String</code> amb la sentncia DELETE construda en MySQL.
	 * 
	 * @exception MyFrameUOCException Si no es pot obtenir la sentncia DELETE construda en MySQL.
	 */
	@Override
	public String getQuery() throws MyFrameUOCException {
		String query	= null;
		
		//Validar la sentncia DELETE.
		this.validateQuery();
		
		query = "DELETE FROM " + this.getTable();
		if (this.hasRestriction()){
			query += " " + this.getRestrictionQuery();
		}
		return (query);
	}
}
