package com.uoc.myframeuoc.querymanagement;

import com.uoc.myframeuoc.environment.Configuration;
import com.uoc.myframeuoc.environment.SGBDType;
import com.uoc.myframeuoc.environment.Session;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;
import com.uoc.myframeuoc.exceptions.QueryManagementMsg;

/**
 * Classe que representa i gestiona les sentncies DROP TABLE.
 * 
 * @author Jordi Garcia Casanova
 *
 */
public abstract class Drop extends Query {

	/**
	 * Constructor.
	 * 
	 * @param table - Nom de la taula participa en al sentncia (la qual s'esborrar).
	 * 
	 * @throws MyFrameUOCException Si no es pot crear la sentncia DROP TABLE.
	 */
	public Drop(String table) throws MyFrameUOCException {
		super(table);
	}

	/**
	 * Permet obtenir la sentncia DROP TABLE construda.
	 * 
	 * @return Un <code>String</code> amb la sentncia DROP TABLE construda.
	 * 
	 * @exception MyFrameUOCException Si no es pot obtenir la sentncia DROP TABLE construda.
	 */
	@Override
	public abstract String getQuery() throws MyFrameUOCException;

	/**
	 * Permet validar les propietats de la sentncia DROP TABLE.
	 */
	@Override
	public void validateQuery() throws MyFrameUOCException {
		super.validateQuery();
	}
	
	/**
	 * Permet obtenir una sentncia DROP TABLE inicialitzada.
	 * 
	 * @param session - Sessi de MyFrameUOC que s'utilitza.
	 * @param table - Nom de la taula que participa en la sentncia (la qual s'esborrar).
	 * 
	 * @return Un <code>{@link com.uoc.myframeuoc.querymanagement.Drop Drop}</code> que cont
	 * la sentncia DROP TABLE inicialitzada.
	 * 
	 * @throws MyFrameUOCException Si no es pot obtenir la sentncia DROP TABLE inicialitzada. 
	 */
	public static Drop getDrop(Session session, String table) throws MyFrameUOCException{
		Drop drop						= null;
		Configuration configuration		= null;
		SGBDType sgbd					= null;
		
		if (session == null){
			//Error => La sessi no est inicialitzada.
			throw new MyFrameUOCException(QueryManagementMsg.SELECT_SENSE_SESSIO);
		}
		configuration = session.getConfiguration();
		sgbd = configuration.getSGBD();
		
		if (SGBDType.Oracle.name().equals(sgbd.name())){
			drop = new DropOracle(table); 
		}
		else if (SGBDType.MySQL.name().equals(sgbd.name())){
			drop = new DropMySQL(table);
		}
		return (drop);
	}

	
}
