package com.uoc.myframeuoc.querymanagement;

import com.uoc.myframeuoc.exceptions.MyFrameUOCException;
import com.uoc.myframeuoc.exceptions.QueryManagementMsg;

/**
 * Classe que representa un parell camp-valor.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
public class FieldValuePair {

	//Camp.
	private Field field		= null;
	//Valor.
	private String value	= null;
	
	/**
	 * Constructor.
	 * 
	 * @param field - Camp.
	 * @param value - Valor.
	 * 
	 * @throws MyFrameUOCException 
	 */
	public FieldValuePair(Field field, String value) throws MyFrameUOCException {
		if (field == null){
			//Error => No es pot crear un parell de camp-valor sense el camp.
			throw new MyFrameUOCException(QueryManagementMsg.PARELL_SENSE_CAMP);
		}
		if (value == null || "".equals(value)){
			//Error => No es pot crear un parell de camp-valor sense un valor.
			throw new MyFrameUOCException(QueryManagementMsg.PARELL_SENSE_VALOR);
		}
		
		this.field = field;
		this.value = value;
	}
	
	/**
	 * Constructor.
	 * 
	 * @param nameField - Nom del camp.
	 * @param value - Valor.
	 * 
	 * @throws MyFrameUOCException 
	 */
	public FieldValuePair(String nameField, String value) throws MyFrameUOCException{
		Field field		= null;
		
		field = new Field(nameField);
		if (value == null || "".equals(value)){
			//Error => No es pot crear un parell de camp-valor sense un valor.
			throw new MyFrameUOCException(QueryManagementMsg.PARELL_SENSE_VALOR);
		}
		this.field = field;
		this.value = value;
	}
	
	/**
	 * Permet obtenir el camp del parell camp-valor.
	 * 
	 * @return Un <code>{@link com.uoc.myframeuoc.querymanagement.Field Field}</code> que 
	 * cont el camp del parell camp-valor. 
	 */
	public Field getField(){
		return (this.field);
	}
	
	/**
	 * Permet obtenir el valor del parell camp-valor.
	 * 
	 * @return Un <code>String</code> amb el valor del parell camp-valor.
	 */
	public String getValue(){
		return (this.value);
	}

	/**
	 * Permet obtenir la assignaci de la forma 'camp = valor'.
	 * 
	 * @return Un <code>String</code> amb l'assginaci 'camp = valor'.
	 */
	public String getAssignment(){
		String assignacio	= null;
		
		assignacio = this.field.getName() + " = " + this.value;
		
		return (assignacio);
	}
}
