package com.uoc.myframeuoc.querymanagement;

import java.util.ArrayList;

import com.uoc.myframeuoc.exceptions.MyFrameUOCException;
import com.uoc.myframeuoc.exceptions.QueryManagementMsg;

/**
 * Classe que representa i gestiona les sentncies INSERT en Oracle.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
public class InsertOracle extends Insert {

	/**
	 * Constructor.
	 * 
	 * @param table - Nom de la taula que participa en la sentncia INSERT.
	 * 
	 * @throws MyFrameUOCException Si no es pot crear la sentncia INSERT.
	 */
	public InsertOracle(String table) throws MyFrameUOCException {
		super(table);
	}

	/**
	 * Permet obtenir la sentncia INSERT construda en Oracle.
	 * 
	 * @return Un <code>String</code> amb la sentncia INSERT construda en Oracle.
	 * 
	 * @exception MyFrameUOCException Si no es pot obtenir la sentncia INSERT construda en Oracle.
	 */
	@Override
	public String getQuery() throws MyFrameUOCException {
		String query						= null;
		int elements						= 0;
		FieldValuePair pair					= null;
		String values						= null;
		ArrayList<FieldValuePair> pairs		= null;
		
		//Validar les propietats de la sentncia INSERT.
		this.validateQuery();
		
		try{
			pairs = this.getFieldValuePairs();
			query = "INSERT INTO " + this.getTable() + "(";
			elements = pairs.size();
			pair = pairs.get(0);
			query += pair.getField().getName();
			values = "VALUES(";
			values += pair.getValue();
			for (int i = 1; i < elements; i++){
				pair = pairs.get(i);
				query += ", " + pair.getField().getName();
				values += ", " + pair.getValue();
			}
			query += ") " + values + ")";
		}
		catch (Exception e){
			//Error => S'ha produt un error en la construcci de la sentncia INSERT.
			throw new MyFrameUOCException(QueryManagementMsg.ERROR_CONSTRUCCIO_INSERT, e.getMessage());
		}
		return (query);
	}
}
