package com.uoc.myframeuoc.querymanagement;

import com.uoc.myframeuoc.exceptions.MyFrameUOCException;
import com.uoc.myframeuoc.exceptions.QueryManagementMsg;

/**
 * Classe que representa i gestiona una consulta SQL preparada per a ser utilitzada
 * en MyFrameUOC. 
 * 
 * @author Jordi Garcia Casanova.
 *
 */
public abstract class Query{

	//Nom de la taula que interv en la sentncia SQL.
	private String table			= null;
	
	/**
	 * Constructor.
	 * 
	 * @param table - Taula que interv en la sentncia SQL.
	 * 
	 * @throws MyFrameUOCException 
	 */
	protected Query(String table) throws MyFrameUOCException {
		if (table == null || "".equals(table)){
			//Error => No es pot crear una sentncia SQL sense una taula.
			throw new MyFrameUOCException(QueryManagementMsg.SENTENCIA_SENSE_TAULA);
		}
		this.table = table;
	}
	
	/**
	 * Permet obtenir la conulta SQL construda.
	 * 
	 * @return Un <code>String</code> amb la consulta SQL preparada.
	 */
	public abstract String getQuery() throws MyFrameUOCException;
	
	/**
	 * Valida que les propietats generals d'una sentncia estiguin
	 * inicialitzades.
	 *  
	 */
	public void validateQuery() throws MyFrameUOCException{
		if (this.table == null || "".equals(table)){
			//Error => No hi ha una taula associada a la sentncia.
			throw new MyFrameUOCException(QueryManagementMsg.NO_TAULA);
		}
	}
	
	/**
	 * Permet obtenir el nom de la taula associad a la sentncia.
	 * 
	 * @return Un <code>String</code> amb el nom de la taula associada a la
	 * sentncia.
	 */
	public String getTable(){
		return (this.table);
	}
}
