package com.uoc.myframeuoc.querymanagement;

/**
 * Aquest <code>Enum</code> serveix per a emmagatzemar els operados relacionals o de
 * comparaci que es poden utilitzar en les condicions d'una sentncia SQL:
 * <br><br>
 * <li>
 * {@link com.uoc.myframeuoc.querymanagement.RelationalOperator#EQUAL EQUAL}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.querymanagement.RelationalOperator#NOT_EQUAL NOT_EQUAL}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.querymanagement.RelationalOperator#GREATER GREATER}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.querymanagement.RelationalOperator#LESS LESS}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.querymanagement.RelationalOperator#IS_NULL IS_NULL}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.querymanagement.RelationalOperator#IS_NOT_NULL IS_NOT_NULL}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.querymanagement.RelationalOperator#GREATER_OR_EQUAL GREATER_OR_EQUAL}
 * </li>
 * <li>
 * {@link com.uoc.myframeuoc.querymanagement.RelationalOperator#LESS_OR_EQUAL LESS_OR_EQUAL}
 * </li>
 * <br><br>
 * @author Jordi Garcia Casanova.
 *
 */
public enum RelationalOperator {
	/**
	 * Operador 'igual que' (=).
	 */
	EQUAL("="),
	/**
	 * Operador 'diferent a' (<>).
	 */
	NOT_EQUAL("<>"),
	/**
	 * Operador 'ms gran que' (>).
	 */
	GREATER(">"),
	/**
	 * Operador 'ms petit que' (<).
	 */
	LESS("<"),
	/**
	 * Operador 's nul' (IS NULL).
	 */
	IS_NULL("IS NULL"),
	/**
	 * Operaodor 'no s nul' (IS NOT NULL).
	 */
	IS_NOT_NULL("IS NOT NULL"),
	/**
	 * Operador 'ms gran o igual que' (>=).
	 */
	GREATER_OR_EQUAL(">="),
	/**
	 * Operador 'ms petit o igual que' (<=).
	 */
	LESS_OR_EQUAL("<=");
	
	//Operador relacional o de comparaci.
	private String operator	= null;
	
	/**
	 * Constructor.
	 * 
	 * @param operator - Operador.
	 */
	RelationalOperator(String operator){
		this.operator = operator;
	}
	
	/**
	 * Permet obtenir l'operador relacional o de comparaci.
	 * 
	 * @return Un <code>String</code> amb l'operador relacional o de
	 * comparaci.
	 */
	public String getOperator(){
		return (this.operator);
	}
}
