package com.uoc.myframeuoc.querymanagement;

import com.uoc.myframeuoc.exceptions.MyFrameUOCException;

/**
 * Classe que representa una consulta amb restricci.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
public abstract class RestrictionQuery extends Query {
	
	//Restricci de la consulta.
	private Restriction restriction	= null;
	
	/**
	 * Constructor. 
	 * 
	 * @param table - Nom de la taula que interv en la consulta.
	 * 
	 * @throws MyFrameUOCException 
	 */
	protected RestrictionQuery(String table) throws MyFrameUOCException {
		super(table);
	}

	/**
	 * Permet obtenir la sentncia amb restricci construda.
	 * 
	 * @exception MyFrameUOCException Si no es pot obtenir la sentncia amb restricci construda.
	 */
	@Override
	public abstract String getQuery() throws MyFrameUOCException;

	/**
	 * Permet validar les propietats de la sentncia amb restricci.
	 * 
	 */
	@Override
	public void validateQuery() throws MyFrameUOCException {
		super.validateQuery();
	}

	/**
	 * Permet obtenir les restriccions de la sentncia en una cadena perqu
	 * es puguin concatenar a una sentncia SQL.
	 * 
	 * @return Un <code>String</code> amb les restriccions de la consulta perqu 
	 * es puguin concatenar a una sentncia SQL.
	 */
	public String getRestrictionQuery(){
		String restriction		= "";
		
		if (this.restriction !=  null){
			restriction = "WHERE " + this.restriction.getRestriction();
		}
		
		return (restriction);
	}
	
	/**
	 * Permet obtenir la restricci de la sentncia SQL.
	 * 
	 * @return Un <code>{@link com.uoc.myframeuoc.querymanagement.Restriction Restriction}</code>
	 * que cont la restricci de la sentncia SQL.
	 */
	public Restriction getRestriction(){
		return (this.restriction);
	}
	
	/**
	 * Permet conixer si la sentncia cont una restricci..
	 * 
	 * @return <code>True</code> si la sentncia t una restricci.
	 * <code>False</code> en qualsevol altre cas.
	 */
	public boolean hasRestriction(){
		boolean has	= false;
		if (this.restriction != null){
			has = true;
		}
		return (has);
	}
	
	/**
	 * Afegeix una restricci a la sentncia SQL.
	 * 
	 * @param restriction - Retricci que s'afegeix a la sentncia SQL. Si es passa un nul, 
	 * no s'afegeix res.
	 */
	public void addRestriction(Restriction restriction){
		if (restriction != null){
			this.restriction = restriction;
		}
	}
	
	/**
	 * Elimina la restricci de la sentpencia SQL.
	 */
	public void removeRrestriction(){
		this.restriction = null;
	}
}
