package com.uoc.myframeuoc.querymanagement;

import java.util.ArrayList;

import com.uoc.myframeuoc.exceptions.MyFrameUOCException;

/**
 * Classe que representa i gestiona les sentncies SELECT en MySQL.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
public class SelectMySQL extends Select {

	/**
	 * Constructor.
	 * 
	 * @param table - Nom de la taula que participa en la sentncia SELECT.
	 * 
	 * @throws MyFrameUOCException Si no es pot crear la sentncia SELECT.
	 */
	public SelectMySQL(String table) throws MyFrameUOCException {
		super(table);
	}

	/**
	 * Permet obtenir la sentncia SELECT construda en MySQL.
	 * 
	 * @return Un <code>String</code> amb la sentncia SELECT construda en MySQL.
	 * 
	 * @exception MyFrameUOCException Si no es pot obtenir la sentncia SELECT construda en MySQL.
	 */
	@Override
	public String getQuery() throws MyFrameUOCException {
		String query				= null;
		int elements				= 0;
		Field field					= null;
		ArrayList<Field> fields		= null;
		
		//Validar les propietats de la sentncia SELECT per a poder construir-la.
		this.validateQuery();
		
		fields = this.getFields();
		query = "SELECT ";
		elements = fields.size();
		field = fields.get(0);
		query += field.getName();
		for (int i = 1; i < elements; i++){
			field = fields.get(i);
			query += ", " + field.getName();
		}
		query += " FROM " + this.getTable();
		if (this.hasRestriction()){
			query += " " + this.getRestrictionQuery(); 
		}
		return (query);
	}
}
