package com.uoc.myframeuoc.querymanagement;

import java.util.ArrayList;

import com.uoc.myframeuoc.exceptions.MyFrameUOCException;

/**
 * Classe que representa i gestiona les sentncies UPDATE en Oracle.
 * 
 * @author Jordi Garcia Casanova
 *
 */
public class UpdateOracle extends Update {

	/**
	 * Constructor.
	 * 
	 * @param table - Nom de la taula que participa en la sentncia UPDATE.
	 * 
	 * @throws MyFrameUOCException Si no es pot crear la sentncia UPDATE.
	 */
	public UpdateOracle(String table) throws MyFrameUOCException {
		super(table);
	}

	/**
	 * Permet obteir la sentncia UPDATE construda en Oracle.
	 * 
	 * @return Un <code>String</code> amb la sentncia UPDATE construda en Oracle.
	 * 
	 * @throws MyFrameUOCException Si no es pot obtenir la sentncia UPDATE construda en Oracle.
	 */
	@Override
	public String getQuery() throws MyFrameUOCException {
		String query							= null;
		int elements							= 0;
		FieldValuePair pair						= null;
		ArrayList<FieldValuePair> pairs		= null;
		
		//Validar la sentncia UPDATE.
		this.validateQuery();
		
		pairs = this.getFieldValuePairs();
		elements = pairs.size();
		pair = pairs.get(0);
		query = "UPDATE " + this.getTable() + " SET " + pair.getAssignment();
		for (int i = 1; i < elements; i++){
			pair = pairs.get(i);
			query += ", " + pair.getAssignment();
		}
		if (this.hasRestriction()){
			query += " " + this.getRestrictionQuery();
		}
		return (query);
	}
}
