package com.uoc.myframeuoc.utils;

import java.lang.reflect.Method;
import java.util.ArrayList;

import com.uoc.myframeuoc.exceptions.MappingMsg;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;

/**
 * Clase que serveix per a emmagatzemar valors constants que s'utilitzen en el
 * framework MyFrameUOC.
 * 
 * @author Jordi Garcia Casanova
 *
 */
public class MyFrameUOC {	
	/**
	 * Nom del node arrel <i>MyFrameUOC</i> del fitxer de configuraci.
	 */
	public static final String ROOT_NODE		= "MyFrameUOC";
	
	/**
	 * Nom del node <i>propietats</i> del fitxer de configuraci.
	 */
	public static final String PROPERTIES_NODE	= "properties";
	
	/**
	 * Nom del node <i>SGBD</i> del fitxer de configuraci.
	 */
	public static final String SGBD_NODE		= "SGBD";
	
	/**
	 * Nom del node <i>url</i> del fitxer de configuraci.
	 */
	public static final String URL_NODE			= "url";
	
	/**
	 * Nom del node <i>database</i> del fitxer de configuraci.
	 */
	public static final String DATABASE_NODE	= "database";
	
	/**
	 * Nom del node <i>user</I> del fitxer de configuraci.
	 */
	public static final String USER_NODE		= "user";
	
	/**
	 * Nom del node <i>password</i> del fitxer de configuraci. 
	 */
	public static final String PASSWORD_NODE	= "password";
	
	/**
	 * Separador dels camps de correspondncia de les anotacions.
	 */
	public static final String SEPARATOR_FIELDS	= ",";
	
	/**
	 * Separador d'un camp de correspondncia de les anotacions.
	 */
	public static final String SEPARATOR_FIELD	= "-";
	
	/**
	 * Codificaci utilitzada per a ubicar la precisi en un tipus de dades mapejat.
	 */
	public static final String PARAM_PRECISION	= "?p";
	
	/**
	 * Codificaci utilitzada per a ubicar l'escala en un tipus de dades mapejat.
	 */
	public static final String PARAM_SCALE		= "?s";
	
	/**
	 * Codificaci utilitzada per a ubicar la mida en un tipus de dades  mapejat.
	 */
	public static final String PARAM_LENGTH		= "?l";
	
	/**
	 * Codificaci utilitzada per als parmetres de les sentncies preparades.
	 */
	public static final String PARAM_STATEMENT	= "#";
	
	/**
	 * Codificaci utilitzada per a separar els parmetres de les sentncies preparades.
	 */
	public static final String SEPARATOR_PARAM_STATEMENT	= "@";
	
	/**
	 * Codificaci utilitzada per a substitur els valors en les sentncies preparades.
	 */
	public static final String PARAM_VALUE = "?";

	/**
	 * Permet obtenir el valor d'un atribut d'un objecte.
	 * 
	 * @param nameProperty - Nom de l'atribut de l'objecte del qual es vol obtenir el seu valor.
	 * @param obj - Objecte del qual es vol obtenir el valor d'un atribut.
	 * 
	 * @throws MyFrameUOCException Si no es pot obtenir el valor de l'atribut de l'objecte.
	 */
	public static Object getObjectValue(String nameProperty, Object obj) throws MyFrameUOCException{
		Object value			= null;
		Class<?> c				= null;
		Method method			= null;
		Class<?>[] methodArgs	= null;
		Object[] invokeArgs		= null;
		String getter			= null;
		
		try{
			if (nameProperty == null || "".equals(nameProperty)){
				//Error => No s'ha indicat el nom de l'atribut.
				throw new MyFrameUOCException(MappingMsg.GETOBJECTVALUE_SENSE_ATRIBUT);
			}
			if (obj == null){
				//Error => L'0bjecte s nul.
				throw new MyFrameUOCException(MappingMsg.GETOBJECTVALUE_SENSE_OBJECTE);
			}
			getter = "get" + String.valueOf(nameProperty.charAt(0)).toUpperCase() + nameProperty.substring(1, nameProperty.length());
			c = Class.forName(obj.getClass().getCanonicalName());
			methodArgs = new Class[]{};
			method = c.getMethod(getter, methodArgs);
			invokeArgs = new Object[]{};
			value = method.invoke(obj, invokeArgs);
		}
		catch (Exception e){
			//Error => S'ha produt un error en obtenir el valor d'un atribut d'un objecte.
			throw new MyFrameUOCException(MappingMsg.GETOBJECTVALUE_ERROR, e.getMessage());
		}
		return (value);
	}
	
	/**
	 * Assigna un objecte a un atribut d'un objecte.
	 * 
	 * @param nameProperty - Nom de l'atribut de l'objecte 'obj' al qual s'assignar l'objecte 'objSource'.
	 * @param obj - Objecte al qual se li vol modificar el valor d'un els seus atributs.
	 * @param objSource - Objecte que s'assignar a un dels atributs de l'objecte 'obj'.
	 * 
	 * @throws MyFrameUOCException Si no es pot assignar un objecte a l'atribut d'un objecte. 
	 */
	public static void setObjectProperty(String nameProperty, Object obj, Object objSource) throws MyFrameUOCException{
		Class<?> c					= null;
		Method method				= null;
		Class<?>[] methodArgs		= null;
		Object[] invokeArgs			= null;
		String setter				= null;
		Class<?> classObjSource		= null;
		
		try{
			if (nameProperty == null || "".equals(nameProperty)){
				//Error => No s'ha indicat el nom de l'atribut.
				throw new MyFrameUOCException(MappingMsg.SETOBJECTPROPERTY_SENSE_ATRIBUT);
			}
			if (obj == null){
				//Error => L'objecte s nul.
				throw new MyFrameUOCException(MappingMsg.SETOBJECTPROPERTY_SENSE_OBJ);
			}
			if (objSource == null){
				//Error => L'objecte a assignar s nul.
				throw new MyFrameUOCException(MappingMsg.SETOBJECTPROPERTY_SENSE_OBJSOURCE);
			}
			setter = "set" + String.valueOf(nameProperty.charAt(0)).toUpperCase() + nameProperty.substring(1, nameProperty.length());
			c = Class.forName(obj.getClass().getCanonicalName());
			classObjSource = Class.forName(objSource.getClass().getCanonicalName());
			methodArgs = new Class[]{classObjSource};
			method = c.getMethod(setter, methodArgs);
			invokeArgs = new Object[]{objSource};
			method.invoke(obj, invokeArgs);
		}
		catch (Exception e){
			//Error => S'ha produt un error en obtenir el valor d'un atribut d'un objecte.
			throw new MyFrameUOCException(MappingMsg.GETOBJECTVALUE_ERROR, e.getMessage());
		}
	}
	
	/**
	 * Permet conixer si dos <code>ArrayList</code> sn iguals (contenen els mateixos objectes).
	 * 
	 * @param list1 - Primer <code>ArrayList</code> a comparar.
	 * @param list2 - Segon <code>ArrayList</code> a comparar.
	 * 
	 * @return <code>True</code> si els dos <code>ArrayList</code> sn iguals. <code>False</code> en
	 * qualsevol altrer cas.
	 */
	public static boolean equals(ArrayList<Object> list1, ArrayList<Object> list2){
		boolean equals			= false;
		int sizeList1;
		int sizeList2;
		boolean different 		= false;
		Object objList1			= null;
		Object objList2			= null;
		int i 					= 0;
		
		if (list1 != null && list2 != null){
			sizeList1 = list1.size();
			sizeList2 = list2.size();
			if (sizeList1 == sizeList2){
				while (i < sizeList1 && !different){
					objList1 = list1.get(i);
					objList2 = list2.get(i);
					if (objList1 != null && objList2 != null){
						if (!String.valueOf(objList1).equals(String.valueOf(objList2))){
							different = true;
						}
					}
					else{
						if (objList1 != null || objList2 != null){
							different = true;
						}
					}
					if (!different){
						i++;
					}
				}
				if (!different){
					equals = true; 
				}
			}
		}
		else{
			if (list1 == null && list2 == null){
				equals = true;
			}
		}
		return (equals);
	}
}
