package test.database.javatype;

import java.math.BigDecimal;
import java.math.BigInteger;
import java.sql.Date;
import java.sql.Time;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.GregorianCalendar;

import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import org.junit.runners.Parameterized.Parameters;

import com.uoc.myframeuoc.environment.Session;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;


/**
 * Proves dels tipus de dades.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
@RunWith(Parameterized.class)
public class JavaTypeTest {
	private String file		= null;
	
	@Parameters
	public static Collection<Object[]> data(){
		Object[][] data = {
							{"test/ConfigurationFiles/OracleConfiguration.xml"}, 
							{"test/ConfigurationFiles/MySQLConfiguration.xml"}
						};
		return Arrays.asList(data);
	}
	
	public JavaTypeTest(String file){
		this.file = file;
	}
	
	@Test
	public void test0001(){
		Session session 				= null;
		Entitat0001 entitat				= null;
		ArrayList<Object> pk			= null;
		Entitat0001 entitatRead			= null;
		GregorianCalendar gc			= null;
		String valueString				= "Hola";
		char valueChar_					= 'a';
		Character valueCharacter		= new Character('b');
		char[] valueCharArray			= "Hola!!!".toCharArray();
		int valueInt_					= 12;
		Integer valueInteger			= new Integer(2578);
		float valueFloat_				= 3.4f;
		Float valueFloat				= new Float(2.6f);
		double valueDouble_				= 1471.1241;
		Double valueDouble				= new Double("1544.1237");
		BigDecimal valueBigDecimal		= new BigDecimal("157.35");
		byte valueByte_					= 100;
		Byte valueByte					= new Byte("120");
		short valueShort_				= 4;
		Short valueShort				= new Short("20");
		long valueLong_					= 15000;
		Long valueLong					= new Long("20000");
		boolean valueBoolean_			= true;
		Boolean valueBoolean			= false;
		Date valueDate					= null;
		Time valueTime					= null;
		BigInteger valueBigInteger		= new BigInteger("1234567890123456789012345");
		
		
		gc = new GregorianCalendar(2012, 11, 14);
		valueDate = new Date(gc.getTime().getTime());
		valueTime = Time.valueOf("01:02:03");
		
		entitat = new Entitat0001();
		entitat.setAtribut1(1);
		entitat.setAtribut2(valueString);
		entitat.setAtribut3(valueChar_);
		entitat.setAtribut4(valueCharacter);
		entitat.setAtribut5(valueCharArray);
		entitat.setAtribut6(valueInt_);
		entitat.setAtribut7(valueInteger);
		entitat.setAtribut8(valueFloat_);
		entitat.setAtribut9(valueFloat);
		entitat.setAtribut10(valueDouble_);
		entitat.setAtribut11(valueDouble);
		entitat.setAtribut12(valueBigDecimal);
		entitat.setAtribut13(valueDate);
		entitat.setAtribut14(valueByte_);
		entitat.setAtribut15(valueByte);
		entitat.setAtribut16(valueShort_);
		entitat.setAtribut17(valueShort);
		entitat.setAtribut18(valueLong_);
		entitat.setAtribut19(valueLong);
		entitat.setAtribut20(valueBoolean_);
		entitat.setAtribut21(valueBoolean);
		entitat.setAtribut22(valueTime);
		entitat.setAtribut23(valueBigInteger);
		
		pk = new ArrayList<Object>();
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail();
		}
		
		try {
			session.drop(Entitat0001.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}	
		
		pk.add(1);
		try {
			entitatRead = (Entitat0001) session.read(Entitat0001.class.getCanonicalName(), pk);
			if (entitatRead == null){
				session.close();
				Assert.fail();
			}
			if (entitatRead.getAtribut1() != 1){
				session.close();
				Assert.fail();
			}
			if (!valueString.equals(entitatRead.getAtribut2())){
				session.close();
				Assert.fail();
			}
			if (valueChar_ != entitatRead.getAtribut3()){
				session.close();
				Assert.fail();
			}
			if (!valueCharacter.equals(entitatRead.getAtribut4())){
				session.close();
				Assert.fail();
			}
			if (!String.valueOf(valueCharArray).equals(String.valueOf(entitatRead.getAtribut5()))){
				session.close();
				Assert.fail();
			}
			if (entitatRead.getAtribut6() != valueInt_){
				session.close();
				Assert.fail();
			}
			if (!valueInteger.equals(entitatRead.getAtribut7())){
				session.close();
				Assert.fail();
			}
			if (valueFloat_ != entitatRead.getAtribut8()){
				session.close();
				Assert.fail();
			}
			if (!valueFloat.equals(entitatRead.getAtribut9())){
				session.close();
				Assert.fail();
			}
			if (valueDouble_ != entitatRead.getAtribut10()){
				session.close();
				Assert.fail();
			}
			if (!valueDouble.equals(entitatRead.getAtribut11())){
				session.close();
				Assert.fail();
			}
			if (!valueBigDecimal.equals(entitatRead.getAtribut12())){
				session.close();
				Assert.fail();
			}
			if (!valueDate.equals(entitatRead.getAtribut13())){
				session.close();
				Assert.fail();
			}
			if (valueByte_ != entitatRead.getAtribut14()){
				session.close();
				Assert.fail();
			}
			if (!valueByte.equals(entitatRead.getAtribut15())){
				session.close();
				Assert.fail();
			}
			if (valueShort_ != entitatRead.getAtribut16()){
				session.close();
				Assert.fail();
			}
			if (!valueShort.equals(entitatRead.getAtribut17())){
				session.close();
				Assert.fail();
			}
			if (valueLong_ != entitatRead.getAtribut18()){
				session.close();
				Assert.fail();
			}
			if (!valueLong.equals(entitatRead.getAtribut19())){
				session.close();
				Assert.fail();
			}
			if (valueBoolean_ != entitatRead.getAtribut20()){
				session.close();
				Assert.fail();
			}
			if (!valueBoolean.equals(entitatRead.getAtribut21())){
				session.close();
				Assert.fail();
			}
			if (!valueTime.equals(entitatRead.getAtribut22())){
				session.close();
				Assert.fail();
			}
			if (!valueBigInteger.equals(entitat.getAtribut23())){
				session.close();
				Assert.fail();
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		entitat = new Entitat0001();
		entitat.setAtribut1(2);
		
		try {
			session.delete(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.update(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0001.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0002(){
		Session session			= null;
		Entitat0002 entitat		= null;
		ArrayList<Object> pk	= null;
		Entitat0002 entitatRead	= null;
		
		entitat = new Entitat0002();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0002.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.add(1);
		
		try {
			entitatRead = (Entitat0002) session.read(Entitat0002.class.getCanonicalName(), pk);
			Assert.assertTrue(entitatRead != null);
			Assert.assertTrue(entitatRead.getAtribut1() == 1);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.update(entitat);
		}
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0002.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0003(){
		Session session 		= null;
		Entitat0003 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s de tipus String, t informat la precisi i MyFrameUOC no ha donat error.";
		
		pk = new ArrayList<Object>();
		entitat = new Entitat0003();
		
		entitat.setAtribut1(1);
		entitat.setAtribut2("Hola");
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
	
		pk.add(1);
		try {
			session.read(Entitat0003.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0003.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.close();
		}
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0004(){
		Session session 		= null;
		Entitat0004 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 t s de tipus String, t informat la precisi i l'escala, i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0004();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		entitat.setAtribut2("Hola");
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		try {
			session.read(Entitat0004.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0004.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0005(){
		Session session 		= null;
		Entitat0005 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 t s de tipus String, t informat l'escala i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0005();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		entitat.setAtribut2("Hola");
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		try {
			session.read(Entitat0005.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0005.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0006(){
		Session session 		= null;
		Entitat0006 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s de tipus char, t informada la precisi i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0006();
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0006.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		try {
			session.read(Entitat0006.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0006.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0007(){
		Session session 		= null;
		Entitat0007 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s de tipus char, t informada l'escala i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0007();
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0007.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		try {
			session.read(Entitat0007.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0007.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0008(){
		Session session 		= null;
		Entitat0008 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un char[], no s'ha informat la mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0008();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0008.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		try {
			session.read(Entitat0008.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0008.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0009(){
		Session session 		= null;
		Entitat0009 entitat		= null;
		String msg				= "L'atribut 2 s un int, s'ha informat la precisi i MyFrameUOC no ha donat error.";
		ArrayList<Object> pk	= null;
		
		entitat = new Entitat0009();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0009.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		try {
			session.read(Entitat0009.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0009.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0010(){
		Session session 		= null;
		Entitat0010 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un int, s'ha informat l'escala i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0010();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0010.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0010.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0010.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0011(){
		Session session 		= null;
		Entitat0011 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un Integer, t informat la precisi i l'escala, i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0011();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0011.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0011.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0011.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		}
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0012(){
		Session session 		= null;
		Entitat0012 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un float, t informat la precisi i l'escala, i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0012();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0012.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0012.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0012.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0013(){
		Session session 		= null;
		Entitat0013 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un Float, t informat la precisi i l'escala, i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0013();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0013.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0013.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0013.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0014(){
		Session session 		= null;
		Entitat0014 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un double, t informat la precisi i l'escala, i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0014();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0014.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0014.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0014.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0015(){
		Session session 		= null;
		Entitat0015 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un Double, t informat la precisi i l'escala, i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0015();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0015.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0015.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0015.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0016(){
		Session session 		= null;
		Entitat0016 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un BigDecimal, no t informat la precisi i l'escala, i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0016();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0016.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0016.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0016.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0017(){
		Session session 		= null;
		Entitat0017 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un java.sql.Date, t informat la precisi i l'escala, i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0017();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0017.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0017.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0017.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		}
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0018(){
		Session session 		= null;
		Entitat0018 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un byte, t informat la precisi i l'escala, i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0018();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0018.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0018.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0018.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0019(){
		Session session 		= null;
		Entitat0019 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un Byte, t informat la precisi i l'escala, i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0019();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0019.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0019.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0019.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0020(){
		Session session 		= null;
		Entitat0020 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un short, t informat la precisi i l'escala, i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0020();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0020.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0020.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0020.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0021(){
		Session session 		= null;
		Entitat0021 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un Short, t informat la precisi i l'escala, i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0021();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0021.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0021.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0021.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		}
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0022(){
		Session session 		= null;
		Entitat0022 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un long, t informat la precisi i l'escala, i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0022();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0022.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0022.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0022.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0023(){
		Session session 		= null;
		Entitat0023 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un Long, t informat la precisi i l'escala, i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0023();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0023.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0023.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0023.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0024(){
		Session session 		= null;
		Entitat0024 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un boolean, t informat la precisi i l'escala, i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0024();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0024.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0024.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0024.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0025(){
		Session session 		= null;
		Entitat0025 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un Boolean, t informat la precisi i l'escala, i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0025();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0025.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0025.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0025.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0026(){
		Session session 		= null;
		Entitat0026 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un java.sql.Time, t informat la precisi i l'escala, i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0026();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0026.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0026.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0026.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0027(){
		Session session 		= null;
		Entitat0027 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un BigInteger, t informat la precisi i l'escala, i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0027();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0027.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0027.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0027.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0028(){
		Session session 		= null;
		Entitat0028 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un BigInteger, t informada l'escala i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0028();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0028.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0028.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//Ok.
		}
		
		try {
			session.drop(Entitat0028.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0029(){
		Session session 		= null;
		Entitat0029 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un BigInteger, no t informada la precisi i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0029();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0029.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0029.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0029.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0030(){
		Session session 		= null;
		Entitat0030 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un char, t informada una mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0030();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0030.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0030.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0030.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0031(){
		Session session 		= null;
		Entitat0031 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un Character, t informada una mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0031();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0031.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0031.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0031.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0032(){
		Session session 		= null;
		Entitat0032 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un int, t informada una mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0032();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0032.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0032.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0032.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0033(){
		Session session 		= null;
		Entitat0033 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un Integer, t informada una mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0033();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0033.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0033.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0033.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0034(){
		Session session 		= null;
		Entitat0034 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un float, t informada una mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0034();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0034.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0034.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0034.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0035(){
		Session session 		= null;
		Entitat0035 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un Float, t informada una mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0035();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0035.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0035.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0035.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0036(){
		Session session 		= null;
		Entitat0036 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un double, t informada una mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0036();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0036.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0036.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0036.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0037(){
		Session session 		= null;
		Entitat0037 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un Double, t informada una mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0037();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0037.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0037.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0037.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0038(){
		Session session 		= null;
		Entitat0038 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un BigDecimal, t informada una mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0038();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0038.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0038.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0038.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0039(){
		Session session 		= null;
		Entitat0039 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un java.sql.Date, t informada una mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0039();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0039.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0039.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0039.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0040(){
		Session session 		= null;
		Entitat0040 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un byte, t informada una mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0040();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0040.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0040.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0040.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0041(){
		Session session 		= null;
		Entitat0041 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un Byte, t informada una mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0041();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0041.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0041.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0041.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0042(){
		Session session 		= null;
		Entitat0042 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un short, t informada una mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0042();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0042.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0042.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0042.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0043(){
		Session session 		= null;
		Entitat0043 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un Short, t informada una mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0043();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0043.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0043.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0043.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0044(){
		Session session 		= null;
		Entitat0044 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un long, t informada una mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0044();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0044.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0044.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0044.class.getCanonicalName());
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0045(){
		Session session 		= null;
		Entitat0045 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un Long, t informada una mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0045();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0045.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0045.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0045.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0046(){
		Session session 		= null;
		Entitat0046 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un boolean, t informada una mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0046();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0046.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0046.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0046.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0047(){
		Session session 		= null;
		Entitat0047 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un Boolean, t informada una mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0047();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0047.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0047.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0047.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0048(){
		Session session 		= null;
		Entitat0048 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un java.sql.Time, t informada una mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0048();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0048.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0048.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0048.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0049(){
		Session session 		= null;
		Entitat0049 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s un BigInteger, t informada una mida i MyFrameUOC no ha donat error.";
		
		entitat = new Entitat0049();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0049.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0049.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0049.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0050(){
		Session session 		= null;
		Entitat0050 entitat		= null;
		ArrayList<Object> pk	= null;
		Entitat0050 entitatRead	= null;
		String atribut1			= "1A";
		String atribut2			= "Hola";
		char atribut3			= 'c';
		Character atribut4		= new Character('b');
		char[] atribut5			= "Adu!".toCharArray();
		int atribut6			= 2631;
		Integer atribut7		= new Integer("3652");
		double atribut10		= 1.45;
		Double atribut11		= new Double("654.2331");
		BigDecimal atribut12	= new BigDecimal("150020.3645");
		GregorianCalendar gc	= null;
		Date atribut13			= null;
		byte atribut14			= 100;
		Byte atribut15			= new Byte("85");
		short atribut16			= 165;
		Short atribut17			= new Short("123");
		
		entitat = new Entitat0050();
		
		gc = new GregorianCalendar(2012, 11, 16);
		atribut13 = new Date(gc.getTime().getTime());
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(atribut1);
		entitat.setAtribut2(atribut2);
		entitat.setAtribut3(atribut3);
		entitat.setAtribut4(atribut4);
		entitat.setAtribut5(atribut5);
		entitat.setAtribut6(atribut6);
		entitat.setAtribut7(atribut7);
		entitat.setAtribut10(atribut10);
		entitat.setAtribut11(atribut11);
		entitat.setAtribut12(atribut12);
		entitat.setAtribut13(atribut13);
		entitat.setAtribut14(atribut14);
		entitat.setAtribut15(atribut15);
		entitat.setAtribut16(atribut16);
		entitat.setAtribut17(atribut17);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0050.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.add(atribut1);
		pk.add(atribut2);
		pk.add(atribut3);
		pk.add(atribut4);
		pk.add(atribut5);
		pk.add(atribut6);
		pk.add(atribut7);
		pk.add(atribut10);
		pk.add(atribut11);
		pk.add(atribut12);
		pk.add(atribut13);
		pk.add(atribut14);
		pk.add(atribut15);
		pk.add(atribut16);
		pk.add(atribut17);
		
		try {
			entitatRead = (Entitat0050) session.read(Entitat0050.class.getCanonicalName(), pk);
			
			if (entitatRead == null){
				session.close();
				Assert.fail("No s'ha llegit l'objecte de l'entitat Entitat0050.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.update(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitat);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0050.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0051(){
		Session session 		= null;
		Entitat0051 entitat		= null;
		ArrayList<Object> pk	= null;
		Entitat0051 entitatRead	= null;
		int atribut1			= 1;
		String atribut2			= "Hola";
		char atribut3			= 'c';
		Character atribut4		= new Character('b');
		char[] atribut5			= "Adu!".toCharArray();
		int atribut6			= 2631;
		Integer atribut7		= new Integer("3652");
		double atribut10		= 1.45;
		Double atribut11		= new Double("654.2331");
		BigDecimal atribut12	= new BigDecimal("150020.3645");
		GregorianCalendar gc	= null;
		Date atribut13			= null;
		byte atribut14			= 100;
		Byte atribut15			= new Byte("85");
		short atribut16			= 165;
		Short atribut17			= new Short("123");
		long atribut18			= 1548780015;
		Long atribut19			= new Long("365789741");
		boolean atribut20		= true;
		Boolean atribut21		= new Boolean(false);
		Time atribut22			= Time.valueOf("10:36:25");
		BigInteger atribut23	= new BigInteger("12345");
		
		entitat = new Entitat0051();
		
		gc = new GregorianCalendar(2012, 11, 16);
		atribut13 = new Date(gc.getTime().getTime());
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(atribut1);
		entitat.setAtribut18(atribut18);
		entitat.setAtribut19(atribut19);
		entitat.setAtribut20(atribut20);
		entitat.setAtribut21(atribut21);
		entitat.setAtribut22(atribut22);
		entitat.setAtribut23(atribut23);
		
		entitat.setAtribut2(atribut2);
		entitat.setAtribut3(atribut3);
		entitat.setAtribut4(atribut4);
		entitat.setAtribut5(atribut5);
		entitat.setAtribut6(atribut6);
		entitat.setAtribut7(atribut7);
		entitat.setAtribut10(atribut10);
		entitat.setAtribut11(atribut11);
		entitat.setAtribut12(atribut12);
		entitat.setAtribut13(atribut13);
		entitat.setAtribut14(atribut14);
		entitat.setAtribut15(atribut15);
		entitat.setAtribut16(atribut16);
		entitat.setAtribut17(atribut17);
		
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0051.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.add(atribut1);
		pk.add(atribut18);
		pk.add(atribut19);
		pk.add(atribut20);
		pk.add(atribut21);
		pk.add(atribut22);
		
		try {
			entitatRead = (Entitat0051) session.read(Entitat0051.class.getCanonicalName(), pk);
			
			if (entitatRead == null){
				session.close();
				Assert.fail("No s'ha llegit l'objecte de l'entitat Entitat0051.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.update(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitat);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0051.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0052(){
		Session session 		= null;
		Entitat0052 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s d'un tipus de dades no suportat i MyFrameUOC no ha donat error.";
		GregorianCalendar gc	= null;
		java.util.Date atribut1 = null;
		
		gc = new GregorianCalendar(2012, 11, 16);
		atribut1 = gc.getTime();
		
		entitat = new Entitat0052();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(atribut1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0052.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(atribut1);
		
		try {
			session.read(Entitat0052.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0052.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0053(){
		Session session 		= null;
		Entitat0053 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'atribut 2 s d'un tipus de dades no suportat i MyFrameUOC no ha donat error.";
		Entitat0001 atribut1	= null;
		
		entitat = new Entitat0053();
		
		pk = new ArrayList<Object>();
		
		atribut1 = new Entitat0001();
		
		entitat.setAtribut1(atribut1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0053.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(atribut1);
		
		try {
			session.read(Entitat0053.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0053.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
}
