package test.environment.delete;

import java.math.BigDecimal;
import java.math.BigInteger;
import java.sql.Date;
import java.sql.Time;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.GregorianCalendar;

import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import org.junit.runners.Parameterized.Parameters;

import com.uoc.myframeuoc.environment.Session;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;



/**
 * Proves dels delete.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
@RunWith(Parameterized.class)
public class DeleteTest {
	private String file		= null;
	
	@Parameters
	public static Collection<Object[]> data(){
		Object[][] data = {
							{"test/ConfigurationFiles/OracleConfiguration.xml"}, 
							{"test/ConfigurationFiles/MySQLConfiguration.xml"}
						};
		return Arrays.asList(data);
	}
	
	public DeleteTest(String file){
		this.file = file;
	}

	@Test
	public void test0001(){
		Session session 				= null;
		Entitat0001 entitat				= null;
		ArrayList<Object> pk			= null;
		Entitat0001 entitatRead			= null;
		String nameEntity				= Entitat0001.class.getCanonicalName();
		int atribut1					= 1;
		String atribut2					= "Valor de l'atribut 2.";
		char atribut3					= 'd';
		Character atribut4				= new Character('f');
		char[] atribut5					= "Valor de l'atribut 5".toCharArray();
		int atribut6					= 55230;
		Integer atribut7				= new Integer("1500");
		float atribut8					= 1.5f;
		Float atribut9					= new Float(2.36f);
		double atribut10				= 4.5d;
		Double atribut11				= new Double(5.25);
		BigDecimal atribut12			= new BigDecimal("1234567.3421");
		Date atribut13					= null;
		byte atribut14					= 15;
		Byte atribut15					= new Byte("30");
		short atribut16					= 45;
		Short atribut17					= new Short("36");
		long atribut18					= 789888;
		Long atribut19					= new Long("150000");
		boolean atribut20				= true;
		Boolean atribut21				= new Boolean(true);
		Time atribut22					= Time.valueOf("19:30:30");
		BigInteger atribut23			= new BigInteger("123456788888");
		GregorianCalendar gc			= null;
		
		
		gc = new GregorianCalendar(2012, 11, 16);
		atribut13 = new Date(gc.getTime().getTime());
		
		entitat = new Entitat0001();
		entitat.setAtribut1(atribut1);
		entitat.setAtribut2(atribut2);
		entitat.setAtribut3(atribut3);
		entitat.setAtribut4(atribut4);
		entitat.setAtribut5(atribut5);
		entitat.setAtribut6(atribut6);
		entitat.setAtribut7(atribut7);
		entitat.setAtribut8(atribut8);
		entitat.setAtribut9(atribut9);
		entitat.setAtribut10(atribut10);
		entitat.setAtribut11(atribut11);
		entitat.setAtribut12(atribut12);
		entitat.setAtribut13(atribut13);
		entitat.setAtribut14(atribut14);
		entitat.setAtribut15(atribut15);
		entitat.setAtribut16(atribut16);
		entitat.setAtribut17(atribut17);
		entitat.setAtribut18(atribut18);
		entitat.setAtribut19(atribut19);
		entitat.setAtribut20(atribut20);
		entitat.setAtribut21(atribut21);
		entitat.setAtribut22(atribut22);
		entitat.setAtribut23(atribut23);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail();
		}
		
		try {
			session.drop(Entitat0001.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}	
		
		try {
			session.delete(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk = new ArrayList<Object>();
		pk.add(atribut1);
		
		try {
			entitatRead = (Entitat0001) session.read(nameEntity, pk);
			if (entitatRead != null){
				session.close();
				Assert.fail("L'eliminaci de l'objecte de la base de dades no s'ha fet correctament.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0001.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0002(){
		Entitat0001 entitat			= null;
		String nameEntity			= Entitat0001.class.getCanonicalName();
		Session session				= null;
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		entitat = new Entitat0001();
		entitat.setAtribut1(1);
		
		try {
			session.delete(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		entitat = null;
		
		try {
			session.delete(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			}
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0003(){
		Entitat0002 entitat					= null;
		ArrayList<Entitat0002> objectes		= null;
		int numObjectes						= 10;
		Session session						= null;
		String nameEntity					= Entitat0002.class.getCanonicalName();
		Entitat0002 entitatRead				= null;
		ArrayList<Object> pk				= null;
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			}
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		objectes = new ArrayList<Entitat0002>();
		for (int i = 0; i < numObjectes; i++){
			entitat =  new Entitat0002();
			entitat.setAtribut1(i);
			entitat.setAtribut2("Valor camp 2 " + i);
			entitat.setAtribut3(new BigDecimal("12345.68"));
			entitat.setAtribut4(new BigInteger("12345678901234567890"));
			objectes.add(entitat);
			
			try {
				session.insert(entitat);
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		pk = new ArrayList<Object>();
		for (int i = 0; i < numObjectes; i++){
			entitat = objectes.get(i);
			
			try {
				session.delete(entitat);
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		for (int i = 0; i < numObjectes; i++){
			entitat = objectes.get(i);
			pk.clear();
			pk.add(entitat.getAtribut1());
			
			try {
				entitatRead = (Entitat0002) session.read(nameEntity, pk);
				if (entitatRead != null){
					session.close();
					Assert.fail("L'eliminaci dels objectes de la base de dades no ha funcionat correctament.");
				}
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		try {
			session.drop(nameEntity);
		}
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
}
