package test.environment.insert;

import java.math.BigInteger;
import java.util.Arrays;
import java.util.Collection;

import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import org.junit.runners.Parameterized.Parameters;

import com.uoc.myframeuoc.environment.Session;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;


/**
 * Proves dels inserts.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
@RunWith(Parameterized.class)
public class InsertTest {
	private String file		= null;
	
	@Parameters
	public static Collection<Object[]> data(){
		Object[][] data = {
							{"test/ConfigurationFiles/OracleConfiguration.xml"}, 
							{"test/ConfigurationFiles/MySQLConfiguration.xml"}
						};
		return Arrays.asList(data);
	}
	
	public InsertTest(String file){
		this.file = file;
	}
	
	@Test
	public void test0001(){
		Session session 		= null;
		Entitat0001 entitat		= null;
		String msg				= "No s'ha informat el valor de la clau primria de l'entitat Entitat0001 i MyFrameUOC no ha donat error.";
		String atribut1			= null;
		String atribut2			= "Hola, aix s un prova d'un insert.";
		
		entitat = new Entitat0001();
		
		entitat.setAtribut1(atribut1);
		entitat.setAtribut2(atribut2);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0001.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		try {
			session.drop(Entitat0001.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0002(){
		Session session 		= null;
		Entitat0001 entitat		= null;
		String atribut1			= "1AB007D";
		String atribut2			= "Hola, aix s un prova d'un insert.";
				
		entitat = new Entitat0001();
		
		entitat.setAtribut1(atribut1);
		entitat.setAtribut2(atribut2);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0001.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat);
			session.closeNoEx();
			Assert.fail("No es pot inserir un mateix objecte dues vegades en la base de dades.");
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0001.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0003(){
		Session session 		= null;
		Entitat0001 entitat		= null;
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0001.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		for (int i = 0; i < 300; i++){
			entitat = new Entitat0001();
			entitat.setAtribut1("A" + i);
			entitat.setAtribut2(String.valueOf(i));
			entitat.setAtribut3(new BigInteger("123456" + i));
			
			try {
				session.insert(entitat);
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		try {
			session.drop(Entitat0001.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0004(){
		Session session 		= null;
		Entitat0001 entitat		= null;
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0001.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		for (int i = 0; i < 50; i++){
			entitat = new Entitat0001();
			entitat.setAtribut1("A" + i);
			entitat.setAtribut2(String.valueOf(i));
			
			try {
				session.insert(entitat);
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		for (int i = 0; i < 50; i++){
			entitat = new Entitat0001();
			entitat.setAtribut1("A" + i);
			entitat.setAtribut2(String.valueOf(i));
			
			try {
				session.insert(entitat);
				session.closeNoEx();
				Assert.fail("No es pot inserir un mateix objecte dues vegades en la base de dades.");
			} 
			catch (MyFrameUOCException e) {
				//OK.
			}
		}
		
		
		
		try {
			session.drop(Entitat0001.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0005(){
		Session session 		= null;
		Entitat0001 entitat		= null;
		String msg				= "No es pot inserir un objecte nul i MyFrameUOC no ha donat error.";
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0001.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}

		try {
			session.drop(Entitat0001.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
}
