package test.environment.read;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;

import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import org.junit.runners.Parameterized.Parameters;

import com.uoc.myframeuoc.environment.Session;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;



/**
 * Proves dels read.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
@RunWith(Parameterized.class)
public class ReadTest {
	private String file		= null;
	
	@Parameters
	public static Collection<Object[]> data(){
		Object[][] data = {
							{"test/ConfigurationFiles/OracleConfiguration.xml"}, 
							{"test/ConfigurationFiles/MySQLConfiguration.xml"}
						};
		return Arrays.asList(data);
	}
	
	public ReadTest(String file){
		this.file = file;
	}

	@Test
	public void test0001(){
		Session session			= null;
		Entitat0001 entitat		= null;
		Entitat0001 entitatRead	= null;
		ArrayList<Object> pk	= null;
		String atribut1			= "1AC";
		String atribut2			= "Aix s una prova";
		BigInteger atribut3		= new BigInteger("12345");
		String atribut1Aux		= "1AD";
		
		entitat = new Entitat0001();
		
		entitat.setAtribut1(atribut1);
		entitat.setAtribut2(atribut2);
		entitat.setAtribut3(atribut3);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0001.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e2) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk = new ArrayList<Object>();
		
		entitat = new Entitat0001();
		entitat.setAtribut1(atribut1Aux);
		pk.add(atribut1Aux);
		
		try {
			entitatRead = (Entitat0001) session.read(Entitat0001.class.getCanonicalName(), pk);
			if (entitatRead != null){
				session.close();
				Assert.fail("L'objecte amb pk '" + atribut1Aux + "' no hauria d'existir.");
				
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0001.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0002(){
		Session session			= null;
		Entitat0002 entitat		= null;
		ArrayList<Object> pk	= null;
		int atribut1			= 5;
		String atribut2			= "Aix s una prova.";
		char atribut3			= 'm';
		
		entitat = new Entitat0002();
		
		entitat.setAtribut1(atribut1);
		entitat.setAtribut2(atribut2);
		entitat.setAtribut3(atribut3);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0002.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e2) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk = new ArrayList<Object>();
		
		pk.add(atribut1);
		pk.add(atribut2);
		
		try {
			session.read(Entitat0002.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail("Faltens valors en la llista de claus primries i MyFrameUOC no ha donat error.");
		} 
		catch (MyFrameUOCException e) {
		}
		
		try {
			session.drop(Entitat0002.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0003(){
		Session session			= null;
		Entitat0002 entitat		= null;
		ArrayList<Object> pk	= null;
		int atribut1			= 5;
		String atribut2			= "Aix s una prova.";
		char atribut3			= 'm';
		
		entitat = new Entitat0002();
		
		entitat.setAtribut1(atribut1);
		entitat.setAtribut2(atribut2);
		entitat.setAtribut3(atribut3);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0002.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e2) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.read(Entitat0002.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail("La llista de valors de les claus primries s nulla i MyFrameUOC no ha donat error.");
		} 
		catch (MyFrameUOCException e) {
		}
		
		try {
			session.drop(Entitat0002.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0004(){
		Session session						= null;
		Entitat0003 entitat					= null;
		Entitat0003 entitatRead				= null;
		ArrayList<Object> pk				= null;
		ArrayList<Entitat0003> objectes		= null;
		String atribut2						= "Valor";
		int numObjectes						= 100;
	
		objectes = new ArrayList<Entitat0003>();
		
		for (int i = 0; i < numObjectes; i++){
			entitat = new Entitat0003();
			entitat.setAtribut1(i);
			entitat.setAtribut2(atribut2 + i);
			objectes.add(entitat);
		}
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0003.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e2) {
			}
			Assert.fail(e.getMessage());
		}
		
		for (int i = 0; i < numObjectes; i++){
			entitat = objectes.get(i);
			try {
				session.insert(entitat);
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		for (int i = 0; i < numObjectes; i++){
			entitat = objectes.get(i);
			pk = new ArrayList<Object>();
			pk.add(entitat.getAtribut1());
			
			try {
				entitatRead = (Entitat0003) session.read(Entitat0003.class.getCanonicalName(), pk);
				if (entitatRead == null){
					session.close();
					Assert.fail("No s'ha pogut llegir un objecte de la base de dades.");
				}
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		try {
			session.drop(Entitat0003.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0005(){
		Session session			= null;
		Entitat0004 entitat		= null;
		Entitat0004 entitatRead	= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'objecte de l'entitat Entitat0004 no s'ha llegit correctament de la base de dades";
		int atribut1			= 15;
		BigInteger atribut2		= new BigInteger("123456789012345");
		
		entitat = new Entitat0004();
		
		entitat.setAtribut1(atribut1);
		entitat.setAtribut2(atribut2);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0004.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e2) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk = new ArrayList<Object>();
		
		pk.add(atribut1);
		
		try {
			entitatRead = (Entitat0004) session.read(Entitat0004.class.getCanonicalName(), pk);
			if (atribut1 != entitatRead.getAtribut1()){
				session.close();
				Assert.fail(msg);
			}
			if (!atribut2.equals(entitatRead.getAtribut2())){
				session.close();
				Assert.fail(msg);
			}
		}
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0004.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
	}
}
