package test.environment.transaction;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;

import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import org.junit.runners.Parameterized.Parameters;

import com.uoc.myframeuoc.environment.Session;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;

/**
 * Proves de les transaccions.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
@RunWith(Parameterized.class)
public class TransactionTest {
	private String file		= null;
	
	@Parameters
	public static Collection<Object[]> data(){
		Object[][] data = {
							{"test/ConfigurationFiles/OracleConfiguration.xml"}, 
							{"test/ConfigurationFiles/MySQLConfiguration.xml"}
						};
		return Arrays.asList(data);
	}
	
	public TransactionTest(String file){
		this.file = file;
	}

	@Test
	public void test0001(){
		Session session						= null;
		Entitat0001 entitat					= null;
		String nameEntity					= Entitat0001.class.getCanonicalName();
		ArrayList<Entitat0001> objectes		= null;
		int numObjectes						= 100;
		ArrayList<Object> pk				= null;
		Entitat0001 entitatRead				= null;
		
		objectes = new ArrayList<Entitat0001>();
		for (int i = 0; i < numObjectes; i++){
			entitat = new Entitat0001();
			entitat.setAtribut1("ABC" + i);
			entitat.setAtribut2("Valor de l'atribut 2: " + i);
			entitat.setAtribut3(new Integer(i));
			objectes.add(entitat);
		}
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.beginTransaction();
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			}
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		for (Entitat0001 entitat2: objectes){
			try {
				session.insert(entitat2);
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		try {
			session.commit();
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk = new ArrayList<Object>();
		for (Entitat0001 entitat2: objectes){
			pk.clear();
			pk.add(entitat2.getAtribut1());
			try {
				entitatRead = (Entitat0001) session.read(nameEntity, pk);
				if (entitatRead == null){
					session.close();
					Assert.fail("No s'ha llegit l'objecte de la base de dades. El commit no ha funcionat correctament.");
				}
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		try {
			session.drop(nameEntity);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0002(){
		Session session						= null;
		Entitat0001 entitat					= null;
		String nameEntity					= Entitat0001.class.getCanonicalName();
		ArrayList<Entitat0001> objectes		= null;
		int numObjectes						= 100;
		Entitat0001 entitatRead				= null;
		ArrayList<Object> pk				= null;
		
		objectes = new ArrayList<Entitat0001>();
		for (int i = 0; i < numObjectes; i++){
			entitat = new Entitat0001();
			entitat.setAtribut1("ABC" + i);
			entitat.setAtribut2("Valor de l'atribut 2: " + i);
			entitat.setAtribut3(new Integer(i));
			objectes.add(entitat);
		}
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.beginTransaction();
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			}
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		for (Entitat0001 entitat2: objectes){
			try {
				session.insert(entitat2);
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		try {
			session.rollback();
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk = new ArrayList<Object>();
		for (Entitat0001 entitat2: objectes){
			pk.clear();
			pk.add(entitat2.getAtribut1());
			try {
				entitatRead = (Entitat0001) session.read(nameEntity, pk);
				if (entitatRead != null){
					session.close();
					Assert.fail("No s'hauria d'haver llegit l'objecte de la base de dades. El rollback no ha funcionat correctament.");
				}
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		try {
			session.drop(nameEntity);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0003(){
		Session session						= null;
		Entitat0001 entitat					= null;
		String nameEntity					= Entitat0001.class.getCanonicalName();
		ArrayList<Entitat0001> objectes		= null;
		int numObjectes						= 100;
		Entitat0001 entitatRead				= null;
		ArrayList<Object> pk				= null;
		
		objectes = new ArrayList<Entitat0001>();
		for (int i = 0; i < numObjectes; i++){
			entitat = new Entitat0001();
			entitat.setAtribut1("ABC" + i);
			entitat.setAtribut2("Valor de l'atribut 2: " + i);
			entitat.setAtribut3(new Integer(i));
			objectes.add(entitat);
		}
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.beginTransaction();
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			}
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.beginTransaction();
			try {
				session.close();
			}
			catch (MyFrameUOCException e) {
			}
			Assert.fail("S'ha intentat iniciar una transacci quan ja hi ha una iniciada i MyFrameUOC no ha donat error.");
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.commit();
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.beginTransaction();
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		for (Entitat0001 entitat2: objectes){
			try {
				session.insert(entitat2);
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		try {
			session.rollback();
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk = new ArrayList<Object>();
		for (Entitat0001 entitat2: objectes){
			pk.clear();
			pk.add(entitat2.getAtribut1());
			try {
				entitatRead = (Entitat0001) session.read(nameEntity, pk);
				if (entitatRead != null){
					session.close();
					Assert.fail("No s'hauria d'haver llegit l'objecte de la base de dades. El rollback no ha funcionat correctament.");
				}
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		try {
			session.drop(nameEntity);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
	}

	@Test
	public void test0004(){
		Session session						= null;
		Entitat0001 entitat					= null;
		String nameEntity					= Entitat0001.class.getCanonicalName();
		ArrayList<Entitat0001> objectes		= null;
		int numObjectes						= 100;
		Entitat0001 entitatRead				= null;
		ArrayList<Object> pk				= null;
		
		objectes = new ArrayList<Entitat0001>();
		for (int i = 0; i < numObjectes; i++){
			entitat = new Entitat0001();
			entitat.setAtribut1("ABC" + i);
			entitat.setAtribut2("Valor de l'atribut 2: " + i);
			entitat.setAtribut3(new Integer(i));
			objectes.add(entitat);
		}
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.beginTransaction();
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			}
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.beginTransaction();
			try {
				session.close();
			}
			catch (MyFrameUOCException e) {
			}
			Assert.fail("S'ha intentat iniciar una transacci quan ja hi ha una iniciada i MyFrameUOC no ha donat error.");
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.commit();
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.beginTransaction();
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		for (Entitat0001 entitat2: objectes){
			try {
				session.insert(entitat2);
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		try {
			session.commit();
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk = new ArrayList<Object>();
		for (Entitat0001 entitat2: objectes){
			pk.clear();
			pk.add(entitat2.getAtribut1());
			try {
				entitatRead = (Entitat0001) session.read(nameEntity, pk);
				if (entitatRead == null){
					session.close();
					Assert.fail("No s'ha pogut llegir l'objecte de la base de dades. El commit no ha funcionat correctament.");
				}
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		try {
			session.drop(nameEntity);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0005(){
		Session session						= null;
		Entitat0001 entitat					= null;
		String nameEntity					= Entitat0001.class.getCanonicalName();
		ArrayList<Entitat0001> objectes		= null;
		int numObjectes						= 100;
		ArrayList<Object> pk				= null;
		Entitat0001 entitatRead				= null;
		
		objectes = new ArrayList<Entitat0001>();
		for (int i = 0; i < numObjectes; i++){
			entitat = new Entitat0001();
			entitat.setAtribut1("ABC" + i);
			entitat.setAtribut2("Valor de l'atribut 2: " + i);
			entitat.setAtribut3(new Integer(i));
			objectes.add(entitat);
		}
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		for (Entitat0001 entitat2: objectes){
			try {
				session.insert(entitat2);
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		try {
			session.commit();
			try {
				session.close();
			} 
			catch (MyFrameUOCException e) {
			}
			Assert.fail("No es pot fer un commit sense iniciar una transacci prviament.");
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk = new ArrayList<Object>();
		for (Entitat0001 entitat2: objectes){
			pk.clear();
			pk.add(entitat2.getAtribut1());
			try {
				entitatRead = (Entitat0001) session.read(nameEntity, pk);
				if (entitatRead == null){
					session.close();
					Assert.fail("No s'ha llegit l'objecte de la base de dades.");
				}
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		try {
			session.drop(nameEntity);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0006(){
		Session session						= null;
		Entitat0001 entitat					= null;
		String nameEntity					= Entitat0001.class.getCanonicalName();
		ArrayList<Entitat0001> objectes		= null;
		int numObjectes						= 100;
		ArrayList<Object> pk				= null;
		Entitat0001 entitatRead				= null;
		
		objectes = new ArrayList<Entitat0001>();
		for (int i = 0; i < numObjectes; i++){
			entitat = new Entitat0001();
			entitat.setAtribut1("ABC" + i);
			entitat.setAtribut2("Valor de l'atribut 2: " + i);
			entitat.setAtribut3(new Integer(i));
			objectes.add(entitat);
		}
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		for (Entitat0001 entitat2: objectes){
			try {
				session.insert(entitat2);
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		try {
			session.rollback();
			try {
				session.close();
			} 
			catch (MyFrameUOCException e) {
			}
			Assert.fail("No es pot fer un rollback sense iniciar una transacci prviament.");
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		pk = new ArrayList<Object>();
		for (Entitat0001 entitat2: objectes){
			pk.clear();
			pk.add(entitat2.getAtribut1());
			try {
				entitatRead = (Entitat0001) session.read(nameEntity, pk);
				if (entitatRead == null){
					session.close();
					Assert.fail("No s'ha llegit l'objecte de la base de dades.");
				}
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		try {
			session.drop(nameEntity);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
	}
}
