package test.environment.uocql;

import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import org.junit.runners.Parameterized.Parameters;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import com.uoc.myframeuoc.environment.Session;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;


/**
 * Proves del les consultes UOCQL.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
@RunWith(Parameterized.class)
public class UOCQLTest {
	private String file		= null;
	
	@Parameters
	public static Collection<Object[]> data(){
		Object[][] data = {
							{"test/ConfigurationFiles/OracleConfiguration.xml"}, 
							{"test/ConfigurationFiles/MySQLConfiguration.xml"}
						};
		return Arrays.asList(data);
	}
	
	public UOCQLTest(String file){
		this.file = file;
	}

	@Test
	public void test0001(){
		Entitat0001A entitatA1					= null;
		Entitat0001A entitatA2					= null;
		Entitat0001A entitatA3					= null;
		Entitat0001A entitatA4					= null;
		String nameEntityA						= Entitat0001A.class.getCanonicalName();
		Session session							= null;
		String queryUOCQL						= null;
		ArrayList<Object> listObjRead			= null;
		Entitat0001A entitatARead				= null;
		
		entitatA1 = new Entitat0001A();
		entitatA1.setAtribut1A(1);
		entitatA1.setAtribut2A(1);
		entitatA1.setAtribut3A("Valor atribut3A 1-1");
		entitatA1.setAtribut4A(new Integer("45"));
		
		entitatA2 = new Entitat0001A();
		entitatA2.setAtribut1A(2);
		entitatA2.setAtribut2A(1);
		entitatA2.setAtribut3A("Valor atribut3A 2-1");
		entitatA2.setAtribut4A(new Integer("50"));
		
		entitatA3 = new Entitat0001A();
		entitatA3.setAtribut1A(3);
		entitatA3.setAtribut2A(2);
		entitatA3.setAtribut3A("Valor atribut3A 3-2");
		entitatA3.setAtribut4A(new Integer("36"));
		
		entitatA4 = new Entitat0001A();
		entitatA4.setAtribut1A(4);
		entitatA4.setAtribut2A(2);
		entitatA4.setAtribut3A("Valor atribut3A 4-2");
		entitatA4.setAtribut4A(new Integer("25"));
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntityA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitatA1);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitatA2);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
			
		try {
			session.insert(entitatA3);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitatA4);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			queryUOCQL = "FROM " + nameEntityA + " WHERE atribut1A >= 1 AND atribut2A = 1";
			listObjRead = session.executeUOCQL(queryUOCQL);
			if (listObjRead == null){
				session.close();
				Assert.fail("La consulta UOCQL no funciona correctament.");
			}
			for (Object obj: listObjRead){
				entitatARead = (Entitat0001A) obj;
				if (!(entitatARead.getAtribut1A() == entitatA1.getAtribut1A() || entitatARead.getAtribut1A() == entitatA2.getAtribut1A())){
					session.close();
					Assert.fail("La consulta UOCQL no funciona correctament.");
				}
			}
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			queryUOCQL = "FROM " + nameEntityA + " WHERE atribut1A <= 4 AND atribut1A >= 3";
			listObjRead = session.executeUOCQL(queryUOCQL);
			if (listObjRead == null){
				session.close();
				Assert.fail("La consulta UOCQL no funciona correctament.");
			}
			for (Object obj: listObjRead){
				entitatARead = (Entitat0001A) obj;
				if (!(entitatARead.getAtribut1A() == entitatA3.getAtribut1A() || entitatARead.getAtribut1A() == entitatA4.getAtribut1A())){
					session.close();
					Assert.fail("La consulta UOCQL no funciona correctament.");
				}
			}
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			queryUOCQL = "FROM " + nameEntityA + " WHERE atribut1A = 1 AND atribut2A = 2";
			listObjRead = session.executeUOCQL(queryUOCQL);
			if (listObjRead != null && listObjRead.size() > 0){
				session.close();
				Assert.fail("La consulta UOCQL no funciona correctament.");
			}
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			queryUOCQL = "FROM " + nameEntityA + " WHERE atribut1A = 1 OR atribut1A = 3";
			listObjRead = session.executeUOCQL(queryUOCQL);
			if (listObjRead == null){
				session.close();
				Assert.fail("La consulta UOCQL no funciona correctament.");
			}
			for (Object obj: listObjRead){
				entitatARead = (Entitat0001A) obj;
				if (!(entitatARead.getAtribut1A() == entitatA1.getAtribut1A() || entitatARead.getAtribut1A() == entitatA3.getAtribut1A())){
					session.close();
					Assert.fail("La consulta UOCQL no funciona correctament.");
				}
			}
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntityA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
}
