package test.environment.update;

import java.math.BigDecimal;
import java.math.BigInteger;
import java.sql.Date;
import java.sql.Time;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.GregorianCalendar;

import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import org.junit.runners.Parameterized.Parameters;

import com.uoc.myframeuoc.environment.Session;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;


/**
 * Proves dels update.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
@RunWith(Parameterized.class)
public class UpdateTest {
	private String file		= null;
	
	@Parameters
	public static Collection<Object[]> data(){
		Object[][] data = {
							{"test/ConfigurationFiles/OracleConfiguration.xml"}, 
							{"test/ConfigurationFiles/MySQLConfiguration.xml"}
						};
		return Arrays.asList(data);
	}
	
	public UpdateTest(String file){
		this.file = file;
	}

	@Test
	public void test0001(){
		Session session 				= null;
		Entitat0001 entitat				= null;
		ArrayList<Object> pk			= null;
		Entitat0001 entitatRead			= null;
		String nameEntity				= Entitat0001.class.getCanonicalName();
		int atribut1					= 1;
		String atribut2					= "Valor de l'atribut 2.";
		String atribut2Nou				= "Nou valor de l'atribut2";
		char atribut3					= 'd';
		char atribut3Nou				= 'e';
		Character atribut4				= new Character('f');
		Character atribut4Nou			= new Character('p');
		char[] atribut5					= "Valor de l'atribut 5".toCharArray();
		char[] atribut5Nou				= "Nou valor de l'atribut 5".toCharArray();
		int atribut6					= 55230;
		int atribut6Nou					= 68000;
		Integer atribut7				= new Integer("1500");
		Integer atribut7Nou				= new Integer("960");
		float atribut8					= 1.5f;
		float atribut8Nou				= 5.6f;
		Float atribut9					= new Float(2.36f);
		Float atribut9Nou				= new Float(6.12f);
		double atribut10				= 4.5d;
		double atribut10Nou				= 1.36d;
		Double atribut11				= new Double(5.25);
		Double atribut11Nou				= new Double(85.231);
		BigDecimal atribut12			= new BigDecimal("1234567.3421");
		BigDecimal atribut12Nou			= new BigDecimal("63000.1234");
		Date atribut13					= null;
		Date atribut13Nou				= null;
		byte atribut14					= 15;
		byte atribut14Nou 				= 10;
		Byte atribut15					= new Byte("30");
		Byte atribut15Nou				= new Byte("45");
		short atribut16					= 45;
		short atribut16Nou				= 12;
		Short atribut17					= new Short("36");
		Short atribut17Nou				= new Short("63");
		long atribut18					= 789888;
		long atribut18Nou				= 800000;
		Long atribut19					= new Long("150000");
		Long atribut19Nou				= new Long("2553311");
		boolean atribut20				= true;
		boolean atribut20Nou			= false;
		Boolean atribut21				= new Boolean(true);
		Boolean atribut21Nou			= new Boolean(false);
		Time atribut22					= Time.valueOf("19:30:30");
		Time atribut22Nou				= Time.valueOf("20:00:05");
		BigInteger atribut23			= new BigInteger("123456788888");
		BigInteger atribut23Nou			= new BigInteger("999912345678901");
		GregorianCalendar gc			= null;
		GregorianCalendar gcNou			= null;
		
		
		gc = new GregorianCalendar(2012, 11, 16);
		gcNou = new GregorianCalendar(2012, 11, 25);
		atribut13 = new Date(gc.getTime().getTime());
		atribut13Nou = new Date(gcNou.getTime().getTime());
		
		entitat = new Entitat0001();
		entitat.setAtribut1(atribut1);
		entitat.setAtribut2(atribut2);
		entitat.setAtribut3(atribut3);
		entitat.setAtribut4(atribut4);
		entitat.setAtribut5(atribut5);
		entitat.setAtribut6(atribut6);
		entitat.setAtribut7(atribut7);
		entitat.setAtribut8(atribut8);
		entitat.setAtribut9(atribut9);
		entitat.setAtribut10(atribut10);
		entitat.setAtribut11(atribut11);
		entitat.setAtribut12(atribut12);
		entitat.setAtribut13(atribut13);
		entitat.setAtribut14(atribut14);
		entitat.setAtribut15(atribut15);
		entitat.setAtribut16(atribut16);
		entitat.setAtribut17(atribut17);
		entitat.setAtribut18(atribut18);
		entitat.setAtribut19(atribut19);
		entitat.setAtribut20(atribut20);
		entitat.setAtribut21(atribut21);
		entitat.setAtribut22(atribut22);
		entitat.setAtribut23(atribut23);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail();
		}
		
		try {
			session.drop(Entitat0001.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}	

		entitat.setAtribut2(atribut2Nou);
		entitat.setAtribut3(atribut3Nou);
		entitat.setAtribut4(atribut4Nou);
		entitat.setAtribut5(atribut5Nou);
		entitat.setAtribut6(atribut6Nou);
		entitat.setAtribut7(atribut7Nou);
		entitat.setAtribut8(atribut8Nou);
		entitat.setAtribut9(atribut9Nou);
		entitat.setAtribut10(atribut10Nou);
		entitat.setAtribut11(atribut11Nou);
		entitat.setAtribut12(atribut12Nou);
		entitat.setAtribut13(atribut13Nou);
		entitat.setAtribut14(atribut14Nou);
		entitat.setAtribut15(atribut15Nou);
		entitat.setAtribut16(atribut16Nou);
		entitat.setAtribut17(atribut17Nou);
		entitat.setAtribut18(atribut18Nou);
		entitat.setAtribut19(atribut19Nou);
		entitat.setAtribut20(atribut20Nou);
		entitat.setAtribut21(atribut21Nou);
		entitat.setAtribut22(atribut22Nou);
		entitat.setAtribut23(atribut23Nou);
		
		try {
			session.update(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk = new ArrayList<Object>();
		pk.add(atribut1);
		
		try {
			entitatRead = (Entitat0001) session.read(nameEntity, pk);
			if (entitatRead == null){
				session.close();
				Assert.fail();
			}
			if (entitatRead.getAtribut1() != atribut1){
				session.close();
				Assert.fail();
			}
			if (!atribut2Nou.equals(entitatRead.getAtribut2())){
				session.close();
				Assert.fail();
			}
			if (atribut3Nou != entitatRead.getAtribut3()){
				session.close();
				Assert.fail();
			}
			if (!atribut4Nou.equals(entitatRead.getAtribut4())){
				session.close();
				Assert.fail();
			}
			if (!String.valueOf(atribut5Nou).equals(String.valueOf(entitatRead.getAtribut5()))){
				session.close();
				Assert.fail();
			}
			if (entitatRead.getAtribut6() != atribut6Nou){
				session.close();
				Assert.fail();
			}
			if (!atribut7Nou.equals(entitatRead.getAtribut7())){
				session.close();
				Assert.fail();
			}
			if (atribut8Nou != entitatRead.getAtribut8()){
				session.close();
				Assert.fail();
			}
			if (!atribut9Nou.equals(entitatRead.getAtribut9())){
				session.close();
				Assert.fail();
			}
			if (atribut10Nou != entitatRead.getAtribut10()){
				session.close();
				Assert.fail();
			}
			if (!atribut11Nou.equals(entitatRead.getAtribut11())){
				session.close();
				Assert.fail();
			}
			if (!atribut12Nou.equals(entitatRead.getAtribut12())){
				session.close();
				Assert.fail();
			}
			if (!atribut13Nou.equals(entitatRead.getAtribut13())){
				session.close();
				Assert.fail();
			}
			if (atribut14Nou != entitatRead.getAtribut14()){
				session.close();
				Assert.fail();
			}
			if (!atribut15Nou.equals(entitatRead.getAtribut15())){
				session.close();
				Assert.fail();
			}
			if (atribut16Nou != entitatRead.getAtribut16()){
				session.close();
				Assert.fail();
			}
			if (!atribut17Nou.equals(entitatRead.getAtribut17())){
				session.close();
				Assert.fail();
			}
			if (atribut18Nou != entitatRead.getAtribut18()){
				session.close();
				Assert.fail();
			}
			if (!atribut19Nou.equals(entitatRead.getAtribut19())){
				session.close();
				Assert.fail();
			}
			if (atribut20Nou != entitatRead.getAtribut20()){
				session.close();
				Assert.fail();
			}
			if (!atribut21Nou.equals(entitatRead.getAtribut21())){
				session.close();
				Assert.fail();
			}
			if (!atribut22Nou.equals(entitatRead.getAtribut22())){
				session.close();
				Assert.fail();
			}
			if (!atribut23Nou.equals(entitat.getAtribut23())){
				session.close();
				Assert.fail();
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0001.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0002(){
		Session session 				= null;
		Entitat0001 entitat				= null;
		String nameEntity				= Entitat0001.class.getCanonicalName();
		int atribut1					= 1;
		String atribut2					= "Valor de l'atribut 2.";
		String atribut2Nou				= "Nou valor de l'atribut2";
		char atribut3					= 'd';
		char atribut3Nou				= 'e';
		Character atribut4				= new Character('f');
		Character atribut4Nou			= new Character('p');
		char[] atribut5					= "Valor de l'atribut 5".toCharArray();
		char[] atribut5Nou				= "Nou valor de l'atribut 5".toCharArray();
		int atribut6					= 55230;
		int atribut6Nou					= 68000;
		Integer atribut7				= new Integer("1500");
		Integer atribut7Nou				= new Integer("960");
		float atribut8					= 1.5f;
		float atribut8Nou				= 5.6f;
		Float atribut9					= new Float(2.36f);
		Float atribut9Nou				= new Float(6.12f);
		double atribut10				= 4.5d;
		double atribut10Nou				= 1.36d;
		Double atribut11				= new Double(5.25);
		Double atribut11Nou				= new Double(85.231);
		BigDecimal atribut12			= new BigDecimal("1234567.3421");
		BigDecimal atribut12Nou			= new BigDecimal("63000.1234");
		Date atribut13					= null;
		Date atribut13Nou				= null;
		byte atribut14					= 15;
		byte atribut14Nou 				= 10;
		Byte atribut15					= new Byte("30");
		Byte atribut15Nou				= new Byte("45");
		short atribut16					= 45;
		short atribut16Nou				= 12;
		Short atribut17					= new Short("36");
		Short atribut17Nou				= new Short("63");
		long atribut18					= 789888;
		long atribut18Nou				= 800000;
		Long atribut19					= new Long("150000");
		Long atribut19Nou				= new Long("2553311");
		boolean atribut20				= true;
		boolean atribut20Nou			= false;
		Boolean atribut21				= new Boolean(true);
		Boolean atribut21Nou			= new Boolean(false);
		Time atribut22					= Time.valueOf("19:30:30");
		Time atribut22Nou				= Time.valueOf("20:00:05");
		BigInteger atribut23			= new BigInteger("123456788888");
		BigInteger atribut23Nou			= new BigInteger("999912345678901");
		GregorianCalendar gc			= null;
		GregorianCalendar gcNou			= null;
		
		
		gc = new GregorianCalendar(2012, 11, 16);
		gcNou = new GregorianCalendar(2012, 11, 25);
		atribut13 = new Date(gc.getTime().getTime());
		atribut13Nou = new Date(gcNou.getTime().getTime());
		
		entitat = new Entitat0001();
		entitat.setAtribut1(atribut1);
		entitat.setAtribut2(atribut2);
		entitat.setAtribut3(atribut3);
		entitat.setAtribut4(atribut4);
		entitat.setAtribut5(atribut5);
		entitat.setAtribut6(atribut6);
		entitat.setAtribut7(atribut7);
		entitat.setAtribut8(atribut8);
		entitat.setAtribut9(atribut9);
		entitat.setAtribut10(atribut10);
		entitat.setAtribut11(atribut11);
		entitat.setAtribut12(atribut12);
		entitat.setAtribut13(atribut13);
		entitat.setAtribut14(atribut14);
		entitat.setAtribut15(atribut15);
		entitat.setAtribut16(atribut16);
		entitat.setAtribut17(atribut17);
		entitat.setAtribut18(atribut18);
		entitat.setAtribut19(atribut19);
		entitat.setAtribut20(atribut20);
		entitat.setAtribut21(atribut21);
		entitat.setAtribut22(atribut22);
		entitat.setAtribut23(atribut23);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail();
		}
		
		try {
			session.drop(nameEntity);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}	

		entitat.setAtribut1(2);
		entitat.setAtribut2(atribut2Nou);
		entitat.setAtribut3(atribut3Nou);
		entitat.setAtribut4(atribut4Nou);
		entitat.setAtribut5(atribut5Nou);
		entitat.setAtribut6(atribut6Nou);
		entitat.setAtribut7(atribut7Nou);
		entitat.setAtribut8(atribut8Nou);
		entitat.setAtribut9(atribut9Nou);
		entitat.setAtribut10(atribut10Nou);
		entitat.setAtribut11(atribut11Nou);
		entitat.setAtribut12(atribut12Nou);
		entitat.setAtribut13(atribut13Nou);
		entitat.setAtribut14(atribut14Nou);
		entitat.setAtribut15(atribut15Nou);
		entitat.setAtribut16(atribut16Nou);
		entitat.setAtribut17(atribut17Nou);
		entitat.setAtribut18(atribut18Nou);
		entitat.setAtribut19(atribut19Nou);
		entitat.setAtribut20(atribut20Nou);
		entitat.setAtribut21(atribut21Nou);
		entitat.setAtribut22(atribut22Nou);
		entitat.setAtribut23(atribut23Nou);
		
		try {
			session.update(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0003(){
		Entitat0001 entitat			= null;
		Session session				= null;
		String nameEntity			= Entitat0001.class.getCanonicalName();
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			}
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.update(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0004(){
		Entitat0002 entitat					= null;
		Session session						= null;
		String nameEntity					= Entitat0002.class.getCanonicalName();
		int numObjectes						= 300;
		ArrayList<Entitat0002> objectes		= null;
		ArrayList<Entitat0002> objectesNous	= null;
		BigDecimal atribut3					= null;
		BigInteger atribut4					= null;
		ArrayList<Object> pk				= null;
		Entitat0002 entitatRead				= null;
		
		objectes = new ArrayList<Entitat0002>();
		objectesNous = new ArrayList<Entitat0002>();
		
		for (int i = 0; i < numObjectes; i++){
			entitat = new Entitat0002();
			entitat.setAtribut1(i);
			entitat.setAtribut2("Valor atribut2 " + i);
			atribut3 = new BigDecimal("15.58");
			entitat.setAtribut3(atribut3);
			atribut4 = new BigInteger("1234567" + i);
			entitat.setAtribut4(atribut4);
			objectes.add(entitat);
			
			entitat = new Entitat0002();
			entitat.setAtribut1(i);
			entitat.setAtribut2("Valor atribut2 " + i + 5);
			atribut3 = new BigDecimal("36.75");
			entitat.setAtribut3(atribut3);
			atribut4 = new BigInteger("1234568000" + i);
			entitat.setAtribut4(atribut4);
			objectesNous.add(entitat);
		}
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			}
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		for (Entitat0002 entitat2: objectes){
			try {
				session.insert(entitat2);
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		for (Entitat0002 entitat2: objectesNous){
			try {
				session.update(entitat2);
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		for (Entitat0002 entitat2: objectesNous){
			pk = new ArrayList<Object>();
			pk.add(entitat2.getAtribut1());
			
			try {
				entitatRead = (Entitat0002) session.read(nameEntity, pk);
				
				if (entitatRead == null){
					session.close();
					Assert.fail("No s'ha trobat l'objecte en la base de dades.");
				}
				if (!entitat2.getAtribut2().equals(entitatRead.getAtribut2())){
					session.close();
					Assert.fail("L'actualitzaci no ha sigut correcta.");
				}
				if (!entitat2.getAtribut3().equals(entitatRead.getAtribut3())){
					session.close();
					Assert.fail("L'actualitzaci no ha sigut correcta.");
				}
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		try {
			session.drop(nameEntity);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
}
