package test.mapping.foreignkey;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;

import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import org.junit.runners.Parameterized.Parameters;


import com.uoc.myframeuoc.environment.Session;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;


/**
 * Proves de les claus foranes.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
@RunWith(Parameterized.class)
public class ForeignKeyTest {
	private String file		= null;
	
	@Parameters
	public static Collection<Object[]> data(){
		Object[][] data = {
							{"test/ConfigurationFiles/OracleConfiguration.xml"}, 
							{"test/ConfigurationFiles/MySQLConfiguration.xml"}
						};
		return Arrays.asList(data);
	}
	
	public ForeignKeyTest(String file){
		this.file = file;
	}

	@Test
	public void test0001(){
		Session session				= null;
		Entitat0001A entitat1		= null;
		Entitat0001B entitat2		= null;
		String nameEntity1			= Entitat0001A.class.getCanonicalName();
		String nameEntity2			= Entitat0001B.class.getCanonicalName();
		
		entitat2 = new Entitat0001B();
		entitat2.setAtribut1B(1);
		entitat2.setAtribut2B("Valor del camp2B");
		
		entitat1 = new Entitat0001A();
		entitat1.setAtribut1A(1);
		entitat1.setAtribut2A("Valor del camp2A");
		entitat1.setAtribut3A(entitat2);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity1);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity2);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat1);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity1);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity2);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0002(){
		Session session						= null;
		Entitat0002A entitat0002A			= null;
		Entitat0002B entitat0002B			= null;
		Entitat0002A entitat0002ARead		= null;
		Entitat0002B entitat0002BRead 		= null;
		String nameEntity1					= Entitat0002A.class.getCanonicalName();
		String nameEntity2					= Entitat0002B.class.getCanonicalName();
		ArrayList<Object> pk				= null;
		int atribut1A						= 1;
		String atribut2A					= "Valor del camp2A";
		Entitat0002B atribut3A				= null;
		int atribut1B						= 1;
		String atribut2B					= "Valor del camp2B";
		Entitat0002A atribut3B				= null;
		String atribut2ANou					= "Valor del camp2A nou";
		Entitat0002B atribut3ANou			= null;
		int atribut1BNou					= 2;
		String atribut2BNou					= "Valor del camp2B nou";
		Entitat0002A atribut3BNou			= null;
		
		entitat0002A = new Entitat0002A();
		entitat0002A.setAtribut1A(atribut1A);
		entitat0002A.setAtribut2A(atribut2A);
		
		entitat0002B = new Entitat0002B();
		entitat0002B.setAtribut1B(atribut1B);
		entitat0002B.setAtribut2B(atribut2B);
		
		atribut3A = entitat0002B;
		atribut3B = entitat0002A;
		
		entitat0002A.setAtribut3A(atribut3A);
		entitat0002B.setAtribut3B(atribut3B);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity1);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat0002A);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk = new ArrayList<Object>();
		pk.add(1);
		
		try {
			entitat0002ARead = (Entitat0002A) session.read(nameEntity1, pk);
			if (entitat0002ARead == null){
				session.close();
				Assert.fail("No s'ha pogut llegir l'objecte de l'entitat Entitat0002A de la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		
		entitat0002B = new Entitat0002B();
		entitat0002B.setAtribut1B(atribut1BNou);
		entitat0002B.setAtribut2B(atribut2BNou);
		
		entitat0002A.setAtribut2A(atribut2ANou);
		
		atribut3ANou = entitat0002B;
		atribut3BNou = entitat0002A;
		
		entitat0002A.setAtribut3A(atribut3ANou);
		entitat0002B.setAtribut3B(atribut3BNou);
		
		try {
			session.update(entitat0002A);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {	
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atribut1BNou);
		
		try {
			entitat0002BRead = (Entitat0002B) session.read(nameEntity2, pk);
			if (entitat0002BRead == null){
				session.close();
				Assert.fail("No s'ha llegit l'objecte de l'entitat Entitat0002B de la base de dades.");
			}
			if (!atribut2BNou.equals(entitat0002BRead.getAtribut2B())){
				session.close();
				Assert.fail("L'actualitzaci de l'objecte de l'entitat Entitat0002A no s'ha fet correctament.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atribut1A);
		try {
			entitat0002ARead = (Entitat0002A) session.read(nameEntity1, pk);
			if (entitat0002ARead == null){
				session.close();
				Assert.fail("No s'ha pogut llegir l'objecte de l'entitat Entitat0002A.");
			}
			if (!atribut2ANou.equals(entitat0002ARead.getAtribut2A())){
				session.close();
				Assert.fail("L'actualitzaci de l'objecte de l'entitat Entitat0002A no s'ha fet correctament.");
			}
			if (atribut3ANou.getAtribut1B() != entitat0002ARead.getAtribut3A().getAtribut1B()){
				session.close();
				Assert.fail("L'actualitzaci de l'objecte de l'entitat Entitat0002A no s'ha fet correctament.");
			}
			if (!atribut3ANou.getAtribut2B().equals(entitat0002ARead.getAtribut3A().getAtribut2B())){
				session.close();
				Assert.fail("L'actualitzaci de l'objecte de l'entitat Entitat0002A no s'ha fet correctament.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atribut1B);
		
		try {
			entitat0002BRead = (Entitat0002B) session.read(nameEntity2, pk);
			if (entitat0002BRead != null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat002B amb clau primria 1 no hauria d'existir en la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity1);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0003(){
		Session session						= null;
		Entitat0002A entitat0002A			= null;
		Entitat0002B entitat0002B			= null;
		Entitat0002A entitat0002ARead		= null;
		Entitat0002B entitat0002BRead 		= null;
		String nameEntity1					= Entitat0002A.class.getCanonicalName();
		String nameEntity2					= Entitat0002B.class.getCanonicalName();
		ArrayList<Object> pk				= null;
		int atribut1A						= 1;
		String atribut2A					= "Valor del camp2A";
		Entitat0002B atribut3A				= null;
		int atribut1B						= 1;
		String atribut2B					= "Valor del camp2B";
		Entitat0002A atribut3B				= null;
		
		entitat0002A = new Entitat0002A();
		entitat0002A.setAtribut1A(atribut1A);
		entitat0002A.setAtribut2A(atribut2A);
		
		entitat0002B = new Entitat0002B();
		entitat0002B.setAtribut1B(atribut1B);
		entitat0002B.setAtribut2B(atribut2B);
		
		atribut3A = entitat0002B;
		atribut3B = entitat0002A;
		
		entitat0002A.setAtribut3A(atribut3A);
		entitat0002B.setAtribut3B(atribut3B);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity1);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitat0002A);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat0002A);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk = new ArrayList<Object>();
		pk.add(1);
		
		try {
			entitat0002ARead = (Entitat0002A) session.read(nameEntity1, pk);
			if (entitat0002ARead == null){
				session.close();
				Assert.fail("No s'ha pogut llegir l'objecte de l'entitat Entitat0002A de la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitat0002B);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk = new ArrayList<Object>();
		pk.add(atribut1A);
		try {
			entitat0002ARead = (Entitat0002A) session.read(nameEntity1, pk);
			if (entitat0002ARead != null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat0002A no s'ha eliminat correctament de la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			}
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atribut1B);
		try {
			entitat0002BRead = (Entitat0002B) session.read(nameEntity2, pk);
			if (entitat0002BRead != null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat0002B no s'ha eliminat correctament de la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitat0002A);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			}
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity1);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0004(){
		Entitat4A entitat4A				= new Entitat4A();
		Entitat4B entitat4B				= new Entitat4B();
		Entitat4C entitat4C				= new Entitat4C();
		Entitat4D entitat4D				= new Entitat4D();
		String nameEntity4A				= Entitat4A.class.getCanonicalName();
		String nameEntity4B				= Entitat4B.class.getCanonicalName();
		String nameEntity4C				= Entitat4C.class.getCanonicalName();
		String nameEntity4D				= Entitat4D.class.getCanonicalName();
		ArrayList<Object> atributs4A	= new ArrayList<Object>();
		ArrayList<Object> atributs4B	= new ArrayList<Object>();
		ArrayList<Object> atributs4C	= new ArrayList<Object>();
		ArrayList<Object> atributs4D	= new ArrayList<Object>();
		Session session					= null;
		Entitat4A entitat4ARead			= null;
		Entitat4B entitat4BRead			= null;
		Entitat4C entitat4CRead			= null;
		Entitat4D entitat4DRead			= null;
		ArrayList<Object> pk			= null;
		
		atributs4A.add(1);
		atributs4A.add(new String("Valor atribut2A"));
		
		atributs4B.add(1);
		atributs4B.add(new String("Valor atribut2B"));
		
		atributs4C.add(1);
		atributs4C.add(new String("Valor atribut2C"));
		
		atributs4D.add(1);
		atributs4D.add(new String("Valor atribut2D"));
		
		entitat4A.setAtribut1A(Integer.parseInt(String.valueOf(atributs4A.get(0))));
		entitat4A.setAtribut2A((String) atributs4A.get(1));
		
		entitat4B.setAtribut1B(Integer.parseInt(String.valueOf(atributs4B.get(0))));
		entitat4B.setAtribut2B((String) atributs4B.get(1));
		
		entitat4C.setAtribut1C(Integer.parseInt(String.valueOf(atributs4C.get(0))));
		entitat4C.setAtribut2C((String) atributs4C.get(1));
		
		entitat4D.setAtribut1D(Integer.parseInt(String.valueOf(atributs4D.get(0))));
		entitat4D.setAtribut2D((String) atributs4D.get(1));
		
		entitat4A.setAtribut3A(entitat4B);
		entitat4B.setAtribut3B(entitat4A);
		entitat4B.setAtribut4B(entitat4C);
		entitat4C.setAtribut3C(entitat4D);
		entitat4D.setAtribut3D(entitat4B);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4A);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			
			session.insert(entitat4A);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk = new ArrayList<Object>();
		pk.add(atributs4A.get(0));
		
		try {
			entitat4ARead = (Entitat4A) session.read(nameEntity4A, pk);
			if (entitat4ARead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4A no s'ha pogut llegir de la base de dades.");
			}
			if (!String.valueOf(atributs4A.get(1)).equals(entitat4ARead.getAtribut2A())){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4A que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
			if (entitat4B.getAtribut1B() != entitat4ARead.getAtribut3A().getAtribut1B()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4A que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atributs4B.get(0));
		
		try {
			entitat4BRead = (Entitat4B) session.read(nameEntity4B, pk);
			if (entitat4BRead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4B no s'ha pogut llegir de la base de dades.");
			}
			if (!String.valueOf(atributs4B.get(1)).equals(entitat4BRead.getAtribut2B())){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4B que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
			if (entitat4A.getAtribut1A() != entitat4BRead.getAtribut3B().getAtribut1A()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4B que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
			if (entitat4C.getAtribut1C() != entitat4BRead.getAtribut4B().getAtribut1C()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4B que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atributs4C.get(0));
		try {
			entitat4CRead = (Entitat4C) session.read(nameEntity4C, pk);
			if (entitat4CRead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4C no s'ha pogut llegir de la base de dades.");
			}
			if (!atributs4C.get(1).equals(entitat4CRead.getAtribut2C())){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4C que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
			if (entitat4D.getAtribut1D() != entitat4CRead.getAtribut3C().getAtribut1D()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4C que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atributs4D.get(0));
		try {
			entitat4DRead = (Entitat4D) session.read(nameEntity4D, pk);
			if (entitat4DRead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4D no s'ha pogut llegir de la base de dades.");
			}
			if (!atributs4D.get(1).equals(entitat4DRead.getAtribut2D())){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4D que s'ha llegir de la base de dades no coincideix amb el que s'ha inserit.");
			}
			if (entitat4B.getAtribut1B() != entitat4DRead.getAtribut3D().getAtribut1B()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4D que s'ha llegir de la base de dades no coincideix amb el que s'ha inserit.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4A);
		}
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0005(){
		Entitat4A entitat4A				= new Entitat4A();
		Entitat4B entitat4B				= new Entitat4B();
		Entitat4C entitat4C				= new Entitat4C();
		Entitat4D entitat4D				= new Entitat4D();
		Entitat4E entitat4E				= new Entitat4E();
		String nameEntity4A				= Entitat4A.class.getCanonicalName();
		String nameEntity4B				= Entitat4B.class.getCanonicalName();
		String nameEntity4C				= Entitat4C.class.getCanonicalName();
		String nameEntity4D				= Entitat4D.class.getCanonicalName();
		String nameEntity4E				= Entitat4E.class.getCanonicalName();
		ArrayList<Object> atributs4A	= new ArrayList<Object>();
		ArrayList<Object> atributs4B	= new ArrayList<Object>();
		ArrayList<Object> atributs4C	= new ArrayList<Object>();
		ArrayList<Object> atributs4D	= new ArrayList<Object>();
		ArrayList<Object> atributs4E	= new ArrayList<Object>();
		Session session					= null;
		Entitat4A entitat4ARead			= null;
		Entitat4B entitat4BRead			= null;
		Entitat4C entitat4CRead			= null;
		Entitat4D entitat4DRead			= null;
		Entitat4E entitat4ERead			= null;
		ArrayList<Object> pk			= null;
		
		atributs4A.add(1);
		atributs4A.add(new String("Valor atribut2A"));
		
		atributs4B.add(1);
		atributs4B.add(new String("Valor atribut2B"));
		
		atributs4C.add(1);
		atributs4C.add(new String("Valor atribut2C"));
		
		atributs4D.add(1);
		atributs4D.add(new String("Valor atribut2D"));
		
		atributs4E.add(1);
		atributs4E.add(new String("Valor atribut2E"));
		
		entitat4A.setAtribut1A(Integer.parseInt(String.valueOf(atributs4A.get(0))));
		entitat4A.setAtribut2A(String.valueOf(atributs4A.get(1)));
		
		entitat4B.setAtribut1B(Integer.parseInt(String.valueOf(atributs4B.get(0))));
		entitat4B.setAtribut2B(String.valueOf(atributs4B.get(1)));
		
		entitat4C.setAtribut1C(Integer.parseInt(String.valueOf(atributs4C.get(0))));
		entitat4C.setAtribut2C(String.valueOf(atributs4C.get(1)));
		
		entitat4D.setAtribut1D(Integer.parseInt(String.valueOf(atributs4D.get(0))));
		entitat4D.setAtribut2D(String.valueOf(atributs4D.get(1)));
		
		entitat4E.setAtribut1E(Integer.parseInt(String.valueOf(atributs4E.get(0))));
		entitat4E.setAtribut2E(String.valueOf(atributs4E.get(1)));
		
		entitat4A.setAtribut3A(entitat4B);
		entitat4B.setAtribut3B(entitat4A);
		entitat4B.setAtribut4B(entitat4C);
		entitat4C.setAtribut3C(entitat4D);
		entitat4D.setAtribut3D(entitat4B);
		entitat4E.setAtribut3E(entitat4B);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4E);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4A);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			
			session.insert(entitat4A);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat4E);
		}
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk = new ArrayList<Object>();
		pk.add(atributs4A.get(0));
		
		try {
			entitat4ARead = (Entitat4A) session.read(nameEntity4A, pk);
			if (entitat4ARead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4A no s'ha pogut llegir de la base de dades.");
			}
			if (!String.valueOf(atributs4A.get(1)).equals(entitat4ARead.getAtribut2A())){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4A que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
			if (entitat4B.getAtribut1B() != entitat4ARead.getAtribut3A().getAtribut1B()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4A que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atributs4B.get(0));
		
		try {
			entitat4BRead = (Entitat4B) session.read(nameEntity4B, pk);
			if (entitat4BRead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4B no s'ha pogut llegir de la base de dades.");
			}
			if (!String.valueOf(atributs4B.get(1)).equals(entitat4BRead.getAtribut2B())){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4B que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
			if (entitat4A.getAtribut1A() != entitat4BRead.getAtribut3B().getAtribut1A()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4B que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
			if (entitat4C.getAtribut1C() != entitat4BRead.getAtribut4B().getAtribut1C()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4B que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atributs4C.get(0));
		try {
			entitat4CRead = (Entitat4C) session.read(nameEntity4C, pk);
			if (entitat4CRead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4C no s'ha pogut llegir de la base de dades.");
			}
			if (!atributs4C.get(1).equals(entitat4CRead.getAtribut2C())){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4C que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
			if (entitat4D.getAtribut1D() != entitat4CRead.getAtribut3C().getAtribut1D()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4C que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atributs4D.get(0));
		try {
			entitat4DRead = (Entitat4D) session.read(nameEntity4D, pk);
			if (entitat4DRead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4D no s'ha pogut llegir de la base de dades.");
			}
			if (!atributs4D.get(1).equals(entitat4DRead.getAtribut2D())){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4D que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
			if (entitat4B.getAtribut1B() != entitat4DRead.getAtribut3D().getAtribut1B()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4D que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atributs4E.get(0));
		try {
			entitat4ERead = (Entitat4E) session.read(nameEntity4E, pk);
			if (entitat4ERead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4E no s'ha pogut llegir de la base de dades.");
			}
			if (!atributs4E.get(1).equals(entitat4ERead.getAtribut2E())){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4E que s'ha legit de la base de dades no coincideix amb el que s'ha inserit.");
			}
			if (entitat4B.getAtribut1B() != entitat4ERead.getAtribut3E().getAtribut1B()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4E que s'ha legit de la base de dades no coincideix amb el que s'ha inserit.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4E);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			}
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4A);
		}
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0006(){
		Entitat4A entitat4A				= new Entitat4A();
		Entitat4B entitat4B				= new Entitat4B();
		Entitat4C entitat4C				= new Entitat4C();
		Entitat4D entitat4D				= new Entitat4D();
		Entitat4E entitat4E				= new Entitat4E();
		Entitat4F entitat4F				= new Entitat4F();
		String nameEntity4A				= Entitat4A.class.getCanonicalName();
		String nameEntity4B				= Entitat4B.class.getCanonicalName();
		String nameEntity4C				= Entitat4C.class.getCanonicalName();
		String nameEntity4D				= Entitat4D.class.getCanonicalName();
		String nameEntity4E				= Entitat4E.class.getCanonicalName();
		String nameEntity4F				= Entitat4F.class.getCanonicalName();
		ArrayList<Object> atributs4A	= new ArrayList<Object>();
		ArrayList<Object> atributs4B	= new ArrayList<Object>();
		ArrayList<Object> atributs4C	= new ArrayList<Object>();
		ArrayList<Object> atributs4D	= new ArrayList<Object>();
		ArrayList<Object> atributs4E	= new ArrayList<Object>();
		ArrayList<Object> atributs4F	= new ArrayList<Object>();
		Session session					= null;
		Entitat4A entitat4ARead			= null;
		Entitat4B entitat4BRead			= null;
		Entitat4C entitat4CRead			= null;
		Entitat4D entitat4DRead			= null;
		Entitat4E entitat4ERead			= null;
		Entitat4F entitat4FRead			= null;
		ArrayList<Object> pk			= null;
		
		atributs4A.add(1);
		atributs4A.add(new String("Valor atribut2A"));
		
		atributs4B.add(1);
		atributs4B.add(new String("Valor atribut2B"));
		
		atributs4C.add(1);
		atributs4C.add(new String("Valor atribut2C"));
		
		atributs4D.add(1);
		atributs4D.add(new String("Valor atribut2D"));
		
		atributs4E.add(1);
		atributs4E.add(new String("Valor atribut2E"));
		
		atributs4F.add(1);
		atributs4F.add(new String("Valor atribut2F"));
		
		entitat4A.setAtribut1A(Integer.parseInt(String.valueOf(atributs4A.get(0))));
		entitat4A.setAtribut2A(String.valueOf(atributs4A.get(1)));
		
		entitat4B.setAtribut1B(Integer.parseInt(String.valueOf(atributs4B.get(0))));
		entitat4B.setAtribut2B(String.valueOf(atributs4B.get(1)));
		
		entitat4C.setAtribut1C(Integer.parseInt(String.valueOf(atributs4C.get(0))));
		entitat4C.setAtribut2C(String.valueOf(atributs4C.get(1)));
		
		entitat4D.setAtribut1D(Integer.parseInt(String.valueOf(atributs4D.get(0))));
		entitat4D.setAtribut2D(String.valueOf(atributs4D.get(1)));
		
		entitat4E.setAtribut1E(Integer.parseInt(String.valueOf(atributs4E.get(0))));
		entitat4E.setAtribut2E(String.valueOf(atributs4E.get(1)));
		
		entitat4F.setAtribut1F(Integer.parseInt(String.valueOf(atributs4F.get(0))));
		entitat4F.setAtribut2F(String.valueOf(atributs4F.get(1)));
		
		entitat4A.setAtribut3A(entitat4B);
		entitat4B.setAtribut3B(entitat4A);
		entitat4B.setAtribut4B(entitat4C);
		entitat4C.setAtribut3C(entitat4D);
		entitat4D.setAtribut3D(entitat4B);
		entitat4E.setAtribut3E(entitat4B);
		entitat4F.setAtribut3F(entitat4E);
		entitat4F.setAtribut4F(entitat4C);
		entitat4F.setAtribut5F(entitat4D);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4F);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4E);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4A);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat4A);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat4E);
		}
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat4F);
		}
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
	
		pk = new ArrayList<Object>();
		pk.add(atributs4A.get(0));
		
		try {
			entitat4ARead = (Entitat4A) session.read(nameEntity4A, pk);
			if (entitat4ARead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4A no s'ha pogut llegir de la base de dades.");
			}
			if (!String.valueOf(atributs4A.get(1)).equals(entitat4ARead.getAtribut2A())){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4A que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
			if (entitat4B.getAtribut1B() != entitat4ARead.getAtribut3A().getAtribut1B()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4A que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atributs4B.get(0));
		
		try {
			entitat4BRead = (Entitat4B) session.read(nameEntity4B, pk);
			if (entitat4BRead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4B no s'ha pogut llegir de la base de dades.");
			}
			if (!String.valueOf(atributs4B.get(1)).equals(entitat4BRead.getAtribut2B())){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4B que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
			if (entitat4A.getAtribut1A() != entitat4BRead.getAtribut3B().getAtribut1A()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4B que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
			if (entitat4C.getAtribut1C() != entitat4BRead.getAtribut4B().getAtribut1C()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4B que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atributs4C.get(0));
		try {
			entitat4CRead = (Entitat4C) session.read(nameEntity4C, pk);
			if (entitat4CRead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4C no s'ha pogut llegir de la base de dades.");
			}
			if (!atributs4C.get(1).equals(entitat4CRead.getAtribut2C())){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4C que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
			if (entitat4D.getAtribut1D() != entitat4CRead.getAtribut3C().getAtribut1D()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4C que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atributs4D.get(0));
		try {
			entitat4DRead = (Entitat4D) session.read(nameEntity4D, pk);
			if (entitat4DRead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4D no s'ha pogut llegir de la base de dades.");
			}
			if (!atributs4D.get(1).equals(entitat4DRead.getAtribut2D())){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4D que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
			if (entitat4B.getAtribut1B() != entitat4DRead.getAtribut3D().getAtribut1B()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4D que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atributs4E.get(0));
		try {
			entitat4ERead = (Entitat4E) session.read(nameEntity4E, pk);
			if (entitat4ERead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4E no s'ha pogut llegir de la base de dades.");
			}
			if (!atributs4E.get(1).equals(entitat4ERead.getAtribut2E())){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4E que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
			if (entitat4B.getAtribut1B() != entitat4ERead.getAtribut3E().getAtribut1B()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4E que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atributs4F.get(0));
		try {
			entitat4FRead = (Entitat4F) session.read(nameEntity4F, pk);
			if (entitat4FRead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4F no s'ha pogut llegir de la base de dades.");
			}
			if (!atributs4F.get(1).equals(entitat4FRead.getAtribut2F())){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4F que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
			if (entitat4FRead.getAtribut3F().getAtribut1E() != entitat4E.getAtribut1E()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4F que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
			if (entitat4FRead.getAtribut4F().getAtribut1C() != entitat4C.getAtribut1C()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4F que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
			if (entitat4FRead.getAtribut5F().getAtribut1D() != entitat4D.getAtribut1D()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4F que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4F);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4E);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			}
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4A);
		}
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0007(){
		Entitat4A entitat4A						= null;
		Entitat4B entitat4B						= null;
		Entitat4C entitat4C						= null;
		Entitat4D entitat4D						= null;
		Entitat4E entitat4E						= null;
		Entitat4F entitat4F						= null;
		String nameEntity4A						= Entitat4A.class.getCanonicalName();
		String nameEntity4B						= Entitat4B.class.getCanonicalName();
		String nameEntity4C						= Entitat4C.class.getCanonicalName();
		String nameEntity4D						= Entitat4D.class.getCanonicalName();
		String nameEntity4E						= Entitat4E.class.getCanonicalName();
		String nameEntity4F						= Entitat4F.class.getCanonicalName();
		ArrayList<Object> atributs4A			= new ArrayList<Object>();
		ArrayList<Object> atributs4B			= new ArrayList<Object>();
		ArrayList<Object> atributs4C			= new ArrayList<Object>();
		ArrayList<Object> atributs4D			= new ArrayList<Object>();
		ArrayList<Object> atributs4E			= new ArrayList<Object>();
		ArrayList<Object> atributs4F			= new ArrayList<Object>();
		Session session							= null;
		Entitat4A entitat4ARead					= null;
		Entitat4B entitat4BRead					= null;
		Entitat4C entitat4CRead					= null;
		Entitat4D entitat4DRead					= null;
		Entitat4E entitat4ERead					= null;
		Entitat4F entitat4FRead					= null;
		ArrayList<Object> pk					= null;
		ArrayList<Entitat4A> entitats4A			= new ArrayList<Entitat4A>();
		ArrayList<Entitat4B> entitats4B			= new ArrayList<Entitat4B>();
		ArrayList<Entitat4C> entitats4C 		= new ArrayList<Entitat4C>();
		ArrayList<Entitat4D> entitats4D 		= new ArrayList<Entitat4D>();
		ArrayList<Entitat4E> entitats4E 		= new ArrayList<Entitat4E>();
		ArrayList<Entitat4F> entitats4F 		= new ArrayList<Entitat4F>();
		int numEntitats							= 100;
		ArrayList<Object> atributs4ANous		= new ArrayList<Object>();
		ArrayList<Object> atributs4BNous		= new ArrayList<Object>();
		
		for (int i = 0; i < numEntitats; i++){
			entitat4A = new Entitat4A();
			entitat4B = new Entitat4B();
			entitat4C = new Entitat4C();
			entitat4D = new Entitat4D();
			entitat4E = new Entitat4E();
			entitat4F = new Entitat4F();
			
			atributs4A.clear();
			atributs4A.add(i);
			atributs4A.add(new String("Valor atribut2A " + i));

			atributs4B.clear();
			atributs4B.add(i);
			atributs4B.add(new String("Valor atribut2B " + i));

			atributs4C.clear();
			atributs4C.add(i);
			atributs4C.add(new String("Valor atribut2C " + i));

			atributs4D.clear();
			atributs4D.add(i);
			atributs4D.add(new String("Valor atribut2D " + i));

			atributs4E.clear();
			atributs4E.add(i);
			atributs4E.add(new String("Valor atribut2E " + i));

			atributs4F.clear();
			atributs4F.add(i);
			atributs4F.add(new String("Valor atribut2F " + i));

			entitat4A.setAtribut1A(Integer.parseInt(String.valueOf(atributs4A.get(0))));
			entitat4A.setAtribut2A(String.valueOf(atributs4A.get(1)));

			entitat4B.setAtribut1B(Integer.parseInt(String.valueOf(atributs4B.get(0))));
			entitat4B.setAtribut2B(String.valueOf(atributs4B.get(1)));

			entitat4C.setAtribut1C(Integer.parseInt(String.valueOf(atributs4C.get(0))));
			entitat4C.setAtribut2C(String.valueOf(atributs4C.get(1)));

			entitat4D.setAtribut1D(Integer.parseInt(String.valueOf(atributs4D.get(0))));
			entitat4D.setAtribut2D(String.valueOf(atributs4D.get(1)));

			entitat4E.setAtribut1E(Integer.parseInt(String.valueOf(atributs4E.get(0))));
			entitat4E.setAtribut2E(String.valueOf(atributs4E.get(1)));

			entitat4F.setAtribut1F(Integer.parseInt(String.valueOf(atributs4F.get(0))));
			entitat4F.setAtribut2F(String.valueOf(atributs4F.get(1)));

			entitat4A.setAtribut3A(entitat4B);
			entitat4B.setAtribut3B(entitat4A);
			entitat4B.setAtribut4B(entitat4C);
			entitat4C.setAtribut3C(entitat4D);
			entitat4D.setAtribut3D(entitat4B);
			entitat4E.setAtribut3E(entitat4B);
			entitat4F.setAtribut3F(entitat4E);
			entitat4F.setAtribut4F(entitat4C);
			entitat4F.setAtribut5F(entitat4D);
			
			entitats4A.add(entitat4A);
			entitats4B.add(entitat4B);
			entitats4C.add(entitat4C);
			entitats4D.add(entitat4D);
			entitats4E.add(entitat4E);
			entitats4F.add(entitat4F);
		}
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4F);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4E);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4A);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		for (int i = 0; i < numEntitats; i++){
			try {
				session.insert(entitats4A.get(i));
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}

			try {
				session.insert(entitats4E.get(i));
			}
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}

			try {
				session.insert(entitats4F.get(i));
			}
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}

			pk = new ArrayList<Object>();
			pk.add(entitats4A.get(i).getAtribut1A());

			try {
				entitat4ARead = (Entitat4A) session.read(nameEntity4A, pk);
				if (entitat4ARead == null){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4A no s'ha pogut llegir de la base de dades.");
				}
				if (!entitats4A.get(i).getAtribut2A().equals(entitat4ARead.getAtribut2A())){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4A que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
				}
				if (entitats4A.get(i).getAtribut3A().getAtribut1B() != entitat4ARead.getAtribut3A().getAtribut1B()){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4A que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
				}
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}

			pk.clear();
			pk.add(entitats4B.get(i).getAtribut1B());

			try {
				entitat4BRead = (Entitat4B) session.read(nameEntity4B, pk);
				if (entitat4BRead == null){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4B no s'ha pogut llegir de la base de dades.");
				}
				if (!entitats4B.get(i).getAtribut2B().equals(entitat4BRead.getAtribut2B())){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4B que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
				}
				if (entitats4B.get(i).getAtribut3B().getAtribut1A() != entitat4BRead.getAtribut3B().getAtribut1A()){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4B que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
				}
				if (entitats4B.get(i).getAtribut4B().getAtribut1C() != entitat4BRead.getAtribut4B().getAtribut1C()){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4B que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
				}
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}

			pk.clear();
			pk.add(entitats4C.get(i).getAtribut1C());
			
			try {
				entitat4CRead = (Entitat4C) session.read(nameEntity4C, pk);
				if (entitat4CRead == null){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4C no s'ha pogut llegir de la base de dades.");
				}
				if (entitats4C.get(i).getAtribut1C() != entitat4CRead.getAtribut1C()){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4C que s'ha llelgit de la base de dades no coincideix amb el que s'ha inserit.");
				}
				if (!entitats4C.get(i).getAtribut2C().equals(entitat4CRead.getAtribut2C())){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4C que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
				}
				if (entitats4C.get(i).getAtribut3C().getAtribut1D() != entitat4CRead.getAtribut3C().getAtribut1D()){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4C que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
				}
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}

			pk.clear();
			pk.add(entitats4D.get(i).getAtribut1D());
			
			try {
				entitat4DRead = (Entitat4D) session.read(nameEntity4D, pk);
				if (entitat4DRead == null){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4D no s'ha pogut llegir de la base de dades.");
				}
				if (entitats4D.get(i).getAtribut1D() != entitat4DRead.getAtribut1D()){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4D que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
				}
				if (!entitats4D.get(i).getAtribut2D().equals(entitat4DRead.getAtribut2D())){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4D que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
				}
				if (entitats4D.get(i).getAtribut3D().getAtribut1B() != entitat4DRead.getAtribut3D().getAtribut1B()){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4D que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
				}
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}

			pk.clear();
			pk.add(entitats4E.get(i).getAtribut1E());
			
			try {
				entitat4ERead = (Entitat4E) session.read(nameEntity4E, pk);
				if (entitat4ERead == null){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4E no s'ha pogut llegir de la base de dades.");
				}
				if (entitats4E.get(i).getAtribut1E() != entitat4ERead.getAtribut1E()){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4E que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
				}
				if (!entitats4E.get(i).getAtribut2E().equals(entitat4ERead.getAtribut2E())){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4E que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
				}
				if (entitats4E.get(i).getAtribut3E().getAtribut1B() != entitat4ERead.getAtribut3E().getAtribut1B()){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4E que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
				}
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}

			pk.clear();
			pk.add(entitats4F.get(i).getAtribut1F());
			
			try {
				entitat4FRead = (Entitat4F) session.read(nameEntity4F, pk);
				if (entitat4FRead == null){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4F no s'ha pogut llegir de la base de dades.");
				}
				if (entitats4F.get(i).getAtribut1F() != entitat4FRead.getAtribut1F()){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4F que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
				}
				if (!entitats4F.get(i).getAtribut2F().equals(entitat4FRead.getAtribut2F())){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4F que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
				}
				if (entitat4FRead.getAtribut3F().getAtribut1E() != entitats4F.get(i).getAtribut3F().getAtribut1E()){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4F que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
				}
				if (entitat4FRead.getAtribut4F().getAtribut1C() != entitats4F.get(i).getAtribut4F().getAtribut1C()){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4F que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
				}
				if (entitat4FRead.getAtribut5F().getAtribut1D() != entitats4F.get(i).getAtribut5F().getAtribut1D()){
					session.close();
					Assert.fail("L'objecte de l'entitat Entitat4F que s'ha llegit de la base de dades no coincideix amb el que s'ha inserit.");
				}
			} 
			catch (MyFrameUOCException e) {
				try {
					session.close();
				} 
				catch (MyFrameUOCException e1) {
				}
				Assert.fail(e.getMessage());
			}
		}
		
		//Actualitzar objecte 0 de l'entitat Entitat4A.
		atributs4ANous.clear();
		entitat4A = entitats4A.get(0);
		atributs4ANous.add(new String("Nou valor atribut1A " + 0));
		entitat4B = entitats4B.get(1);
		atributs4ANous.add(entitat4B);
		entitat4A.setAtribut2A(String.valueOf(atributs4ANous.get(0)));
		entitat4A.setAtribut3A((Entitat4B) atributs4ANous.get(1));

		try {
			session.update(entitat4A);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			}
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}

		pk.clear();
		pk.add(entitat4A.getAtribut1A());

		try {
			entitat4ARead = (Entitat4A) session.read(nameEntity4A, pk);
			if (entitat4ARead == null){
				session.close();
				Assert.fail("L'actualitzaci de l'objecte de l'entitat Entitat4A no s'ha fet correctament.");
			}
			if (!entitat4A.getAtribut2A().equals(entitat4ARead.getAtribut2A())){
				session.close();
				Assert.fail("L'actualitzaci de l'objecte de l'entitat Entitat4A no ha s'ha fet correctament.");
			}
			if (entitat4A.getAtribut3A().getAtribut1B() != entitat4ARead.getAtribut3A().getAtribut1B()){
				session.close();
				Assert.fail("L'actualitzaci de l'objecte de l'entitat Entitat4A no ha s'ha fet correctament.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		//Actualitzar l'objecte 1 de l'entitat4A.
		atributs4ANous.clear();
		entitat4A = entitats4A.get(1);
		atributs4ANous.add(new String("Nou valor atribut1A " + 1));
		entitat4B = entitats4B.get(2);
		atributs4ANous.add(entitat4B);
		entitat4A.setAtribut2A(String.valueOf(atributs4ANous.get(0)));
		entitat4A.setAtribut3A((Entitat4B) atributs4ANous.get(1));

		try {
			session.update(entitat4A);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			}
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}

		pk.clear();
		pk.add(entitat4A.getAtribut1A());

		try {
			entitat4ARead = (Entitat4A) session.read(nameEntity4A, pk);
			if (entitat4ARead == null){
				session.close();
				Assert.fail("L'actualitzaci de l'objecte de l'entitat Entitat4A no s'ha fet correctament.");
			}
			if (!entitat4A.getAtribut2A().equals(entitat4ARead.getAtribut2A())){
				session.close();
				Assert.fail("L'actualitzaci de l'objecte de l'entitat Entitat4A no ha s'ha fet correctament.");
			}
			if (entitat4A.getAtribut3A().getAtribut1B() != entitat4ARead.getAtribut3A().getAtribut1B()){
				session.close();
				Assert.fail("L'actualitzaci de l'objecte de l'entitat Entitat4A no ha s'ha fet correctament.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		
		atributs4BNous.clear();
		atributs4BNous.add(new String("Nou valor atribut2B " + 2));
		atributs4BNous.add(entitats4A.get(3));
		atributs4BNous.add(entitats4C.get(2));
		entitat4B = entitats4B.get(2);
		entitat4B.setAtribut2B(String.valueOf(atributs4BNous.get(0)));
		entitat4B.setAtribut3B((Entitat4A) atributs4BNous.get(1));
		entitat4B.setAtribut4B((Entitat4C) atributs4BNous.get(2));
		
		try {
			session.update(entitat4B);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(entitat4B.getAtribut1B());
		try {
			entitat4BRead = (Entitat4B) session.read(nameEntity4B, pk);
			if (entitat4BRead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4B no s'ha pogut llegir de la base de dades.");
			}
			if (!atributs4BNous.get(0).equals(entitat4BRead.getAtribut2B())){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4B no s'ha actualitzat correctament.");
			}
			entitat4A = (Entitat4A) atributs4BNous.get(1);
			if (entitat4A.getAtribut1A() != entitat4BRead.getAtribut3B().getAtribut1A()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4B no s'ha actualitzat correctament.");
			}
			entitat4C = (Entitat4C) atributs4BNous.get(2);
			if (entitat4C.getAtribut1C() != entitat4BRead.getAtribut4B().getAtribut1C()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4B no s'ha actualitzat correctament.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4F);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4E);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			}
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4A);
		}
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0008(){
		Entitat4A entitat4A				= new Entitat4A();
		Entitat4B entitat4B				= new Entitat4B();
		Entitat4C entitat4C				= new Entitat4C();
		Entitat4D entitat4D				= new Entitat4D();
		Entitat4E entitat4E				= new Entitat4E();
		Entitat4F entitat4F				= new Entitat4F();
		String nameEntity4A				= Entitat4A.class.getCanonicalName();
		String nameEntity4B				= Entitat4B.class.getCanonicalName();
		String nameEntity4C				= Entitat4C.class.getCanonicalName();
		String nameEntity4D				= Entitat4D.class.getCanonicalName();
		String nameEntity4E				= Entitat4E.class.getCanonicalName();
		String nameEntity4F				= Entitat4F.class.getCanonicalName();
		ArrayList<Object> atributs4A	= new ArrayList<Object>();
		ArrayList<Object> atributs4B	= new ArrayList<Object>();
		ArrayList<Object> atributs4C	= new ArrayList<Object>();
		ArrayList<Object> atributs4D	= new ArrayList<Object>();
		ArrayList<Object> atributs4E	= new ArrayList<Object>();
		ArrayList<Object> atributs4F	= new ArrayList<Object>();
		Session session					= null;
		Entitat4A entitat4ARead			= null;
		Entitat4B entitat4BRead			= null;
		Entitat4C entitat4CRead			= null;
		Entitat4D entitat4DRead			= null;
		Entitat4E entitat4ERead			= null;
		Entitat4F entitat4FRead			= null;
		ArrayList<Object> pk			= null;
		
		atributs4A.add(1);
		atributs4A.add(new String("Valor atribut2A"));
		
		atributs4B.add(1);
		atributs4B.add(new String("Valor atribut2B"));
		
		atributs4C.add(1);
		atributs4C.add(new String("Valor atribut2C"));
		
		atributs4D.add(1);
		atributs4D.add(new String("Valor atribut2D"));
		
		atributs4E.add(1);
		atributs4E.add(new String("Valor atribut2E"));
		
		atributs4F.add(1);
		atributs4F.add(new String("Valor atribut2F"));
		
		entitat4A.setAtribut1A(Integer.parseInt(String.valueOf(atributs4A.get(0))));
		entitat4A.setAtribut2A(String.valueOf(atributs4A.get(1)));
		
		entitat4B.setAtribut1B(Integer.parseInt(String.valueOf(atributs4B.get(0))));
		entitat4B.setAtribut2B(String.valueOf(atributs4B.get(1)));
		
		entitat4C.setAtribut1C(Integer.parseInt(String.valueOf(atributs4C.get(0))));
		entitat4C.setAtribut2C(String.valueOf(atributs4C.get(1)));
		
		entitat4D.setAtribut1D(Integer.parseInt(String.valueOf(atributs4D.get(0))));
		entitat4D.setAtribut2D(String.valueOf(atributs4D.get(1)));
		
		entitat4E.setAtribut1E(Integer.parseInt(String.valueOf(atributs4E.get(0))));
		entitat4E.setAtribut2E(String.valueOf(atributs4E.get(1)));
		
		entitat4F.setAtribut1F(Integer.parseInt(String.valueOf(atributs4F.get(0))));
		entitat4F.setAtribut2F(String.valueOf(atributs4F.get(1)));
		
		entitat4A.setAtribut3A(entitat4B);
		entitat4B.setAtribut3B(entitat4A);
		entitat4B.setAtribut4B(entitat4C);
		entitat4C.setAtribut3C(entitat4D);
		entitat4D.setAtribut3D(entitat4B);
		entitat4E.setAtribut3E(entitat4B);
		entitat4F.setAtribut3F(entitat4E);
		entitat4F.setAtribut4F(entitat4C);
		entitat4F.setAtribut5F(entitat4D);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4F);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4E);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4A);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat4A);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat4E);
		}
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat4F);
		}
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
	
		
		try {
			session.delete(entitat4A);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		
		pk = new ArrayList<Object>();
		pk.add(entitat4A.getAtribut1A());
		
		try {
			entitat4ARead = (Entitat4A) session.read(nameEntity4A, pk);
			if (entitat4ARead !=  null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4A no s'ha esborrat de la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			}
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(entitat4B.getAtribut1B());
		
		try {
			entitat4BRead = (Entitat4B) session.read(nameEntity4B, pk);
			if (entitat4BRead != null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4B no s'ha esborrat de la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(entitat4C.getAtribut1C());
		
		try {
			entitat4CRead = (Entitat4C) session.read(nameEntity4C, pk);
			if (entitat4CRead != null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4C no s'ha esborrat de la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(entitat4D.getAtribut1D());
		
		try {
			entitat4DRead = (Entitat4D) session.read(nameEntity4D, pk);
			if (entitat4DRead != null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4D no s'ha esborrat de la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(entitat4E.getAtribut1E());
		
		try {
			entitat4ERead = (Entitat4E) session.read(nameEntity4E, pk);
			if (entitat4ERead != null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4E no s'ha esborrat de la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			}
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(entitat4F.getAtribut1F());
		
		try {
			entitat4FRead = (Entitat4F) session.read(nameEntity4F, pk);
			if (entitat4FRead != null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat4F no s'ha esborrat de la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4F);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4E);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			}
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntity4A);
		}
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0009(){
		Entitat0009A entitatA			= null;
		Entitat0009B entitatB			= null;
		String nameEntityA				= Entitat0009A.class.getCanonicalName();
		String nameEntityB				= Entitat0009B.class.getCanonicalName();
		Session session					= null;
		Entitat0009A entitatARead		= null;
		Entitat0009B entitatBRead		= null;
		ArrayList<Object> pk			= new ArrayList<Object>();
		
		entitatA = new Entitat0009A();
		entitatA.setAtribut1A(1);
		entitatA.setAtribut2A("Valor de l'atribut atribut2A");
		
		entitatB = new Entitat0009B();
		entitatB.setAtribut1B(1);
		entitatB.setAtribut2B("1B");
		entitatB.setAtribut3B("Valor de l'atribut3B");
		
		entitatA.setAtribut3A(entitatB);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntityA);
		}
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitatA);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(entitatA.getAtribut1A());
		
		try {
			entitatARead = (Entitat0009A) session.read(nameEntityA, pk);
			if (entitatARead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat0009A no s'ha pogut recuperar de la base de dades.");
			}
			if (!entitatA.getAtribut2A().equals(entitatARead.getAtribut2A())){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat0009A no s'ha emmagatzemat correctament en la base de dades.");
			}
			if (entitatA.getAtribut3A().getAtribut1B() != entitatARead.getAtribut3A().getAtribut1B() ||
					!entitatA.getAtribut3A().getAtribut2B().equals(entitatARead.getAtribut3A().getAtribut2B())){
				session.close();
				Assert.fail("L'objecte de l'entitat Entiat0009A no s'ha emmagatzemat correctament en la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(entitatB.getAtribut1B());
		pk.add(entitatB.getAtribut2B());
		
		try {
			entitatBRead = (Entitat0009B) session.read(nameEntityB, pk);
			if (entitatBRead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat0009B no s'ha pogut recuperar de la base de dades.");
			}
			if (!entitatB.getAtribut3B().equals(entitatBRead.getAtribut3B())){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat0009B no s'ha emmagatzemat correctament en la base de dades.");
			}
		}
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitatA);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntityA);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		}
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
}
