package test.mapping.onetomany;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;

import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import org.junit.runners.Parameterized.Parameters;


import com.uoc.myframeuoc.environment.Session;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;


/**
 * Proves de les relacions d'un a molts.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
@RunWith(Parameterized.class)
public class OneToManyTest {
	private String file		= null;
	
	@Parameters
	public static Collection<Object[]> data(){
		Object[][] data = {
							{"test/ConfigurationFiles/OracleConfiguration.xml"}, 
							{"test/ConfigurationFiles/MySQLConfiguration.xml"}
						};
		return Arrays.asList(data);
	}
	
	public OneToManyTest(String file){
		this.file = file;
	}

	@Test
	public void test0001(){
		Session session								= null;
		Entitat0001A entitatA						= new Entitat0001A();
		Entitat0001B entitatB						= null;
		String nameEntityA							= Entitat0001A.class.getCanonicalName();
		ArrayList<Entitat0001B> llistaB				= new ArrayList<Entitat0001B>();
		int elementsB								= 5;
		Entitat0001A entitatARead					= null;
		Entitat0001B entitatBRead					= null;
		ArrayList<Object> pk						= new ArrayList<Object>();
		ArrayList<Entitat0001B> llistaBRead			= new ArrayList<Entitat0001B>();
		
		
		for (int i = 0; i < elementsB; i++){
			entitatB = new Entitat0001B();
			entitatB.setAtribut1B(i);
			entitatB.setAtribut2B("Valor de l'atribut2B " + i);
			llistaB.add(entitatB);
		}
		
		entitatA.setAtribut1A(1);
		entitatA.setAtribut2A("Valor de l'atribut2A");
		entitatA.setAtribut3A(llistaB);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntityA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitatA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(entitatA.getAtribut1A());
		
		try {
			entitatARead = (Entitat0001A) session.read(nameEntityA, pk);
			if (entitatARead == null){
				session.closeNoEx();
				Assert.fail("L'objecte de l'entitat Entitat0001A no s'ha pogut recuperar de la base de dades.");
			}
			if (!entitatA.getAtribut2A().equals(entitatARead.getAtribut2A())){
				session.closeNoEx();
				Assert.fail("L'objecte de l'entitat Entitat0001A no s'ha emmagatzemat correctament en la base de dades.");
			}
			llistaBRead = (ArrayList<Entitat0001B>) entitatARead.getAtribut3A();
			for (int i = 0; i < elementsB; i++){
				entitatBRead = llistaBRead.get(i);
				if (llistaB.get(i).getAtribut1B() != entitatBRead.getAtribut1B()){
					session.closeNoEx();
					Assert.fail("Un dels objeces de la collecci de l'entitat Entitat0001A no s'ha pogut recuperar de la base de dades.");
				}
			}
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		entitatA = new Entitat0001A();
		entitatA.setAtribut1A(1);
		entitatA.setAtribut2A("Nou valor per a l'atribut2A");
		
		llistaB.clear();	
		for (int i = 0; i < elementsB + 5; i++){
			entitatB = new Entitat0001B();
			entitatB.setAtribut1B(i + elementsB);
			entitatB.setAtribut2B("Nou valor de l'atribut2B " + i);
			llistaB.add(entitatB);
		}
		
		entitatA.setAtribut3A(llistaB);
		
		try {
			session.update(entitatA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(entitatA.getAtribut1A());
		
		try {
			entitatARead = (Entitat0001A) session.read(nameEntityA, pk);
			if (entitatARead == null){
				session.closeNoEx();
				Assert.fail("L'objecte de l'entitat Entitat0001A no s'ha pogut recuperar de la base de dades desprs de fer l'actualitzaci.");
			}
			if (!entitatA.getAtribut2A().equals(entitatARead.getAtribut2A())){
				session.closeNoEx();
				Assert.fail("L'objecte de l'entitat Entitat0001A no s'ha actualitzat correctament en la base de dades.");
			}
			llistaBRead = (ArrayList<Entitat0001B>) entitatARead.getAtribut3A();
			for (int i = 0; i < elementsB; i++){
				entitatBRead = llistaBRead.get(i);
				if (llistaB.get(i).getAtribut1B() != entitatBRead.getAtribut1B()){
					session.closeNoEx();
					Assert.fail("Un dels objeces de la collecci de l'entitat Entitat0001A no s'ha actualitzat correctament en la base de dades.");
				}
			}
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(llistaB.get(0));
		}
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitatA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		
		try {
			entitatARead = (Entitat0001A) session.read(nameEntityA, pk);
			if (entitatARead != null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat0001A no s'ha eliminat correctament de la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitatA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}

		try {
			session.drop(nameEntityA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0002(){
		Entitat0002A entitatA				= null;
		Entitat0002B entitatB				= null;
		Entitat0002C entitatC				= null;
		Entitat0002D entitatD				= null;
		String nameEntityA					= Entitat0002A.class.getCanonicalName();
		Session session						= null;
		ArrayList<Object> pk				= new ArrayList<Object>();
		ArrayList<Entitat0002B> llistaB		= new ArrayList<Entitat0002B>();
		ArrayList<Entitat0002C> llistaC		= new ArrayList<Entitat0002C>();
		ArrayList<Entitat0002D> llistaD		= new ArrayList<Entitat0002D>();
		int elements						= 3;
		Entitat0002A entitatARead			= null;
		
		for (int i = 0; i < elements; i++){
			entitatD = new Entitat0002D();
			entitatD.setAtribut1D(i);
			entitatD.setAtribut2D("Valor atribut2D " + i);
			llistaD.add(entitatD);
		}
		
		entitatC = new Entitat0002C();
		entitatC.setAtribut1C(1);
		entitatC.setAtribut2C("Valor atribut2C");
		entitatC.setAtribut3C(llistaD);
		llistaC.add(entitatC);
		
		entitatB = new Entitat0002B();
		entitatB.setAtribut1B(1);
		entitatB.setAtribut2B("Valor atribut2B");
		entitatB.setAtribut3B(llistaC);
		llistaB.add(entitatB);
		
		entitatA = new Entitat0002A();
		entitatA.setAtribut1A(1);
		entitatA.setAtribut2A("Valor atribut2A");
		entitatA.setAtribut3A(llistaB);
		
		try {
			session = Session.getSession(this.file);
		}
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntityA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitatA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(entitatA.getAtribut1A());
		
		try {
			entitatARead = (Entitat0002A) session.read(nameEntityA, pk);
			if (entitatARead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat Entiat0002A no s'ha pogut recuperar de la base de dades.");
			}
			if (!entitatA.getAtribut2A().equals(entitatARead.getAtribut2A())){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat0002A no s'ha emmagatzemat correctament en la base de dades.");
			}
			if (entitatA.getAtribut3A().get(0).getAtribut1B() != entitatARead.getAtribut3A().get(0).getAtribut1B()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat0002A no s'ha emmagatzemat correctament en la base de dades.");
			}
			if (entitatA.getAtribut3A().get(0).getAtribut3B().get(0).getAtribut1C() != entitatARead.getAtribut3A().get(0).getAtribut3B().get(0).getAtribut1C()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat0002A no s'ha emmagatzemat correctament en la base de dades.");
			}
			if (entitatA.getAtribut3A().get(0).getAtribut3B().get(0).getAtribut3C().get(1).getAtribut1D() != entitatARead.getAtribut3A().get(0).getAtribut3B().get(0).getAtribut3C().get(1).getAtribut1D()){
				session.close();
				Assert.fail("L'objecte de l'entitat Entitat0002A no s'ha emmagatzemat correctament en la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitatA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntityA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
}
