package test.mapping.onetoone;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;

import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import org.junit.runners.Parameterized.Parameters;


import com.uoc.myframeuoc.environment.Session;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;


/**
 * Proves de les relacions d'un a un.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
@RunWith(Parameterized.class)
public class OneToOneTest {
	private String file		= null;
	
	@Parameters
	public static Collection<Object[]> data(){
		Object[][] data = {
							{"test/ConfigurationFiles/OracleConfiguration.xml"}, 
							{"test/ConfigurationFiles/MySQLConfiguration.xml"}
						};
		return Arrays.asList(data);
	}
	
	public OneToOneTest(String file){
		this.file = file;
	}

	@Test
	public void test0001(){
		Session session					= null;
		EntitatA entitatA				= null;
		EntitatB entitatB				= null;
		ArrayList<Object> atributsA		= new ArrayList<Object>();
		ArrayList<Object> atributsB		= new ArrayList<Object>();
		String nameEntityA				= EntitatA.class.getCanonicalName();
		String nameEntityB				= EntitatB.class.getCanonicalName();
		EntitatA entitatARead			= null;
		EntitatB entitatBRead			= null;
		ArrayList<Object> pk			= new ArrayList<Object>();
		
		atributsA.add(1);
		atributsA.add("Valor atribut2A");
	
		atributsB.add(1);
		atributsB.add("Valor atribut2B");
		
		entitatA = new EntitatA();
		entitatB = new EntitatB();
		
		entitatB.setAtribut1B(Integer.parseInt(String.valueOf(atributsB.get(0))));
		entitatB.setAtribut2B(String.valueOf(atributsB.get(1)));
		
		entitatA.setAtribut1A(Integer.parseInt(String.valueOf(atributsA.get(0))));
		entitatA.setAtribut2A(String.valueOf(atributsA.get(1)));
		entitatA.setAtribut3A(entitatB);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		

		try {
			session.drop(nameEntityA);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitatA);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atributsA.get(0));
		
		try {
			entitatARead = (EntitatA) session.read(nameEntityA, pk);
			if (entitatARead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat EntitatA no s'ha emmagatzemat correctament en la base de dades.");
			}
			if (!atributsA.get(1).equals(entitatARead.getAtribut2A())){
				session.close();
				Assert.fail("L'objecte de l'entitat EntitatA no s'ha emmagatzemat correctament en la base de dades.");
			}
			if (entitatB.getAtribut1B() != entitatARead.getAtribut3A().getAtribut1B()){
				session.close();
				Assert.fail("L'objecte de l'entitat EntitatA no s'ha emmeagatzemat correctament en la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atributsB.get(0));
		try {
			entitatBRead = (EntitatB) session.read(nameEntityB, pk);
			if (entitatBRead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat EntitatB no s'ha pogut recuperar de la base de dades.");
			}
			if (!atributsB.get(1).equals(entitatBRead.getAtribut2B())){
				session.close();
				Assert.fail("L'objecte de l'entitat EntitatB no s'ha pogut recuperar de la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitatA);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntityA);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		}
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0002(){
		Session session					= null;
		EntitatA entitatA				= null;
		EntitatB entitatB				= null;
		ArrayList<Object> atributsA		= new ArrayList<Object>();
		ArrayList<Object> atributsB		= new ArrayList<Object>();
		ArrayList<Object> atributsANous	= new ArrayList<Object>();
		ArrayList<Object> atributsBNous	= new ArrayList<Object>();
		String nameEntityA				= EntitatA.class.getCanonicalName();
		String nameEntityB				= EntitatB.class.getCanonicalName();
		EntitatA entitatARead			= null;
		EntitatB entitatBRead			= null;
		ArrayList<Object> pk			= new ArrayList<Object>();
		
		atributsA.add(1);
		atributsA.add("Valor atribut2A");
	
		atributsB.add(1);
		atributsB.add("Valor atribut2B");
		
		entitatA = new EntitatA();
		entitatB = new EntitatB();
		
		entitatB.setAtribut1B(Integer.parseInt(String.valueOf(atributsB.get(0))));
		entitatB.setAtribut2B(String.valueOf(atributsB.get(1)));
		
		entitatA.setAtribut1A(Integer.parseInt(String.valueOf(atributsA.get(0))));
		entitatA.setAtribut2A(String.valueOf(atributsA.get(1)));
		entitatA.setAtribut3A(entitatB);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntityA);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitatA);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atributsA.get(0));
		
		try {
			entitatARead = (EntitatA) session.read(nameEntityA, pk);
			if (entitatARead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat EntitatA no s'ha emmagatzemat correctament en la base de dades.");
			}
			if (!atributsA.get(1).equals(entitatARead.getAtribut2A())){
				session.close();
				Assert.fail("L'objecte de l'entitat EntitatA no s'ha emmagatzemat correctament en la base de dades.");
			}
			if (entitatB.getAtribut1B() != entitatARead.getAtribut3A().getAtribut1B()){
				session.close();
				Assert.fail("L'objecte de l'entitat EntitatA no s'ha emmeagatzemat correctament en la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atributsB.get(0));
		try {
			entitatBRead = (EntitatB) session.read(nameEntityB, pk);
			if (entitatBRead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat EntitatB no s'ha pogut recuperar de la base de dades.");
			}
			if (!atributsB.get(1).equals(entitatBRead.getAtribut2B())){
				session.close();
				Assert.fail("L'objecte de l'entitat EntitatB no s'ha pogut recuperar de la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		atributsANous.add("Nou valor atribut2A");
		
		atributsBNous.add(3);
		atributsBNous.add("Nou valor atribut2B");
		
		entitatB = new EntitatB();
		entitatB.setAtribut1B(Integer.parseInt(String.valueOf(atributsBNous.get(0))));
		entitatB.setAtribut2B(String.valueOf(atributsBNous.get(1)));
		
		entitatA.setAtribut2A(String.valueOf(atributsANous.get(0)));
		entitatA.setAtribut3A(entitatB);
		
		try {
			session.update(entitatA);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atributsA.get(0));
		
		try {
			entitatARead = (EntitatA) session.read(nameEntityA, pk);
			if (entitatARead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat EntitatA no s'ha actualitzat correctament.");
			}
			if (!atributsANous.get(0).equals(entitatARead.getAtribut2A())){
				session.close();
				Assert.fail("L'objecte de l'entitat EntitatA no s'ha actualitzat correctament.");
			}
			if (entitatB.getAtribut1B() != entitatARead.getAtribut3A().getAtribut1B()){
				session.close();
				Assert.fail("L'objecte de l'entitat EntitatA no s'ha actualitzat correctament.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(atributsBNous.get(0));
		try {
			entitatBRead = (EntitatB) session.read(nameEntityB, pk);
			if (entitatBRead == null){
				session.close();
				Assert.fail("L'objecte de l'entitat EntitatB no s'ha pogut recuperar de la base de dades.");
			}
			if (!atributsBNous.get(1).equals(entitatBRead.getAtribut2B())){
				session.close();
				Assert.fail("L'objecte de l'entitat EntitatB no s'ha actualitzat correctament.");
			}
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitatB);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitatA);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntityA);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		}
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0003(){
		Entitat0003A entitatA1		= null;
		Entitat0003B entitatB1		= null;
		Entitat0003A entitatA2		= null;
		Entitat0003B entitatB2		= null;
		String nameEntityA			= Entitat0003A.class.getCanonicalName();
		Session session				= null;
		
		entitatA1 = new Entitat0003A();
		entitatA1.setAtribut1A(1);
		entitatA1.setAtribut2A("Valor de l'atribut2A A1");
		
		entitatA2 = new Entitat0003A();
		entitatA2.setAtribut1A(2);
		entitatA2.setAtribut2A("Valor de l'atribut2A A2");
		
		entitatB2 = new Entitat0003B();
		entitatB2.setAtribut1B(2);
		entitatB2.setAtribut2B("Valor de l'atribut2B B2");
		entitatB2.setAtribut3B(entitatA1);
		entitatA2.setAtribut3A(entitatB2);
		
		entitatB1 = new Entitat0003B();
		entitatB1.setAtribut1B(1);
		entitatB1.setAtribut2B("Valor de l'atribut2B B1");
		entitatB1.setAtribut3B(entitatA2);
		
		entitatA1.setAtribut3A(entitatB1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntityA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitatA1);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitatA1);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntityA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0004(){
		Entitat0004A entitatA			= new Entitat0004A();
		Entitat0004B entitatB			= new Entitat0004B();
		Entitat0004C entitatC			= new Entitat0004C();
		String nameEntityA				= Entitat0004A.class.getCanonicalName();
		String nameEntityB				= Entitat0004B.class.getCanonicalName();
		String nameEntityC				= Entitat0004C.class.getCanonicalName();
		Session session					= null;
		ArrayList<Object> pk			= new ArrayList<Object>();
		Entitat0004A entitatARead		= null;
		Entitat0004B entitatBRead		= null;
		Entitat0004C entitatCRead		= null;
		
		entitatA.setAtribut1A(1);
		entitatA.setAtribut2A("Valor atribut2A");
		
		entitatB.setAtribut1B(1);
		entitatB.setAtribut2B("Valor atribut2B");
		
		entitatC.setAtribut1C(1);
		entitatC.setAtribut2C("Valor atribut2C");
		
		entitatB.setAtribut3B(entitatC);
		entitatA.setAtribut3A(entitatB);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntityA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitatA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitatB);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitatC);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitatA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(entitatA.getAtribut1A());
		
		try {
			entitatARead = (Entitat0004A) session.read(nameEntityA, pk);
			if (entitatARead == null){
				session.closeNoEx();
				Assert.fail("L'objecte de l'entitat Entitat0004A no s'ha emmagatzemat correctament en la base de dades.");
			}
			if (!entitatA.getAtribut2A().equals(entitatARead.getAtribut2A())){
				session.closeNoEx();
				Assert.fail("L'objecte de l'entitat Entitat0004A no s'ha emmagatzemat correctament en la base de dades.");
			}
			if (entitatA.getAtribut3A().getAtribut1B() != entitatARead.getAtribut3A().getAtribut1B()){
				session.closeNoEx();
				Assert.fail("L'objecte de l'entitat Entitat0004A no s'ha emmagatzemat correctament en la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(entitatB.getAtribut1B());
		
		try {
			entitatBRead = (Entitat0004B) session.read(nameEntityB, pk);
			if (entitatBRead == null){
				session.closeNoEx();
				Assert.fail("L'objecte de l'entitat Entitat0004B no s'ha emmagatzemat correctament en la base de dades.");
			}
			if (!entitatB.getAtribut2B().equals(entitatBRead.getAtribut2B())){
				session.closeNoEx();
				Assert.fail("L'objecte de l'entitat Entitat0004B no s'ha emmagatzemat correctament en la base de dades.");
			}
			if (entitatB.getAtribut3B().getAtribut1C() != entitatBRead.getAtribut3B().getAtribut1C()){
				session.closeNoEx();
				Assert.fail("L'objecete de l'entitat Entitat0004B no s'ha emmagatzemat correctament en la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		pk.clear();
		pk.add(entitatC.getAtribut1C());
		try {
			entitatCRead = (Entitat0004C) session.read(nameEntityC, pk);
			if (entitatCRead == null){
				session.closeNoEx();
				Assert.fail("L'objecte de l'entitat Entitat0004C no s'ha emmagatzemat correctament en la base de dades.");
			}
			if (!entitatC.getAtribut2C().equals(entitatCRead.getAtribut2C())){
				session.closeNoEx();
				Assert.fail("L'objecte de l'entitat Entitat0004C no s'ha emmagatzemat correctament en la base de dades.");
			}
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitatA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitatB);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitatC);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntityA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntityB);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntityC);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0005(){
		Entitat0005A entitatA		= new Entitat0005A();
		Entitat0005B entitatB		= new Entitat0005B();
		Entitat0005C entitatC		= new Entitat0005C();
		Session session				= null;
		String nameEntityA			= Entitat0005A.class.getCanonicalName();
		
		entitatA.setAtribut1A(1);
		entitatA.setAtribut2A("Valor de l'atribut2A");
		
		entitatB.setAtribut1B(1);
		entitatB.setAtribut2B("Valor de l'atribut2B");
		
		entitatC.setAtribut1C(1);
		entitatC.setAtribut2C("Valor de l'atribut2C");
		
		entitatB.setAtribut4B(entitatC);
		entitatB.setAtribut3B(entitatA);
		entitatA.setAtribut3A(entitatB);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntityA);
		}
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitatA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitatA);
		}
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(nameEntityA);
		} 
		catch (MyFrameUOCException e) {
			session.closeNoEx();
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
}
