package test.mapping.primarykey;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;

import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import org.junit.runners.Parameterized.Parameters;


import com.uoc.myframeuoc.environment.Session;
import com.uoc.myframeuoc.exceptions.MyFrameUOCException;


/**
 * Proves de les claus primries.
 * 
 * @author Jordi Garcia Casanova.
 *
 */
@RunWith(Parameterized.class)
public class PrimaryKeyTest {
	private String file		= null;
	
	@Parameters
	public static Collection<Object[]> data(){
		Object[][] data = {
							{"test/ConfigurationFiles/OracleConfiguration.xml"}, 
							{"test/ConfigurationFiles/MySQLConfiguration.xml"}
						};
		return Arrays.asList(data);
	}
	
	public PrimaryKeyTest(String file){
		this.file = file;
	}
	
	@Test
	public void test0001(){
		Session session 		= null;
		Entitat0001 entitat		= null;
		ArrayList<Object> pk	= null;
		String msg				= "L'entitat Entitat0001 t definida claus primries amb diferents noms i MyFrameUOC no ha donat error.";
		
		
		entitat = new Entitat0001();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0001.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.insert(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0001.class.getCanonicalName(), pk);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.update(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.delete(entitat);
			try {
				session.close();
			} 
			catch (MyFrameUOCException e) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.drop(Entitat0001.class.getCanonicalName());
			try {
				session.close();
			} 
			catch (MyFrameUOCException e) {
			}
			Assert.fail(msg);
		} 
		catch (MyFrameUOCException e) {
			//OK.
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
	
	@Test
	public void test0002(){
		Session session 		= null;
		Entitat0002 entitat		= null;
		ArrayList<Object> pk	= null;
				
		
		entitat = new Entitat0002();
		
		pk = new ArrayList<Object>();
		
		entitat.setAtribut1(1);
		
		try {
			session = Session.getSession(this.file);
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0002.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.insert(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		pk.add(1);
		
		try {
			session.read(Entitat0002.class.getCanonicalName(), pk);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.update(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.delete(entitat);
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.drop(Entitat0002.class.getCanonicalName());
		} 
		catch (MyFrameUOCException e) {
			try {
				session.close();
			} 
			catch (MyFrameUOCException e1) {
			}
			Assert.fail(e.getMessage());
		}
		
		try {
			session.close();
		} 
		catch (MyFrameUOCException e) {
			Assert.fail(e.getMessage());
		}
	}
}
